% -*- coding:utf-8 mode:trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: core-syntax.pl,v $
%%  $Revision: 161 $
%%      $Date: 2007-05-30 14:47:43 +0200 (Wed, 30 May 2007) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: All the syntactic constrints that belong to
%%             Universal Grammar.
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.


% should be in the signature, but doing this seems to be too
% complicated since FLIP is not introduced by all languages.

% Does not hold for Persian.
%prd_adj *> flip:minus.


% Arguments (like normal NPs) are marked CLUSTER-.
cluster_minus_argument :=
  arg:loc:cluster:minus.

cluster_minus_synsem :=
  loc:cluster:minus.

coherent_le :=
  (optionally_coherent_le,
   synsem:loc:cat:subcat:hd:arg:(loc:cluster:plus,
                                 lex:plus)).



head_argument_phrase  *> synsem:lex:minus.
head_filler_phrase    *> synsem:lex:minus.
head_specifier_phrase *> synsem:lex:minus.



% In Argumentpositionen dürfen nur phrasale Einheiten
% stehen. Das wird gebraucht, da ausgeschlossen werden muß,
% daß "lachen wird" mit dem Kopf-Argument-Schema kombiniert
% wird. `wird' verlangt von seinem Argument, daß es LEX+ ist,
% und das Kopf-Argument-Schem spezifiziert LEX aber als -.
% Somit kann nur das Verbalkomplexschema angewendet werden.
% Bei adjazentem eingebetteten Verb würden unechte Mehrdeutigkeiten
% entstehen und bei nicht-adjazentem eingebetteten Verb ungrammatische
% Sätze zugelassen:
%
% * daß lesen er den Aufsatz wird
% * daß er lesen den Aufsatz wird
%
head_argument_phrase *> non_head_dtrs:hd:synsem:lex:minus.

% In Persian the future auxiliary allows the embedding of LEX- projections
% (projections that include clitics), but it requires that those are part of
% the predicate complex (CLUSTER+). If a head requires its argument to be
% CLUSTER+, we have to make sure that this argument does not appear
% in a head-argument structure.
head_argument_phrase *> non_head_dtrs:hd:synsem:loc:cluster:minus.

% Of course, in an head argument phrase the head daughter is not part of a cluster.
head_argument_phrase *> head_dtr:synsem:loc:cluster:minus.

% The version of the schema below allows for Standard German only, since all verbal complexes
% have to be formed before a combination with governing verbs takes place.
%
% [V_3 V_2] V_1
%
% However in some German dialects and other languages
% it is possible to raise verbs (or adjectives or particles)
% that take part of complex formation.
%
% [V_3 [V_1 V_2]]
%
% The result is a complex [V_1 V_2] which has the spirit of V_2 on its
% SUBCAT list. Therefore the combination of [V_1 V_2] with V_3 has to take
% into account the possability of a spirit. St.Mü. 11.06.2007


head_cluster_struc *>
 (synsem:loc:cat:subcat:append(First,
                               [(arg:NonHeadDtr,
                                 raised:Raised,
                                 realized:plus)|Rest]),
  head_dtr:synsem:loc:cat:subcat:append((First,
                                         no_or_one_spirit
                                         %list_of_spirits
                                        ),
                                        [(arg:NonHeadDtr,
                                            raised:Raised,
                                            realized:minus)|Rest]),
  non_head_dtrs:[synsem:(NonHeadDtr,
                         loc:cluster:plus)]).

fun no_or_one_spirit(-).

no_or_one_spirit([]) if true.
no_or_one_spirit([realized:plus]) if true.
%no_or_one_spirit([realized:plus,realized:plus]) if true.


/*
% Standard German
% This does not have any effect on performance.
head_cluster_struc *>
 (synsem:loc:cat:subcat:[(arg:NonHeadDtr,
                          raised:Raised,
                          realized:plus)|Rest],
  head_dtr:synsem:loc:cat:subcat:[(arg:NonHeadDtr,
                                   raised:Raised,
                                   realized:minus)|Rest],
  non_head_dtrs:[synsem:(NonHeadDtr,
                         loc:cluster:plus)]).

*/

fun list_of_blocked_arguments(-).
list_of_blocked_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_blocked_arguments(L) ).

undelayed_list_of_blocked_arguments([]) if true.
undelayed_list_of_blocked_arguments([@blocked_np_ref|T]) if
   list_of_blocked_arguments(T).


% Pro-Drop is max_:plus. Because of extraction traces and
% argument attraction, we do not know the valence list. This may
% cause pro-drop to fire in infinitely many ways.
head_cluster_phrase *>
  head_dtr:synsem:max_:minus.

