% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: common.pl,v $
%%  $Revision: 223 $
%%      $Date: 2007-09-12 19:27:44 +0200 (Wed, 12 Sep 2007) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% Hack to reset the timer.

:- statistics(walltime,_).


compile_grammar_hook :-
         inform_user_about_top_level,
         print_examples,
         statistics(walltime,[_,T]),
         msec2time(T,Time),
         number_of(lex(_,_),NumberOfWords),
         format(user_error,"~nGrammatik geladen: ~w~n~w Lexikoneinheiten~n~n",[Time,NumberOfWords]),
         r,   % diese Zeile auskommentieren, falls die Stämme zum Debuggen im Lexikon bleiben sollen
         ( current_predicate(grammar_hook,grammar_hook) -> call_all(grammar_hook)
         ; true).
         

% Interferes with TSDB stuff

%          % If we are at the Prolog top level, ...
%          ( trale_mode(prolog) ->
%              go

%          ;   true
%          ).



t :- testt(all).


% Wie in trale_patches.pl, aber mit Statistik-Ausgaben.

% :- abolish(compile_gram/1).

% compile_gram(File) :-
%   clear_feature_output,   % initialize feature_ordering.pl
%   abolish_preds,
%   reconsult(File),
%   statistics(walltime,_),       % rücksetzen des Timers
%   compile_gram,
%   process_feature_output,       % compile info in feature_ordering.pl
%   statistics(walltime,[_,T]),
%   msec2time(T,Time),
%   number_of(lex(_,_),NumberOfWords),
%   format(user_error,"~nGrammatik geladen: ~w~n~w Lexikoneinheiten~n~n",[Time,NumberOfWords]),
%   r, % diese Zeile auskommentieren, falls die Stämme zum Debuggen im Lexikon bleiben sollen
%   number_of(lex(_,_),NumberOfRemainingWords),
%   format(user_error,"~w verbleibende Lexikoneinheiten~n~n",[NumberOfRemainingWords]),
%   compile_grammar_hook.



:- [trale_home('tsdb/retract_lex_desc')].


% % Dieses Prädikat entfernt die Stämme aus dem Lexikon.
% % In der syntaktischen Analyse braucht man die Stämme nicht,
% % die Grammatikregeln sind ohnehin so formuliert, daß Stämme
% % nicht als Töchter vorkommen können. Stämme für Nomina (Frau, Mann, Haus)
% % und Adjektive (klug, interessant) würden aber beim Parsen in die Parse-Tabelle
% % eingetragen und bei jedem Parse-Schritt wieder überprüft. Diese Arbeit kann
% % man sich sparen, wenn man die Stämme nach der Lexikonberechnung löscht.
r :-    format(user_error,"Lösche Stammeinträge ...~n",[]),
        open_null_stream(DevNull),
        prolog_flag(user_error,UserError,DevNull),
        retract_lex_desc(stem),
        prolog_flag(user_error,_,UserError),
        number_of(lex(_,_),NumberOfRemainingWords),
        format(user_error,"~w verbleibende Lexikoneinheiten~n~n",[NumberOfRemainingWords]).




:- abolish(morph/3).

% % Das ist eine Kopie des Codes aus ale.pl
% % + einer Zeile zur Ausgabe des aktuell erzeugten Wortes.
% % Das ist zum Debuggen und wegen der langen Lexikonkompilierungszeit sinnvoll.

morph(Morphs,WordIn,WordOut):-  % need to instantiate Word even if
  name(WordIn,CodesIn),         %  X becomes X - do we want this?
  make_char_list(CodesIn,CharsIn), 
  morph_chars(Morphs,CharsIn,CharsOut),
  make_char_list(CodesOut,CharsOut),
  name(WordOut,CodesOut),
  format(user_error,"~w~n",[WordOut]),
%  write(user_error,'.'),flush_output(user_error),
  true.





% If a description that should be used for generation is produced from a chart edge,
% which pathes of the input sign shall be considered?
gen_pathes([[synsem,loc,cat,head],[synsem,loc,cat,subcat],[synsem,loc,cont],[rels],[h_cons]]).



% Semantics Definition for Generation with the build-in generator
% ------------------------------------------------------------------------------

% semantics sem1.
% sem1(sem:Cont,Cont) if true.





% Semantics Definition for Generation with Aurelien's generator
% ------------------------------------------------------------------------------

%% PREREQUISITES
%%
%%  o These can be given in theory.pl:
%%          syntactic_object(<type being the mgsat of all syntactic objects>).
%%
%%          ind_path([path,to,index,of,the,mrs]).
%%
%%          cont_path([path,to,mrs]).
%%          liszt_path([path,to,list,of,EPs]).
%%          hcons_path([path,to,handle,constraints]).
%%
%%     Here is what I use. There are chances that it is similar to that:
%%
%%          syntactic_object(syntactic_object).
%%
%%          ind_path([synsem,loc,cont,ind]).
%%          cont_path([synsem,loc,cont]).
%%          liszt_path([synsem,loc,cont,rels]).
%%          hcons_path([synsem,loc,cont,h_cons]).
%%
%% LOADING
%%
%%  o either launch trale with otion:
%%          -e "compile('/path/to/generator/directory/generator.pl')"
%%    or call within trale:
%%          compile('/path/to/generator/directory/generator.pl').
%%
%% USE
%%
%%  o To parse a sentence and generate from its semantics: 
%%          p_and_g([sentence,as,list,of,words]).
%%
%%  o To parse a phrase of description Desc and generate from its semantics:
%%          p_and_g([sentence,as,list,of,words],Desc).
%%
%%  o To generate from a description Desc (representing the whole sign, not only the
%%    semantics), getting all the outputs in the list Words, and matching Desc to the
%%    description Root:
%%          g(Desc).
%%          g(Desc,Words).
%%          g_d(Desc,Words,Root).
%%          g_d(Desc,Root).


          syntactic_object(syntactic_object).

          ind_path([synsem,loc,cont,ind]).
          gtop_path([synsem,loc,cont,gtop]).
          cont_path([synsem,loc,cont]).
          liszt_path([rels]).
          hcons_path([h_cons]).

outscoped_feat(larg).
sc_arg_feat(harg).
scopable_description([@decl,@interrog]).

quantifiers([udef_q,def_q,some_q,demonstrative_q,proper_q]).

%:- compile('generator.pl').



make :- ensure_loaded([trale_home(grammar_interface),
                       trale_home('tsdb/itsdb'),
                       trale_home('chart_display/chart_display'),
                       trale_home('chart_display/sic'),
%                       trale_home('chart_display/ale_redefinitions'),
                       trale_home('chart_display/print_mrs'),
                       trale_home('chart_display/print_mrs_utool'),
                       trale_home('chart_display/utool-interface'),
                  trale_home('tsdb/retract_lex_desc')    % retraction of stems
                  ,trale_home('tsdb/itsdb-err')              % capi-registration write-filed ...
                 ,trale_home('tsdb/trale-itsdb')
                      ,trale_home('debug_unify')
                      ,trale_home('test_suite_handling')
                      ,trale_home('toplevel')
                      ,test_items
                      ,tokenization
                 ]),
         discontinuous_edges,
         chart_display,
%         nofs,
%         german,
         notcl_warnings,
%         hrp,
         mrs,
         display_mrs,
         scope_mrs,
         debug_mrs,
         true.


