% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: core-constraints.pl,v $
%%  $Revision: 292 $
%%      $Date: 2008-01-14 11:24:02 +0100 (Mo, 14 Jan 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.

:- multifile if/2.
:- discontiguous if/2.

:- multifile fun/1.
:- discontiguous fun/1.

:- multifile macro/2.

% append(+,+,-)
% This append assumes that the first or the third argument
% are known to be non_empty or empty lists. 
%

fun append(+,+,-).
append(X,Y,Z) if 
   when( (X=(e_list;ne_list);
          Z=(e_list;ne_list)) 
       , undelayed_append(X,Y,Z)
       ).

undelayed_append([],L,L) if true.
undelayed_append([H|T1],L,[H|T2]) if append(T1,L,T2).

fun del(+,+,-).
del(X,Y,Z) if 
   when( (Y=(e_list;ne_list);
          Z=(e_list;ne_list)) 
       , undelayed_del(X,Y,Z)
       ).

undelayed_del(El,[El|L],L) if true.
undelayed_del(El,[H|T1],[H|T2]) if del(El,T1,T2).


/*

This version is not correct since it fires for [X|_] and returns X.

fun last(+,-).
last(X,L) if
  when( X=(e_list;ne_list)
      , undelayed_last(X,L)
      ).

undelayed_last([L],L) if true.
undelayed_last(tl:T1,L) if last(T1,L).

*/


fun last(+,-).
last(X,Last) if
  when( X=(e_list;ne_list)
      , last2(X,Last)
      ).

last2([H|T],Last) if
  when( T=(e_list;ne_list)
      , undelayed_last([H|T],Last)
      ).

undelayed_last([Last],Last) if true.
undelayed_last(tl:T1,Last)  if last(T1,Last).

% like last, but with different fun declaration.
fun last_el(-,+).
last_el(X,Last) if
  when( X=(e_list;ne_list)
      , last2(X,Last)
      ).

fun member(-,+).  % returns a member
member(El,List) if 
   when( List=(e_list;ne_list)
       , undelayed_member(El,List)
       ).

undelayed_member(El,hd:El)  if true.
undelayed_member(El,tl:T1) if member(El,T1).




fun list_with_zero_or_one_element(-).
list_with_zero_or_one_element(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_zero_or_one_element(X)
      ).
      
undelayed_list_with_zero_or_one_element(e_list)    if true.
undelayed_list_with_zero_or_one_element(tl:e_list) if true.


% Persian does not have a restriction on the number of fronted elements (Karimi:2005a:18)
% If we parse bottom-up this would result in non-termination. Therefore we need to stipulate
% a maximal number of elements in SLASH. The following constraints restricts a list to at most
% two elements.
fun list_with_at_most_two_elements(-).
list_with_at_most_two_elements(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_at_most_two_elements(X)
      ).

undelayed_list_with_at_most_two_elements(e_list)  if true.
undelayed_list_with_at_most_two_elements(tl:L)    if list_with_zero_or_one_element(L).


fun bind_off(+,+,-).
bind_off(BSlash,List,Rest) if
  when( (BSlash=(e_list;ne_list),
         List=(e_list;ne_list))
      , undelayed_bind_off(BSlash,List,Rest)
      ).
      
undelayed_bind_off([],List,List) if true.
undelayed_bind_off(hd:Element,[Element|Rest ],Rest       ) if true.
undelayed_bind_off(hd:Element,[First|Rest1],[First|Rest2]) if
  bind_off(hd:Element,Rest1,Rest2).


% Hey, Negation!

%% Type negation - delay until type T and then die.
not(Type) macro not_type(a_ Type).
fun not_type(+,-).
( not_type((a_ Type),FS) if
      when(FS=Type,
           prolog(fail)) ) :-
        type(Type).




non_move_synsem :=
  (nonloc:inher:(slash:[],
                 rel:[])).

fun list_of_non_move_arguments(-).
list_of_non_move_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_move_arguments(L) ).

undelayed_list_of_non_move_arguments([]) if true.
undelayed_list_of_non_move_arguments([@arg(@non_move_synsem)|T]) if
   list_of_non_move_arguments(T).



fun list_of_spec_none(-).
list_of_spec_none(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_spec_none(L) ).

undelayed_list_of_spec_none([]) if true.
undelayed_list_of_spec_none([@arg(loc:cat:head:spec:none)|T]) if
   list_of_spec_none(T).


% in sysnsem grammars this traverses the list and does not do anything
% in spirit grammars all arguments have to be raised:minus
fun list_of_non_raised_arguments(-).

% list_of_non_raised_arguments(L) if !. % for debugging only, this disables the constraint

list_of_non_raised_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_raised_arguments(L) ).

undelayed_list_of_non_raised_arguments([]) if true.
undelayed_list_of_non_raised_arguments([@non_raised|T]) if        % raised:minus
   list_of_non_raised_arguments(T).




non_complex_forming_synsem :=
  (@cluster_minus_synsem,
   loc:cat:subcat:list_of_spirits,
   lex:minus).

fun list_of_non_complex_forming_synsems(-).
list_of_non_complex_forming_synsems(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_complex_forming_synsems(L) ).

undelayed_list_of_non_complex_forming_synsems([]) if true.

% Mit Spirits muß man die folgenden beiden Fälle unterscheiden:
% Das Element ist noch nicht realisiert, muß also non_complex_formin sein.
undelayed_list_of_non_complex_forming_synsems([(realized:minus,
                                                  arg: @non_complex_forming_synsem)|T]) if
   list_of_non_complex_forming_synsems(T).

% Des Element ist bereits realisiert -> Es ist uns egal, wie es aussieht.
undelayed_list_of_non_complex_forming_synsems([realized:plus|T]) if
   list_of_non_complex_forming_synsems(T).




% depicitives
fun check_identical_append(+,+,+,-).
check_identical_append(DA,Subj,Subcat,D) if
  when((DA = (e_list;ne_list),
        Subj = (e_list;ne_list),
        Subcat = (e_list;ne_list)),
        
       ( % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.

           (DA = [A1],
            Subj = [Subj1],
            A1 =@ Subj1) ->
           append(Subj,Subcat,D)
       ;

         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           (Subj=[],
            DA  =ne_list) -> Subcat = D
       ;
           
           append(DA,Subj,X),
           append(X,Subcat,D)
       )).


