% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%       $RCSfile: core-macros.pl,v $
%%      $Revision: 298 $
%%          $Date: 2008-03-11 20:44:55 +0100 (Di, 11 Mär 2008) $
%%         Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%% $LastChangedBy: stefan $
%%        Purpose: Parts of grammar that are identical for Chinese, German, and Maltese
%%       Language: Trale
%          System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile 'if'/2.
:- multifile 'fun'/1.



relational_le :=
 (synsem:loc:cont:key:Rel,
  rels:hd:Rel).

% things that do not contribute relations.
non_relational_le :=
 (@non_hcons_le,
  @non_idiomatic_le,   % They also should not subtract relations, should they?
  rels:[]).

% one would think that things that do not contribute anything,
% do not have anything under KEY, but is not as simple as this,
% since traces do not contribute locally, but have a KEY that is shared
% with the KEY of the filler.
non_relational_no_key_le :=
 (@non_relational_le,
  synsem:loc:cont:key:none).


arg0_le :=
 (synsem:loc:cont:ind:Ind,
  rels:hd:arg0:Ind).

% In principle all arg0_le should have an appropriately specified key,
% but there are lexical rules that share the HEAD with their daughter and introduce
% an new relation. In this case we get a clash between the new KEY and the original
% main semantic contribution of the daughter (example inflection for finite verbs in German
% and Maltese and Persian). So LRs may be arg0_le and all elements from the listicon
% (that is underived stored lexical items) are relational_arg0_le.
relational_arg0_le :=
 (@relational_le,
  @arg0_le).

ltop_lbl_le :=
 (synsem:loc:cont:ltop:Handle,
  rels:hd:lbl:Handle).

non_hcons_le :=
 h_cons:[].

% subtract_rels contains a list of literal readings that are
% subtracted from the RELS list during composition.
non_idiomatic_le :=
  subtract_rels:[].

non_relativizer_le :=
 synsem:nonloc:to_bind:slash:[].

non_clld_bind_le :=
 synsem:nonloc:to_bind:clld:[].

non_rel_le     :=
  synsem:nonloc:inher:rel:[].

non_slashed_le :=
  synsem:nonloc:inher:slash:[].

non_clld_le :=
  synsem:nonloc:inher:clld:[].

overt_le := 
 %stem_or_word
 (@non_slashed_le,
  @non_clld_bind_le,
  synsem:trace:minus).

% do we need this?
overt_word :=
 (word,
  @overt_le).

stem *> @overt_le.

non_overt_le :=
 (@non_rel_le,
  @non_clld_le,
  @non_clld_bind_le,
  @non_idiomatic_le,
  phon:[]).

non_overt_word :=
 (simple_word,
  @non_overt_le,
  @non_relativizer_le).

 
trace :=
 (@non_overt_word,
  @non_relational_le,
  synsem:trace:extraction_or_head_movement).

e_trace *>
  (@trace,
   synsem:(loc:Loc,
           nonloc:inher:slash:[Loc],
           trace:extraction)).


sc_saturated :=
  synsem:loc:cat:subcat:[]. %In the German grammar: list_of_spirits.  But since we are in the lexicon we may be more specific.

spr_saturated :=
  synsem:loc:cat:spr:[].

saturated :=
 (@spr_saturated,
  @sc_saturated).

/*
% uninflected determiners
det(Pred) :=
 (word,
  synsem:loc:cat:(head:det,
                  spr:[],
                  subcat:[]),
  rels:hd:pred:Pred).

*/

% determiners and pronouns introduce quantifier
% This includes the clitization lexical rules.
% This is the reason why H_CONS is open. Because multiple clitzation is possible,
% the length of this list is not constrined in this type.
quant_intro_le :=
 (%arg0_relational_word,,
  @non_idiomatic_le,
  synsem:loc:cont:(gtop:GTop,
                   ltop:CL_LTop), % This differs from standard MRS, where the LTOP of a quantifier is
                                  % not instantiated. It is needed for accessing the HANDLE of the nominal
                                  % material for instance for the BA and BEI constructions.
                                  % The subject marker says that the noun is agentive.

  rels:hd:(quant_rel,
           lbl:QHandle,
           rstr:Restr),
  h_cons:(hd:(qeq,
              harg:GTop,
              larg:QHandle),
          tl:hd:(qeq,
                 harg:Restr,
                 larg:CL_LTop))).



% Determiners, classifiers and subjects may not be extracted. 
spr:ne_list *> spr:[@arg(%loc:cat:spr:[],             % this is not necessary, but avoids residues
                         % Hm, removes only one of ten residues
                         nonloc:inher:slash:[])].


determiner_or_possp_le :=
 (@quant_intro_le,
  %@relational_arg0_le,                 because of possessives this is not relational_arg0_le
  @non_relativizer_le,
  @non_clld_le,
  @saturated,
  @non_slashed_le,
  synsem:loc:(cat:head:(det,
                        spec:loc:cont:gtop:GTop),
              cont:gtop:GTop)). % This differs from standard MRS, where the LTOP of a quantifier is
                                       % not instantiated. See the Chinese grammar.



% The determiner scopes over the noun.
% determiners and posessive pronouns
%determiner_or_possp_le *>
determiner_le *>
 (@determiner_or_possp_le,
  @relational_arg0_le,
  synsem:loc:(cat:head:spec:loc:cont:(ind:Ind,
                                      gtop:GTop,
                                      ltop:Noun_LTop),
              cont:(gtop:GTop,
                    ltop:Noun_LTop)), % This differs from standard MRS, where the LTOP of a quantifier is
                                      % not instantiated. See the Chinese grammar.
   rels:hd:arg0:Ind,
   h_cons:tl:tl:e_list).

% The second relation is adjectival. Compare the treatment of possessives in the German grammar.
two_place_determiner_le :=
 (determiner_le,
  synsem:loc:(cat:head:spec:loc:cont:ltop:NLtop),
  rels:[arg0:Ind,(arg0:event,
                  lbl:NLtop,
                  arg1:Ind)]).

determiner_word *>
 (%simple_word,
  %determiner_le,
  @non_rel_le).

overt_determiner_word :=
 (determiner_word,
  @overt_le). 

det(Quant-quant_rel) :=
 (@overt_determiner_word,
  rels:[Quant]).

overt_two_place_determiner_word :=
  (@overt_determiner_word,
   @two_place_determiner_le).

% This macro is used for demonstratives that introduce an additional relation
% this vs. that in English, dak vs. dan in Maltese (distal/proximal).
% The ERG does not make this distinction but uses different quantifiers (that_q_dem_rel/this_q_dem_rel),
% but I think it is nice to have the distinction explicitely in the semantic representation.
det(Quant-quant_rel,Pred) :=
 (@overt_two_place_determiner_word,
  rels:[Quant,pred:Pred]).

% clitics and personal pronouns and relative and q-pronouns
pronoun_le :=
 (@saturated,
  @overt_le,
  %@non_relational_no_key_le, This holds for personal pronouns and clitics only.
  synsem:loc:cont:pron).

pronoun_word :=
 (simple_word,
  @pronoun_le).



ref_pronoun_le :=
 (@pronoun_le,
  synsem:loc:cont:ind:ref).

ref_pronoun_word :=
 (@ref_pronoun_le,
  @pronoun_word).

% referential pronouns and expletives
nominal_pronoun_le :=
  (@pronoun_le,
   @nominal_le,
   @comp_nominal_le).

% referential pronouns and expletives
nominal_pronoun_word :=
  (@pronoun_word,
   @nominal_pronoun_le).

nominal_ref_pronoun_le :=
  (@nominal_pronoun_le,
   @ref_pronoun_le).


nominal_non_rel_pronoun_le :=
 (@nominal_pronoun_le,
  @non_rel_le).

nominal_ref_non_rel_pronoun_le :=
 (@nominal_ref_pronoun_le,
  @nominal_non_rel_pronoun_le).

% Maltese clitics and personal pronouns
nominal_ref_non_rel_non_relational_pronoun_le :=
 (@nominal_ref_non_rel_pronoun_le,
  @non_relational_no_key_le).

% possesives have three elements
nominal_ref_pronoun_word :=
  (@nominal_ref_pronoun_le,
   @nominal_pronoun_word).

% personal pronouns and q-pronouns
nominal_ref_non_rel_pronoun_word :=
  (@nominal_non_rel_pronoun_le,
   @nominal_ref_pronoun_word).

pers_pronoun :=
  (@nominal_ref_non_rel_pronoun_word,
   @non_relational_no_key_le,
   @non_clld_le,
   @definite_le).                     % if syntactically relevant.

pers_pronoun(Per,Num,Sort) :=
 (@pers_pronoun,
  synsem:loc:cont:ind:(per:Per,
                       num:Num,
                       sort:Sort)).

pers_pronoun(Per,Num,Gen,Sort) :=
 (@pers_pronoun(Per,Num,Sort),
  synsem:loc:cont:ind:gen:Gen).


q_pron :=
  (@nominal_ref_non_rel_pronoun_word,
   @quant_intro_le,
   @non_clld_le,
%   @definite_le,                     % if syntactically relevant.
   synsem:loc:cont:ind:Ind,
   rels:[
         % the question quantifier
         (which_q,
          arg0:Ind),
         
         % thing_rel or person_rel
         (lbl:OutScoped,
          arg0:Ind)
        ],
   h_cons:tl:[larg:OutScoped]).

q_pron(Pred,Sort) :=
 (@q_pron,
  synsem:loc:cont:ind:sort:Sort,
  rels:tl:hd:pred:Pred).

% Currently there are only nouns that are arguments and verbal nouns in Persian.
nominal_le :=
 (@non_relativizer_le,
  @non_idiomatic_le,
  synsem:loc:cat:head:noun).

comp_nominal_le :=
 (@nominal_le,
  synsem:loc:cat:head:comp_noun).

% Chinese localizer
overt_nominal_word :=
 (@overt_word,
  @comp_nominal_le,
  simple_word).
  
noun_le *>
 (@relational_arg0_le,
  @nominal_le,
  @simple_le).  % identifies the GTOP with the GTOP of the SPR and the SUBCATs
                % important for relational nouns like `son'. St. Mü. 27.05.2007

comp_noun_word *>
 (%noun_word,
  @comp_nominal_le). % currently words are always comp nouns. 

% nouns like `woman' or `plan' that is nouns with or without argument
% and proper names
non_pronoun_noun_le :=
 (noun_le,
  @non_rel_le,
  @non_clld_le,
  @unmarked,
  synsem:loc:cont:npro).

% nouns with a specifier or verbal nouns that are used as preverbs in Persian complex predicates.
noun_or_verbal_noun_le :=
 (@non_pronoun_noun_le,
  @ltop_lbl_le,    % moved to non_pronoun_noun_le from simple_noun_le, since it also holds for (derived)
                   % nouns that have something in SUBCAT.
                   % moved it back, since proper names are also non_pronominal.
  @non_hcons_le,
  synsem:loc:cont:ind:per:third).

% nouns that take a determiner/classifier.
% nouns with or without an argument.
% This is also true for process nouns (Persian). They take a determiner, but nevertheless have a Designated Argument feature.
spr_noun_le :=
 (@noun_or_verbal_noun_le,
  synsem:loc:cat:(head:noun,
                  spr:[(@argument,
                        @arg((loc:cat:(spr:[],
                                       subcat:[]),
                                  % cont:ind:Ind\), Do we need this for Chinese? It is wrong for German
                                  % breaks possessives.
                              nonloc:inher:slash:[])))])).
%              cont:ind:(%Ind

simple_noun_le :=
  (@spr_noun_le,
   @sc_saturated,
   @comp_nominal_le). % currently there are no modifying nouns

% mother, father, ...
% used in German
relational_noun_le :=
 (@spr_noun_le,
  @comp_nominal_le,
  synsem:loc:cat:subcat:[@optional_np(gen,Ind)],
  rels:hd:arg1:Ind).

empty :=
 (@non_overt_word,
  @non_slashed_le,
  synsem:trace:minus).

non_overt_noun_word :=
  (@empty,
   @simple_noun_word, % language specific. Chinese selects a classifier, German a determiner
   rels:[pron_rel]).

overt_noun_word :=
 (@overt_word,
  noun_word).

  
proper_noun_word *>
( @overt_noun_word,
  @non_pronoun_noun_le,
  @quant_intro_le,
  @saturated,
  synsem:loc:cont:(ind:per:third,
                   ltop:NamedLBL), % This is non-standard, see type for quantifiers above.
  rels:[(proper_q,
         arg0:Index),
        (named_rel,
         lbl:NamedLBL,
         arg0:Index) ],
  h_cons:tl:tl:e_list).

proper_noun(Pred,Sort) :=
 (proper_noun_word,
  synsem:loc:cont:ind:sort:Sort,
  rels:tl:hd:name:Pred).


xp_sign :=
 synsem:loc: @xp_local.

xp :=
  (@arg(loc: @xp_local),
   @cluster_minus_argument).

xp(Ind) :=
  (@xp,
   @arg(loc:cont:ind:Ind)).

np :=
  (@xp,
   @arg(loc:cat:head:noun)).

% Eine NP mit strukturellem Kasus
np_str :=
  (%@np,
   @arg(loc: @xp_local),
   @arg(loc:cat:head:noun),
   @arg(loc:cat:head:case:case_type:str)).

n_lex :=
   @arg(loc:cat:head:(noun,
                      case:case_type:lex)).

np_lex :=
  (@np,
   @n_lex).

argument_xp :=
 (@argument,
  @xp).

argument_np :=
  (@argument_xp,
   @np,
   @arg(loc:cat:head:comp_noun)).

np_ref :=
  (@argument_np,
   @arg(loc:cont:ind:ref)).

% das Subjekt von Infinitiven und vom Passiv
pro_np_ref :=
 (@np_ref,
  @non_raised,
  @arg((loc:cat:subcat:[],       % ansonsten hängt ein Constraint rum
        lex:minus))).


np(Ind) :=
  (@np_ref,
   @arg(loc:cont:ind:Ind)).


np_str(Ind) :=
  (@np_str,
   @np(Ind)).

% used in valence frames
np_str(Ind,Sort) :=
  (@np_str(Ind),
   @arg(loc:cont:ind:sort:Sort)).


pro_np(Ind) :=
  (@pro_np_ref,
   @np_str(Ind)).


lex(Case) :=
 (case_type:lex,
  morph_case:Case).

np_is(Ind,Sort) :=
 (@np(Ind),
  @arg(loc:cont:ind:sort:Sort)).

np(Case,Ind) :=
  (@np(Ind),
   @arg(loc:cat:head:case: @lex(Case))).

% for optional arguments of nouns. The REALIZED value is not '-',
% so such relational nouns can be treated as saturated.
optional_np(Case,Ind) :=
  (@np,
   @arg(loc:(cat:head:case: @lex(Case),
             cont:ind:Ind))).

np(Case,Ind,Sort) :=
 (@np_is(Ind,Sort),
  @arg(loc:cat:head:case: @lex(Case))).

np_cpg(Case, Person, Gender) :=
 @np(Case,(per:Person,
           gen:Gender)).

np_gn(Gender,Number) :=
 @np((gen:Gender,
      num:Number)).

% this covers both CPs and V2 clauses in German
% The part of speech has to be specified, since we have to ensure
% that we have a finite clause. If we would refer to events only,
% we would allow for infinitval verbal projections.
s :=
  (@argument_xp,
   @arg(loc:(cat:(head:(comp
                      ;(verb,
                        vform:fin)),
                  subcat:list_of_non_raised_arguments), % necessary for Persian, since arguments of finite verbs may be raised (progressive)
             cont:ind:event))).

n_bar :=
 (loc:cat:(head:noun,
           spr:tl:e_list, %[_],
           subcat:[])).

n_bar(Ind) :=
 (@n_bar,
 loc:cont:ind:Ind).

np_local :=
 (@xp_local,
  cat:head:noun).

np_local(Ind) :=
 (@np_local,
  cont:ind:Ind).

np_synsem :=
 (loc: @np_local).

no_noun :=
  @arg(loc:cat:head: @not(noun)).


pp :=
  (@argument_xp,
   @arg(loc:cat:head:prep)).

pp(Ind) :=
  (@pp,
   @arg(loc:cont:ind:Ind)).

pp_pform(PForm) :=
  (@pp,
   @arg(loc:cat:head:pform:PForm)).

pp(PForm,Case) :=
  (@pp_pform(PForm),
   @arg(loc:cat:head:case:morph_case:Case)).


% adjs like verbs have an ARG-ST. The languages differ in the mapping from ARG-ST
% to SPR and SUBCAT
adj_le *>
 (@simple_le,
  @non_rel_le,
  @non_relativizer_le,
  @non_clld_le,
  @ltop_lbl_le,
  @non_idiomatic_le,
  %@relational_arg0_le, not for scopal adjectives
  % scopal adjectives have the modification semantics, i.e. their index is
  % identified with the modified noun in the lexicon already.
  % This means that the index has to be of type ref, not of type event.
  % See the event specification for intersective adjectives below.  20.03.2007
  synsem:loc:cat:head:adj,
  rels:[arg0:event]).


% Chinese, Persian
% currently there are no scopal adjectives in these grammars.
adjective_word :=
 (%simple_word,
  @intersective_adj_le,
  @overt_word,
  @relational_arg0_le,
  @non_hcons_le,
  synsem:loc:cat:(head:prd_adj,
                  arg_st:[@np_str(Ind)]),
  rels:[arg1:Ind]).

% Chinese, Persian
adj(Pred) :=
 (@adjective_word,
  rels:[pred:Pred]).


% is this used? Remainder of Maltese?
adj(Pred,Gen,Num) :=
 (@adj(Pred),
  synsem:loc:cat:arg_st:hd: @np_gn(Gen,Num)).

adj(Pred,Num) :=
 @adj(Pred,genus,Num).



% Nicht alle Adjektive haben ein Subjekt (mir ist warm)
intersective_adj_le :=
 (adj_le,
  @relational_arg0_le,
  @non_hcons_le,
  synsem:loc:cat:(head:scopal:minus,
                  arg_st: append(_,[ @np_str(Ind) ])),                     % I do not understand why this does not work: last(@np_str(Ind))), Trale Bug?
  rels:[arg1:Ind]).



% klug
simple_adj_le :=
 (@intersective_adj_le,
  synsem:loc:cat:arg_st:tl:e_list).

% German and Maltese
simple_adj_stem :=
 (@simple_adj_le,
  underived_stem).

adj_stem(Relation) :=
 (@simple_adj_stem,
  rels:[pred:Relation]).


% German and Maltese
% These do not appear predicatively.
scopal_adj_stem :=
 (adj_stem,
  @sc_saturated,
  synsem:loc:cat:arg_st:[@np_str],
  @scopal_modifier).

% mutmaßlich
scopal_adj_stem(Relation) :=
 (@scopal_adj_stem,
  rels:[pred:Relation]).


prep_word :=
(simple_word,
 @simple_le,
 @overt_word,
 @spr_saturated,
 @non_rel_le,
 @non_relativizer_le,
 @non_clld_le,
 @non_hcons_le,
 @non_idiomatic_le,
 synsem:loc:(cat:(head:(prep,
                        initial: @prep_initial),        % Language specific?
                  subcat:[ (@argument_np,
                            @arg(nonloc:inher:slash:[])) ] ))).


comp_prep_word *>
 (@prep_word,
  @non_relational_le,
  synsem:loc:(cat:subcat:[@arg(loc:cont:Cont)],
              cont:Cont)).


comp_prep(PForm) :=
 (comp_prep_word,
  synsem:loc:cat:head:pform:PForm).

mod_prep_word :=
 (@prep_word,
  @intersective_modifier_arg1_le,
     synsem:loc:cat:head:mod_prep).        % this should follow by type inference, but somehow it does not. 21.05.2007


% maybe gtop sharing should be something more general
% for everything that selects other elements.
mod_prep_cannonical_word :=
 (@mod_prep_word,
  synsem:loc:(cat:subcat:[@arg(loc:cont:(ind:Ind2,
                                         gtop:GTop))],
              cont:gtop:GTop),
  rels:[arg2:Ind2]).


% vp_mod_prep_word (English, Chinese) is a special case of v_mod_prep_word
v_mod_prep_word :=
 (@mod_prep_cannonical_word,
  @intersective_v_modifier_word).


% Persian
v_mod_prep(Relation) :=
 (@v_mod_prep_word,
  rels:[pred:Relation]).


modifier :=
 (@non_idiomatic_le,
  synsem:loc:(cat:head:mod:loc:cont:gtop:GTop,
              cont:gtop:GTop)).

modifier_le :=
 (@ltop_lbl_le,
  %@relational_arg0_le,  This wrong for adjectives. Their ARG0 is an event, while the IND is the nominal INDEX.
  @modifier).

% relativizer_word inherits from this.
% relative clauses are intersective modifiers as far as nouns
% and the relative clause are concered (LTOPs are identified),
% but they introduce a relation and scopal constraints,
% since they close of a scoping domain.
intersective_modifier_ltop :=
 (@modifier,
  synsem:loc:cat:head:scopal:minus).

intersective_modifier_ltop_no_hcons :=
 (@intersective_modifier_ltop,
  @non_hcons_le).

intersective_modifier_ltop_le :=
 (@modifier_le,
  @intersective_modifier_ltop).

intersective_modifier_le :=
 (@intersective_modifier_ltop_le,
  @intersective_modifier_ltop_no_hcons).
     
% the local top of the whole construction is identical
% to the local tops of the parts. It is projected from cont:ltop.
% for intersective modifiers the labels are identified.
% This happens since the local tops are identified with the respective
% labels.
% Adjectives introduce an event (ARG0), so arg1 is the Index argument
% that is shared with the noun.
intersective_modifier_arg1 :=
 (@intersective_modifier_ltop,
  synsem:loc:cat:head:mod:loc:cont:ind:Index,  
  rels:hd:arg1:Index).

intersective_modifier_arg1_le :=
 (@intersective_modifier_arg1,
  @intersective_modifier_le,
  @intersective_modifier_ltop_le).


% Scopal modifiers add a scope constraint that says:
% the argument (Handle2) has scope over the local top (LTop) of
% the modified head. The new local top is identical to the label
% of the scopal relation.
scopal_modifier :=
 (@modifier,
  synsem:loc:(cat:head:(mod:loc:cont:ltop:LTop,
                        scopal:plus),
              cont:ltop:Label),
  rels:hd:(lbl:Label,
           arg1:Handle2),
  h_cons:[(qeq,
           harg:Handle2,
           larg:LTop)]).

scopal_modifier_le :=
 (@scopal_modifier,
  @modifier_le).

scopal_modifier_word :=
  (simple_word,
   @scopal_modifier_le).


% German differs here in the type hirarchy below head
% v_modifier_le :=
%  (@modifier_le,
%   synsem:loc:cat:head:mod:loc:cat:head:verb).

v_modifier_word :=
 (@overt_word,
  @v_modifier_le).


intersective_v_modifier  :=
 (@intersective_modifier_arg1,
  @v_modifier).

intersective_v_modifier_le  :=
 (@intersective_v_modifier,
  @intersective_modifier_arg1_le,
  @v_modifier_le).

intersective_v_modifier_word  :=
 (@intersective_v_modifier_le,
  @v_modifier_word).

scopal_v_modifier_word        :=
 (@scopal_modifier_word,
  @v_modifier_word).


% This used to contain an identification of the
% n_bar Index and the Index of the n_modifier,
% however the index of an adjective and especially
% the index of an adjectival participle should be an event.
% Therefore we cannot do a structure sharing here. Instead
% the Ind of the n_bar is shared with an argument of the respective
% relation.
n_modifier :=
 (@modifier,
  synsem:loc:cat:head:mod: @n_bar).

n_modifier_le :=
 (@modifier_le,
  @n_modifier).

% relative clauses, attributive adjectives
intersective_n_modifier  :=
 (@intersective_modifier_ltop,
  @n_modifier).

%n_mod_prep_word
intersective_n_modifier_le  :=
 (@intersective_modifier_arg1_le,
  @n_modifier_le).

% both simple adverbs and adverbs that are derived from adjectives
adverb_word :=
 (@v_modifier_word,
%  simple_word,
  @saturated,
  @non_clld_le,
  synsem:loc:cat:head:adv).

non_rel_adverb_word :=
 (@adverb_word,
  @non_rel_le).


ad_adj_word :=
 (@overt_word,
  simple_word,
  @non_relativizer_le,
  @non_rel_le,
  @non_clld_le,
  @relational_arg0_le,
  @intersective_modifier_arg1_le,
  synsem:loc:cat:(head:(adv,
                        mod:loc:(cat:head:adj,
                                 cont:ind:Ind1)
                                %pre_modifier:plus both orders are possible
                       ),
                  spr:[],
                  subcat:[]),
  rels:hd:arg1:Ind1).

% 很 (very)
mod_ad_adj(Pred) :=
 (@ad_adj_word,
  rels:[pred:Pred]).


fun gtop_list(-,+).
gtop_list(List,GTop) if
  when( List=(e_list;ne_list)
      , undelayed_gtop_list(List,GTop)
      ).
      
undelayed_gtop_list([],_) if true.
undelayed_gtop_list([@arg(loc:cont:gtop:GTop)|Rest],GTop) if
  gtop_list(Rest,GTop).



simple_le := 
  synsem:loc:(cat:(spr:gtop_list(GTop),
                   subcat:gtop_list(GTop)),
              cont:gtop:GTop).

% listed verbs have an empty specifier list.
% For configurational languages the Subject is mapped to SPR
% by a lexical rule.
verb_le *>
 (@overt_le,
  @simple_le,
  @non_rel_le,
  @non_relativizer_le,
  @non_clld_le,
%  @spr_saturated,
%  @non_hcons_le,
  @unmarked,
  synsem:loc:(cat:head:verb,
              cont:ind:event)).

event_verb_le :=
 (verb_le,
  @relational_arg0_le,
  @ltop_lbl_le).


% base verbs
verb(Pred) :=
 (@lexical_event_verb_type,              % depends on the language, whether this is event_verb_stem or event_verb_word
  @non_hcons_le,                         % This is not true for all verbs, but currently used for Maltese and Chinese.
  @non_idiomatic_le,
  synsem:loc:cat:head:aux:minus,
  rels:[pred:Pred]).


% Used in German and Persian
%
% Das designierte Argument Nicht-Unakkusativischer Verben ist das letzte
% Element in der SUBCAT-Liste. Das kann eintweder eine NP mit strukturellem
% Kasus oder ein Satzargument sein.
%
% German verbs + Persian verbal nouns
nerg_pred :=
  (synsem:loc:cat:(head:da:[last(ArgSt)],
                   arg_st:ArgSt)).

% Unnacusative verbs in German, inchoative light verbs in Persian
unacc_verb :=
  synsem:loc:cat:head:da:[].



mono_val_verb(Pred,Sort1) :=
 (@verb(Pred),
  synsem:loc:cat:arg_st:[@np_str(Arg1,Sort1)],
  rels:[arg1:Arg1]).

bi_val_verb(Pred,Sort1,Sort2) :=
 (@verb(Pred),
%  @bi_val_verb, % constraints on this type are only imposed in Maltese
  synsem:loc:cat:arg_st:[@np_str(Arg2,Sort2),
                         @np_str(Arg1,Sort1)],
  rels:[(arg1:Arg1,
         arg2:Arg2)] ).


% 
np_np_verb(Case,Pred,Sort1,Sort2) :=
(@verb(Pred),
  synsem:loc:cat:arg_st:[@np(Case,Arg2,Sort2),
                         @np_str(Arg1,Sort1)],
  rels:[(arg1:Arg1,
         arg2:Arg2)] ).


/*
removed this, since there is a macro with the same name
for Persian
np_np_pp_verb(Pred,PForm-pform,Sort1,Sort2,Sort3) :=
 (@verb(Pred),
  synsem:loc:cat:arg_st: [(@argument_xp,
                           @arg(loc:(cat:head:(prep,
                                               pform:PForm),
                                    cont:ind:(Arg3,
                                              sort:Sort3)))),
                          @np_str(Arg2,Sort2),
                          @np_str(Arg1,Sort1)  ],
  rels:[(arg1:Arg1,
         arg2:Arg2,
         arg3:Arg3)] ).

*/

tri_val_verb(Case,Pred,Sort1,Sort2,Sort3) :=
 (@verb(Pred),
%  @tri_val_verb, % constraints on this type are only imposed in Maltese
  synsem:loc:cat:arg_st: [@np(Case,Arg3,Sort3),
                          @np_str(Arg2,Sort2),
                          @np_str(Arg1,Sort1)],
  rels:[(arg1:Arg1,
         arg2:Arg2,
         arg3:Arg3)]).



tri_val_verb(Pred,Sort1,Sort2,Sort3) :=
 @tri_val_verb(dat,Pred,Sort1,Sort2,Sort3).






% Das sind die Beschränkungen, die nötig sind, damit
% keine eingebetteten Köpfe von komplexbildenden Prädikate angezogen werden.
%
% * weil er das Buch lesen [können wird]
%
% Komplexbildende Prädikate müssen immer direkt mit ihrem
% eingebetteten Kopf verbunden werden:
%
% weil er das Buch [[lesen können] wird]



% optional kohärente Verben ziehen alle Elemente auf SUBCAT an.
% This does not hold for Persian, Dutch, and German dialects like Thuringian/Franconian.
% The constraints for Standard German can be found in the respective german files.
% 
% optionally_coherent_le :=
%   synsem:loc:cat:arg_st:[(@argument,
%                           @non_dsl_argument)|list_of_non_complex_forming_arguments].

optionally_coherent_le *>
  synsem:loc:cat:arg_st:hd:(@argument,
                            @non_dsl_argument).



% alle Anhebungsverben, also auch die, die optional kohärent konstruieren,
% Phasenverben (beginnen), sehen, lassn und die, die obligatorisch kohärent konstruieren,
% Modalverben, Futur-Hilfsverb, Perfekt-Hilfsverb

raising_verb_le :=
 (verb_le,                                        %% not event_verb_le since Persian LV that combine with verbal nouns
                                                  %% do not contribute a relation.
  optionally_coherent_le,
% Since Persian light verbs can be passivized, this restriction is introduced
% at the subtypes that are relevant for German only.
%  synsem:loc:cat:head:da:[],                      %% DA-Wert schließt Passivierung von Hilfsverben aus.
  @non_idiomatic_le).

% This allows quantifiers to scope between the raising verb and the embedded predicate.
% A unicorn seems to be approaching.
% For verbs (German, Persian) and preverbs (Persian)
scopal_event_embedding_le :=
 (synsem:loc:cat:subcat:hd:arg:loc:cont:ltop:SLTop,
  rels:[arg3:Handle],
  h_cons:[(qeq,
           harg:Handle,
           larg:SLTop)]).

scopal_event_embedding_verb :=
 (@scopal_event_embedding_le,
  @event_verb_le).

% This does not allow quantifiers to scope between.
nonscopal_event_embedding_verb :=
 (@event_verb_le,
  @non_hcons_le,
  synsem:loc:cat:subcat:hd:arg:loc:cont:ltop:SLTop,
  rels:[arg3:SLTop]).


% These are the raising verbs that introduce a relation and that allow quantifiers to scope
% between this relation and the relation introduced by the embeeded predicate.
% All German raising verbs, but not Persian LV that combine with preverbal nouns.
scopal_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:head:da:[],                      %% DA value excludes passivization of auxiliary verbs.
  @scopal_event_embedding_verb).

% German verb stems, Maltese verb roots, and the empty copula, Persian LVs
subj_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:arg_st:[arg:loc:cat:(head:subj:(Subj,
                                                 list_of_raised_arguments),
                                      subcat:Subcat)
                        |raise(append(Subcat,Subj))]).

scopal_subj_raising_verb_le :=
 (@scopal_raising_verb_le,
  @subj_raising_verb_le).

% Persian auxiliaries
nonscopal_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:head:da:[],                      %% DA value excludes passivization of auxiliary verbs.
  @nonscopal_event_embedding_verb).

nonscopal_subj_raising_verb_le :=
 (@nonscopal_raising_verb_le,
  @subj_raising_verb_le).

copula_verb_le :=
  (@scopal_subj_raising_verb_le,
   synsem:loc:cat:(head:da:[],
                   subcat:hd: @arg(loc:cat:head:prd:plus)),
   rels:[pred: (a_ support_rel)]).

