% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: core-syntax-spirits.pl,v $
%%  $Revision: 298 $
%%      $Date: 2008-03-11 20:44:55 +0100 (Di, 11 Mär 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.


% Diese Beschränkung schließt die Kombination von teilweise gesättigten
% VPen mit optional kohärent konstruierenden Verben aus.
% Da Determinatoren über SPR selegiert werden, sind Fälle wie
% "vom Buch", in denen eine Präposition mit einer N' kombiniert wird,
% nicht betroffen.
head_argument_phrase *> non_head_dtrs:hd:synsem:loc:cat:subcat:list_of_spirits.

%% Kopf-Adjunkt-Strukturen


head_adjunct_phrase *>
   (head_dtr:synsem:HeadSynsem,
    non_head_dtrs:[synsem:(loc:cat:(head:mod:HeadSynsem,
                                    subcat:list_of_spirits),
                           lex:minus)]).


%% Spezifikatorprinzip

(headed_phrase,
 non_head_dtrs:[synsem:loc:cat:head:spec:synsem]) *>
   (head_dtr:synsem:Head,
    non_head_dtrs:[synsem:loc:cat:head:spec:Head]).


head_non_specifier_struc *> 
   (synsem:loc:cat:spr:Spr,
    head_dtr:synsem:loc:cat:spr:Spr).



% Determiners, classifiers and subjects may not be extracted. 
spr:ne_list *> spr:[(%loc:cat:spr:[],             % this is not necessary, but avoids residues
                     % Hm, removes only one of ten residues
                     arg:nonloc:inher:slash:[])].


spr:ne_list *> spr:hd: @non_raised.

head_specifier_phrase *> 
   (synsem:loc:cat:spr:[],                     % we do not keep the element around
    head_dtr:synsem:loc:cat:(spr:[(@non_raised,     % This is needed here since languages like Chinese and Maltese allow for direct
                                                    % predication without copula. Alternatively one could integrate this in the root nodes.
                                                    % This would make it necessary to project the SPR as a spirit.
                                   arg:Spr)],
                             subcat:list_of_spirits),
    non_head_dtrs:[synsem:Spr]).





% Adjunkte sind Extraktionsinseln
(headed_phrase,
 non_head_dtrs:hd:synsem:trace:extraction) *>
      head_dtr:synsem:loc:cat:head:mod:none.



% The specifier of the head daughter is underspecified.
% This allows binding off of the nonlocal dependency before
% the subject or after the subject in Maltese.
head_filler_phrase *>
   (head_dtr:synsem:(loc:cat:(head:verb,
                              subcat:list_of_spirits),
                     nonloc:(inher:slash:hd:Slash,          % Strictly speaking this is not necessary,
                                                            % but for Persian this avoids spurious ambiguities,
                                                            % since it ensures that the order of extraction corresponds
                                                            % to the order of the fillers.
                             to_bind:slash:[Slash])),
    non_head_dtrs:[(%phon:ne_list,
                    % to do: there has to be a restriction on the filler
                    %        that it is definite.
                    synsem:(loc:Slash,
                            nonloc:inher:(rel:[], % "In der hat er geschlafen." hätte sonst zwei Strukturen.
                                          slash:[])))]).



fun list_of_spirits(-).
list_of_spirits(List) if
       when( List=(e_list;ne_list)
           , undelayed_list_of_spirits(List)
           ).

undelayed_list_of_spirits([]) if true.
undelayed_list_of_spirits([realized:plus|Rest]) if list_of_spirits(Rest).





fun assign_case_verb(-).

%assign_case_verb(_) if !,prolog((write(yes-yes),nl)),true. % for debugging we can disable case assignment here.

% Da Spuren auch Kasus zuweisen, muß man warten, bis die SUBCAT-Liste überhaupt instantiiert
% ist. Ansonsten, wäre klar, daß es immer ein Argument gibt und man könnte gleich mit
% assign_case_verb2 beginnen.
assign_case_verb(List) if
       when( List=(e_list;ne_list)
           , assign_case_verb2(List)
           ).



assign_case_verb2([(H,
                    raised:R)|T]) if
       when( (R=(plus;minus),
              T=(e_list;ne_list))
           , undelayed_assign_case_verb([H|T])
           ).

% Wenn die Argumente nicht lokal realisiert wurden, passiert nichts.
undelayed_assign_case_verb([raised:plus])      if true.
undelayed_assign_case_verb([raised:plus|Rest]) if assign_case_verb(Rest).

% Wenn die Argumente lokal realisiert wurden, weise NPen mit strukturellem
% Kasus ja nach Position Nominativ oder Akkusativ zu.

% Die letzte NP mit strukturellem Kasus bekommt Nominativ.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:nom)])  if true.

% Persian verbal nouns have a determiner in SPR. Since Maltese (still) has the subject under SPR,
% the SPR is appended to the list of NPs that get assigned case. Therefore the subject is on second position.
% This clearly is not nice ... St. Mü. 12.01.2008
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:nom),@no_noun])  if true.

% Ein Aufsatz wurde ihm zu lesen erlaubt.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:nom),@np_lex])  if true.


% Nouns that are parts of verbal clusters get lexical case.
% They are unsaturated. The following clause accounts both for regular NPs
% with lexical case and for nouns that are part of predicate complexes.
undelayed_assign_case_verb([(raised:minus,
                             @n_lex)])                                  if true.
undelayed_assign_case_verb([(raised:minus,
                             @no_noun)])                                if true.

% Alle anderen NPen mit strukturellem Kasus bekommen Akkusativ.
% Es muß noch mindestens ein Element in der Valenzliste geben, daß
% nicht durch Passivierung blockiert ist (realized:bool = nicht realized:blocked).
% Für dieses werden die obigen Klauseln angewendet.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:acc),(Nom,
                                                                    @np_str)|Rest])  if assign_case_verb([Nom|Rest]).
% Er verspricht ihm das lied zu singen.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:acc),(Lex,
                                                                    @np_lex),
                                                                   (Nom,
                                                                    @np_str)|Rest])  if assign_case_verb([Lex,Nom|Rest]).
undelayed_assign_case_verb([(raised:minus,
                             @n_lex)|Rest])                                          if assign_case_verb(Rest).
undelayed_assign_case_verb([(raised:minus,
                             @no_noun)|Rest])                                        if assign_case_verb(Rest).




