% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%          $File: german-maltese-lexrules.pl $
%%      $Revision: 94 $
%%          $Date: 2007-03-26 17:16:20 +0200 (Mon, 26 Mar 2007) $
%%         Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%% $LastChangedBy: stefan $
%%        Purpose: Macros that are identical for German and Maltese
%%       Language: Trale
%          System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.
:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile lex_rule/2.
:- discontiguous lex_rule/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.


verb_le *>
 (@non_rel_le,
  synsem:loc:cat:(head:(subj:[],
                        initial:minus),
                  spr:[],
                  subcat:Subcat,
                  arg_st:Subcat)).

non_aux_verb :=
 synsem:loc:cat:head:aux:minus.


% all German verbs except modals, `helfen', and `haben'
non_flip_verb_le :=
 (@event_verb_le,
  @lexical_event_verb_type, % depends on the language, whether this is event_verb_root, event_verb_stem, or event_verb_word
  @non_flip_verb).          % Persian and Dutch differ from German in what triggers Flip. This is a parameter.
                            % Having it and having to mention non_flip_verb in all the subtypes is ugly since the constraint
                            % is only relevant for German, but I do not know a better way right now. St. Mü. 10.10.2007




 
intrans_verb :=
 (@non_flip_verb_le,
  @non_aux_verb,
  @non_idiomatic_le).    % for testing, to be changed later


intrans_unacc_verb :=
  (@intrans_verb,
   @unacc_verb,
   synsem:loc:cat:subcat:append(_,[@np_str(Ind)]),  % Do not know, why last does not work here. Trale bug?
   rels:[arg2:Ind]).

%          goal last(Subcat,@np_str(Ind)).



intrans_nerg_verb :=
 (@intrans_verb,
  @nerg_pred,
  synsem:loc:cat:subcat:append(_,[@np_str(Ind)]),  % Do not know, why last does not work herer. Trale bug? last(@np_str(Ind)),
  rels:[arg1:Ind]).

%       goal last(Subcat,@np_str(Ind)).

% schlafen
strict_intrans_verb :=
  (@intrans_verb,
   @non_hcons_le,  
   synsem:loc:cat:subcat:[_]).

strict_intrans_nerg_verb  :=
  (@strict_intrans_verb,
   @intrans_nerg_verb).

strict_intrans_unacc_verb :=
  (@strict_intrans_verb,
   @intrans_unacc_verb).

intrans_verb(Relation) :=
 (@strict_intrans_nerg_verb,
  rels:[pred:Relation]).

intrans_verb(Relation,Sort) :=
 (@strict_intrans_nerg_verb,
  rels:[(pred:Relation,
         arg1:sort:Sort)]).

intrans_verb(Relation-(a_ _),Arg1Sort-anything,_AuxF-auxf,_VerbSort-situation,_Aktionsart) :=
  @intrans_verb(Relation,Arg1Sort).

intrans_unacc_verb(Relation) :=
 (@strict_intrans_unacc_verb,
  rels:[pred:Relation]).

intrans_unacc_verb(Relation,Sort) :=
 (@strict_intrans_unacc_verb,
  rels:[(pred:Relation,
         arg2:sort:Sort)]).


% denken an
np_pp_verb := 
 (@intrans_verb,
  @non_hcons_le,  
  synsem:loc:cat:subcat:[ @pp(Ind2), _ ],
  rels:[arg3:Ind2]).

np_pp_nerg_verb :=
 (@np_pp_verb,
  @intrans_nerg_verb).

% Persian
np_pp_verb(PForm,Relation,Sort1,Sort3) :=
 (@np_pp_nerg_verb,
  synsem:loc:cat:subcat:hd: @pp_pform(PForm),
  rels:[(pred:Relation,
         arg1:sort:Sort1,
         arg3:sort:Sort3)]).

% German
np_pp_verb(PForm,Case,Relation) :=
 (@np_pp_nerg_verb,
  synsem:loc:cat:subcat:hd: @pp(PForm,Case),
  rels:[pred:Relation]).


% helfen
np_np_nerg_verb :=
 (@intrans_nerg_verb,
  @non_hcons_le,  
  synsem:loc:cat:subcat:[ @np(Ind2), _ ],
  rels:[arg2:Ind2]).

% helfen
np_np_verb(Case,Relation) :=
 (@np_np_nerg_verb,
  synsem:loc:cat:subcat:hd: @np(Case,_Ind2),
  rels:[pred:Relation] ).

% glauben
np_s_nerg_verb :=
 (@intrans_nerg_verb,
  @scopal_event_embedding_verb,
  synsem:loc:cat:subcat:[ @s, _ ]).


np_s_verb(Relation) :=
 (@np_s_nerg_verb,
  rels:[pred:Relation] ).

np_s_verb(Relation,_Sort1,_Sort2) :=
 (@np_s_nerg_verb,
  rels:[pred:Relation] ).


% gelingen
np_np_unacc_verb := 
 (@intrans_unacc_verb,
  @non_hcons_le,  
  synsem:loc:cat:subcat:[ @np(Ind2), @np_str(Ind1) ],
  rels:[(arg2:Ind1,
         arg3:Ind2)]).

np_np_unacc_verb(Case,Relation) :=
 (@np_np_unacc_verb,
  synsem:loc:cat:subcat:hd: @np(Case,_Ind2),
  rels:[pred:Relation]).



% lieben, geben
trans_verb :=
 (@nerg_pred,
  @non_flip_verb_le,
  @non_aux_verb,
  synsem:loc:cat:subcat:append(_, [ @np_str(Ind2), @np_str(Ind1) ]),
  rels:hd:(arg1:Ind1,
           arg2:Ind2)).

% lieben
strict_trans_verb :=
 (@trans_verb,
  @non_hcons_le,  
  synsem:loc:cat:subcat:[ _, _ ]).

non_idiomatic_trans_verb :=
 (@non_idiomatic_le,
  @trans_verb,
  rels:tl:e_list).

non_idiomatic_strict_trans_verb :=
 (@non_idiomatic_trans_verb,
  @strict_trans_verb).

trans_verb(Relation) :=
 (@non_idiomatic_strict_trans_verb,
  rels:[pred:Relation]).

trans_verb(Relation,Sort1,Sort2) :=
 (@non_idiomatic_strict_trans_verb,
  rels:[(pred:Relation,
         arg1:sort:Sort1,
         arg2:sort:Sort2)]).

trans_verb(Relation-(a_ _),Arg1Sort,Arg2Sort,_AuxF,_VerbSort,_Aktionsart) :=
 @trans_verb(Relation,Arg1Sort,Arg2Sort).


idiomatic_trans_verb(IdiomaticRelation,IdiomaticObjectRelation,NonIdiomaticObjectRelation,Sort1,Sort2) :=
 (@strict_trans_verb,
  rels:[(pred:IdiomaticRelation,
         arg1:sort:Sort1,
         arg2:(Ind2,
               sort:Sort2)),
        (pred:IdiomaticObjectRelation,
         lbl:ObjectLbl,
         arg0:Ind2)],
  subtract_rels:[(pred:NonIdiomaticObjectRelation,
                  lbl:ObjectLbl,
                  arg0:Ind2)]).



% geben
ditrans_verb :=
 (@non_idiomatic_trans_verb,
  @non_hcons_le,  
  synsem:loc:cat:subcat:[ @np(dat,Ind3), _, _ ],
  rels:[arg3:Ind3]).

ditrans_verb(Relation) :=
 (@ditrans_verb,
  rels:[pred:Relation]).


% Persian give
np_np_pp_verb :=
 (@non_idiomatic_trans_verb,
  @non_hcons_le,  
  synsem:loc:cat:subcat:[ @pp(Ind3), _, _ ],
  rels:[arg3:Ind3]).

np_np_pp_verb(Relation,PForm-pform,Sort1,Sort2,Sort3) :=
 (@np_np_pp_verb,
  synsem:loc:cat:subcat:hd: @pp_pform(PForm),
  rels:[(pred:Relation,
         arg1:sort:Sort1,
         arg2:sort:Sort2,
         arg3:sort:Sort3)]).



% Komplementierer und das Verb in Erststellung
complementizer_like_word *>
 (@spr_saturated,
  @non_idiomatic_le,
  synsem:loc:cat:(head:(%dsl:none,  German only
                        initial:plus),
                  subcat:[ (@argument_xp,
                            arg:(loc:cat:(head:(verb,
                                                 vform:fin,
                                                 initial:minus),
                                          subcat:list_of_spirits),
                                 trace:minus)) ])).


% The sharing of the LTop has to be done here since the verb movement rule
% does not share the LTop with the argument, but with the rule input instead.
% This is necessary to get scopal modifiers right: The LTop is percolated down to the
% verb trace via DSL. If the VP contains scopal modifiers, the LTop changes to the one
% of the modifier. If we would take the LTop of the selected argument as ARG3,
% we would get circular structures, which would not scope.
% St. Mü. 11.03.2008
complementizer_word *>
 (%simple_word,
  %complementizer_like_word,
  @overt_le,
  @non_rel_le,
  @non_relativizer_le,
  @simple_le,
  @ltop_lbl_le,
  @arg0_le,
  synsem:loc:cat:(head:comp,
                  %subcat:hd:arg:loc:cat:head:dsl:none     German only
                  subcat:hd:arg:loc:cont:ltop:LTop
                 ),
  rels:[(assertion,
         arg3:LTop)],
  h_cons:[]).
