% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%       $RCSfile: core-macros.pl,v $
%%      $Revision: 326 $
%%          $Date: 2008-10-01 15:13:22 +0200 (Mi, 01 Okt 2008) $
%%         Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%% $LastChangedBy: stefan $
%%        Purpose: Parts of grammar that are identical for Chinese, German, and Maltese
%%       Language: Trale
%          System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile (if)/2.
:- multifile (fun)/1.

:- multifile lex_rule/2.
:- discontiguous lex_rule/2.



% First attempt:
% The argument that is realized by a clitic may be realized by an NP too.
% This NP has to have the same case and nunmber, gender, person.
% This is captured by not specifying the REALIZED value of the mother.
% As a result the head counts as fully saturated (compatible with REALIZED+)
% and it allows an additional NP to saturate the argument.

% Unfortunately, this solution does not work, since in the case of
% an unrealized argument the SUBCTAT list of the optional element is not
% instantiated. It just stays `list' with the constraint `list_of_spirits'.
% St. Mü. 

% Is the clitic dislocation non-local? If so, can GTOP be different from the
% GTOP of the lexical verb? That is, will the GTOP correspond to the one
% of the complete sentence? Currently the GTOP is just identified with the
% one of the verb. St. Mü. 15.05.2007

canonical_or_clld_synsem :=
 (loc:(cat:head:%CLHead,
                case:Case,    % only case is shared, definiteness may differ
       cont:(ind:CLInd,
             gtop:GTop)),
  nonloc:inher:(clld: %[];  % we remove this disjunct and omit the requirement that sentences be clld:[]
                       [(@xp_local, % fully saturated
                         cat:head:  %\(% case marked pronouns are contrastive
                                %CLHead,
                                  (compl_noun,
                                      case:Case),
                                %                                  ;
%                                   % nominative forms are not contrastive
%                                   compl_noun,              % The case does not necessarily match. Fabri93a:148
%                                   case:morph_case:nom\),   % jien xtra-li          ktieb sabiħ il-papà.
%                                                           % I    bought(3msg)-1sg book  nice  df-father
                        cont:(ind:CLInd,
                              gtop:GTop))],
                slash:[])).


clitic(Per,Num,Gen) :=
 (@nominal_ref_non_rel_non_relational_pronoun_le,
  synsem:(@canonical_or_clld_synsem,
          loc:(cat:def:plus,
               cont:ind:(per:Per,
                         num:Num,
                         gen:Gen)),
          lex:minus)).

clitic(Case,Per,Num,Gen) :=
 (@clitic(Per,Num,Gen),
  synsem:loc:cat:head:case:morph_case:Case).




fun list_of_complete_locals(-).
list_of_complete_locals(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_complete_locals(L) ).

undelayed_list_of_complete_locals([]) if true.
undelayed_list_of_complete_locals([cat:(spr:[],
                                        subcat:[])|T])  if
   list_of_complete_locals(T).





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Clitic rules

% clitic rules take over everything but the SUBCAT list

% clitic rules apply after inflection, hence the input to this rule
% is restricted to be of type word.
% The clitic rule also applies to nouns and prepositions (Fabri93a:80),
% so the input *must* be a word.

% Clitics are introduced at once. The CLITIC feature blocks recursion.
% This is a hack, but everything else is much more complicated, since
% only certain clitics are possible in combination. To get this right
% in a non-hacky way, we need a theory of stress. St.Mü. 24.04.2007


clitic_lr *>
  (synsem:loc:cat:arg_st:ArgSt,
   clitic:plus,
   head_dtr:(synsem:loc:cat:arg_st:ArgSt,
             clitic:minus)).


% One would love to have this as a subtype of head-argument-struc, but
% the arguments may be saturated in a different order, that is we may have
% io clitics with the do not realized as clitics.

do_or_io_clitic_lr *>
( %headed_struc,
  synsem:loc:cat:subcat:append(Rest,[(arg:Argument,
                                      realized:plus,
                                      raised:Raised)|First]),
  head_dtr:( word,
             synsem:loc:cat:(head:verb, %major, % What about adjectives?
                             subcat:append(Rest,[(arg:Argument,
                                                  raised:Raised,
                                                  realized:minus)|First]))),
  non_head_dtrs:[( clitic,
                   synsem:Argument,
                   stressible:minus)]).




do_clitic_lr *> 
  non_head_dtrs:hd:synsem:loc:cat:head:case:morph_case:acc.   

       


% The io clitic LR takes the same clitics as the DO clitic LR,
% but adds an `l' to mark the dative.
io_clitic_lr :=
 (io_clitic_lr,
  non_head_dtrs:hd:synsem:loc:cat:head:case:morph_case:dat).   

       


do_io_clitic_lr *>
( synsem:loc:cat:subcat:append(Rest,[(arg:ArgumentIO,
                                      raised:Raised,
                                      realized:plus),
                                     (arg:ArgumentDO,
                                      raised:Raised,
                                      realized:plus)]),
  head_dtr:( word,
             synsem:loc:cat:(head:verb,
                             subcat:append(Rest,[(arg:ArgumentIO,
                                                  raised:Raised,
                                                  realized:minus),
                                                 (arg:ArgumentDO,
                                                  raised:Raised,
                                                  realized:minus)]))),
  non_head_dtrs:[( clitic,
                   synsem:ArgumentDO,
                   stressible:plus),
                 ( clitic,
                   synsem:ArgumentIO,
                   stressible:minus)]).



/*
% Direct object cliticisation
% hu is used iff an io marker follows.
% According to Fabri93a only 3sgmas DO clitics are possible if an IO clitic follows.
% Fabri attributes this to the possability to stress certain clitics. Only hu and
% have this property.
% The ultimate analysis has to refer to this property. For now I introduce both clitics
% simultaneously. This ensures the right order and makes bookkeeping features unnecessary.

do_clitic_lr(Per,Num,Gen) :=
 (synsem:loc:cat:subcat:append(Rest,[(arg:Argument,
                                      raised:Raised,
                                      realized:plus)]),
  rels:tl:hd:(lbl:PronLBL,
              arg0:Ind),
  dtrs:[synsem:loc:cat:subcat:append(Rest,[(arg:(Argument,
                                                 loc:cont:ltop:PronLBL),
                                            % This allows for objects of prepositions, which have lexical case,
                                            % and objects of verbs, which have structural case.
                                            arg:loc:cat:head:case:morph_case:acc,
                                            @np((Ind,
                                                 per:Per,
                                                 num:Num,
                                                 gen:Gen)),
                                            @pro_np_ref,
                                            raised:Raised,
                                            realized:minus)]) ]).

do_io_clitic_lr ##
( 
  Dtr
) 
 **>
( do_clitic_lr,
  dtrs:[Dtr])
morphs
  X becomes (X,hu).





io_clitic_lr(Per,Num,Dtr) :=
 (clitic_lr,
  synsem:loc:cat:subcat:append(FirstPart,append([(arg:Argument,
                                                  raised:Raised,
                                                  realized:plus)],LastPart)),
  rels:tl:hd:(lbl:PronLBL,
              arg0:Ind),
  dtrs:[(Dtr,
         synsem:loc:cat:subcat:append(FirstPart,append([(arg:(Argument,
                                                              loc:cont:ltop:PronLBL),
                                                         @np(dat,(Ind,
                                                                  per:Per,
                                                                  num:Num),anything),
                                                         @pro_np_ref,
                                                         raised:Raised,
                                                         realized:minus)],LastPart))) ]).

% `l' is the dative marker `i' is first person singular
% Peterson: ta-w=hu=l=i   'Sie gaben ihn (= das Buch) mir.'
io_clitic_lr ##
( 
  Dtr
) 
 **>
@io_clitic_lr(first,sg,Dtr)
morphs
  X becomes (X,li).

% Fabri93a:41: ta-ni l-ktieb = gave-me df-book
io_clitic_lr ##
( 
  Dtr
) 
 **>
@io_clitic_lr(first,sg,Dtr)
morphs
  X becomes (X,ni).


% ta-k il-ktieb = gave-you df-book
io_clitic_lr ##
( 
  Dtr
) 
 **>
@io_clitic_lr(second,sg,Dtr)
morphs
  X becomes (X,k).

*/

