% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: core-constraints.pl,v $
%%  $Revision: 317 $
%%      $Date: 2008-06-17 18:52:07 +0200 (Di, 17 Jun 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.

:- multifile (if)/2.
:- discontiguous (if)/2.

:- multifile (fun)/1.
:- discontiguous (fun)/1.

:- multifile (macro)/2.
:- dynamic   (macro)/2.  % Has to be here, since both := and macro are used. Martin Lazarov 14.06.2010

% append(+,+,-)
% This append assumes that the first or the third argument
% are known to be non_empty or empty lists. 
%

fun append(+,+,-).
% Original definition due to Detmar Meurers
append(X,Y,Z) if 
   when( (X=(e_list;ne_list);
          Z=(e_list;ne_list)) 
       , undelayed_append(X,Y,Z)
       ).


undelayed_append([],L,L) if true.
undelayed_append([H|T1],L,[H|T2]) if append(T1,L,T2).


% Four place version of append for debugging. It prints the name of the predicate that called it.
fun append(+,+,+,-).
append(Caller,X,Y,Z) if 
   when( (X=(e_list;ne_list);
          Z=(e_list;ne_list)) 
       , undelayed_append(Caller,X,Y,Z)
       ).


undelayed_append(a_ Caller,[],L,L)   if prolog((write('append: '),write(Caller),write([]),write_term(L,[max_depth(3)]),nl)).
undelayed_append(a_ Caller,[H|T1],L,[H|T2]) if prolog((write('append: '),write(Caller),write_term(H,[max_depth(3)]),nl)),append(a_ Caller,T1,L,T2).


/*

% Rewritten by Gerald Penn 24.05.2012
append(X,Y,Z) if 
   when(X=e_list,Y=Z),
   when(Z=e_list,(X=[],Y=Z)),
   % X is a list that starts with H, so Z has to start with H too. The rest is appended by recursion.
   when(H^XT^(X=[H|XT]),
        (Z=[H|ZT], 
         append(XT,Y,ZT))),
   % We do not know what X is, so append has to behave non-deterministically.
   when(H^ZT^(Z=[H|ZT]),
        undelayed_append(X,Y,Z,H,ZT)).

% We already separated Z into H and ZT, so we keep them separate and pass them as the fourth and fifth arguments.
% Notice that we still need to keep Z around (third argument) in order to unify Y and Z - ALE lists are intensional.
undelayed_append([],Z,Z,_,_) if true.
undelayed_append([H|XT],Y,_,H,ZT) if
  append(XT,Y,ZT).

*/

fun del(+,+,-).
del(X,Y,Z) if 
   when( (Y=(e_list;ne_list);
          Z=(e_list;ne_list)) 
       , undelayed_del(X,Y,Z)
       ).

undelayed_del(El,[El|L],L) if true.
undelayed_del(El,[H|T1],[H|T2]) if del(El,T1,T2).


/*

This version is not correct since it fires for [X|_] and returns X.

fun last(+,-).
last(X,L) if
  when( X=(e_list;ne_list)
      , undelayed_last(X,L)
      ).

undelayed_last([L],L) if true.
undelayed_last(tl:T1,L) if last(T1,L).

*/


fun last(+,-).
last(X,Last) if
  when( X=(e_list;ne_list)
      , last2(X,Last)
      ).

last2([H|T],Last) if
  when( T=(e_list;ne_list)
      , undelayed_last([H|T],Last)
      ).

undelayed_last([Last],Last) if true.
undelayed_last(tl:T1,Last)  if last(T1,Last).

% like last, but with different fun declaration.
% can be used to say something about the last element:
% synsem:loc:cat:arg_st:last_el(arg:nonloc:inher:resump:[]).
fun last_el(-,+).
last_el(X,Last) if
  when( X=(e_list;ne_list)
      , last2(X,Last)
      ).

fun member(-,+).  % returns a member
member(El,List) if 
   when( List=(e_list;ne_list)
       , undelayed_member(El,List)
       ).

undelayed_member(El,hd:El) if true.
undelayed_member(El,tl:T1) if member(El,T1).



% Three place member that works like two place member, but never fails and sets a trigger, if an
% element is found in a list.
member(Elt,List,(a_ Trigger)) if
  when( List=(e_list;ne_list),
        undelayed_member(Elt,List,(a_ Trigger))).

undelayed_member(_Elt,e_list,_) if true.
undelayed_member(Elt,hd:Elt,(a_ found_it)) if prolog((trace,write(Elt))),true.
undelayed_member(Elt,tl:Tail,(a_ Trigger)) if
  member(Elt,Tail,(a_ Trigger)).


% used in Persian Grammar
not_member(El,List) if 
   when( List=(e_list;ne_list)
       , undelayed_not_member(El,List)
       ).


undelayed_not_member(_El,[]) if true.
undelayed_not_member(El,hd:El) if !, fail.
undelayed_not_member(El,tl:T1) if not_member(El,T1).


/*

Where was this used? 25.04.2012?

undelayed_not_member(_El,[]) if true.
%undelayed_not_member(El,hd:El) if !, fail.
undelayed_not_member(El,[El2|T1]) if
% for some reasons the delays interact in a way that unblocks on the list type, but
% the actual elements are not instantiated, so we have to wait until they are at least `bot', which is rather unspecific.
  when( El2 = (relation)
       , (identifiable(El,El2) ->
             !, fail
         ; not_member(El,T1))).
%undelayed_not_member(El,[El|Tl]) if !, prolog((write(El),nl,write(Tl),nl)),fail.
%undelayed_not_member(El,tl:T1) if not_member(El,T1).


identifiable(E,E) if true.
*/



/*
undelayed_not_member(El,[El2|T1]) if
% for some reasons the delays interact in a way that unblocks on the list type, but
% the actual elements are not instantiated, so we have to wait until they are at least `bot', which is rather unspecific.
  when( El2 = (relation)
       , (identifiable(El,El2) ->
             !, fail
         ; not_member(El,T1))).
*/
%undelayed_not_member(El,[El|Tl]) if !, prolog((write(El),nl,write(Tl),nl)),fail.



fun list_with_zero_or_one_element(-).
list_with_zero_or_one_element(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_zero_or_one_element(X)
      ).
      
undelayed_list_with_zero_or_one_element(e_list)    if true.
undelayed_list_with_zero_or_one_element(tl:e_list) if true.


% Persian does not have a restriction on the number of fronted elements (Karimi:2005a:18)
% If we parse bottom-up this would result in non-termination. Therefore we need to stipulate
% a maximal number of elements in SLASH. The following constraints restricts a list to at most
% two elements.
fun list_with_at_most_two_elements(-).
list_with_at_most_two_elements(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_at_most_two_elements(X)
      ).

undelayed_list_with_at_most_two_elements(e_list)  if true.
undelayed_list_with_at_most_two_elements(tl:L)    if list_with_zero_or_one_element(L).


% This is needed for a workaround for the old TRALE.
% Somehow two constraints deblock each other producing an infinite list.
% So the constraint below is used to limit this recursion.
% St. Mü. 17.06.2010
fun list_with_at_most_three_elements(-).
list_with_at_most_three_elements(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_at_most_three_elements(X)
      ).

undelayed_list_with_at_most_three_elements(e_list)  if true.
undelayed_list_with_at_most_three_elements(tl:L)    if list_with_at_most_two_elements(L).


% This seems strange and very indirect, but it is needed to delay auxiliaries in languages
% like Danish and English: The auxiliary needs something in SPR but if this is expressed directly
% a lot of constraints apply and cause disjunctions.
fun list_with_at_least_one_element(-).
list_with_at_least_one_element(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_at_least_one_element(X)
      ).

undelayed_list_with_at_least_one_element(ne_list) if true.


fun list_with_exactly_one_element(-).
list_with_exactly_one_element(X) if
  when( X=(e_list;ne_list)
      , undelayed_list_with_exactly_one_element(X)
      ).

undelayed_list_with_exactly_one_element(tl:e_list) if true.

fun bind_off(+,+,-).
bind_off(BSlash,List,Rest) if
  when( (BSlash=(e_list;ne_list),
         List=(e_list;ne_list))
      , undelayed_bind_off(BSlash,List,Rest)
      ).
      
undelayed_bind_off([],List,List) if true.
undelayed_bind_off(hd:Element,[Element|Rest ],Rest       ) if true.
undelayed_bind_off(hd:Element,[First|Rest1],[First|Rest2]) if
  bind_off(hd:Element,Rest1,Rest2).


% Hey, Negation!

%% Type negation - delay until type T and then die.
not_(Type) macro not_type(a_ Type).
fun not_type(+,-).
( not_type((a_ Type),FS) if
      when(FS=Type,
           prolog(fail)) ) :-
        type(Type).




non_move_synsem :=
  (nonloc:inher:(slash:[],
                 rel:[])).

fun list_of_non_move_arguments(-).
list_of_non_move_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_move_arguments(L) ).

undelayed_list_of_non_move_arguments([]) if true.
undelayed_list_of_non_move_arguments([@arg(@non_move_synsem)|T]) if
   list_of_non_move_arguments(T).



fun list_of_spec_none(-).
list_of_spec_none(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_spec_none(L) ).

undelayed_list_of_spec_none([]) if true.
undelayed_list_of_spec_none([@arg(loc:cat:head:spec:none)|T]) if
   list_of_spec_none(T).


% in sysnsem grammars this traverses the list and does not do anything
% in spirit grammars all arguments have to be raised:minus
fun list_of_non_raised_arguments(-).

% list_of_non_raised_arguments(L) if !. % for debugging only, this disables the constraint

list_of_non_raised_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_raised_arguments(L) ).

undelayed_list_of_non_raised_arguments([]) if true.
undelayed_list_of_non_raised_arguments([@non_raised|T]) if        % raised:minus
   list_of_non_raised_arguments(T).




non_complex_forming_synsem :=
  (@cluster_minus_synsem,
   loc:cat:subcat:list_of_spirits,
   lex:minus).

fun list_of_non_complex_forming_synsems(-).
list_of_non_complex_forming_synsems(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_complex_forming_synsems(L) ).

undelayed_list_of_non_complex_forming_synsems([]) if true.

% Mit Spirits muß man die folgenden beiden Fälle unterscheiden:
% Das Element ist noch nicht realisiert, muß also non_complex_formin sein.
undelayed_list_of_non_complex_forming_synsems([(realized:minus,
                                                  arg: @non_complex_forming_synsem)|T]) if
   list_of_non_complex_forming_synsems(T).

% Des Element ist bereits realisiert -> Es ist uns egal, wie es aussieht.
undelayed_list_of_non_complex_forming_synsems([realized:plus|T]) if
   list_of_non_complex_forming_synsems(T).


fun list_of_blocked_arguments(-).
list_of_blocked_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_blocked_arguments(L) ).

undelayed_list_of_blocked_arguments([]) if true.
undelayed_list_of_blocked_arguments([@blocked_np_ref|T]) if
   list_of_blocked_arguments(T).



% depicitives
fun check_identical_append(+,+,+,-).


/*
check_identical_append(DA,Subj,Subcat,D) if
  when((DA = (e_list;ne_list),
        Subj = (e_list;ne_list),
        Subcat = (e_list;ne_list)),  % eventually, you can use DA=max(list) etc. - GBP
        
       ( (
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.

           (DA = [A1],
            Subj = [Subj1],
            A1 =@ Subj1) ->
           append(Subj,Subcat,D)
       ;

         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           (Subj=[],
            DA  =ne_list) -> Subcat = D
       ;
           
           append(DA,Subj,X),
           append(X,Subcat,D)
       ))
).
*/

% Rewritten by Gerald 24.05.2012 Since the middle argument of append does not have to be delayed, we
% do not have to delay on Subcat. The other cases work like it was described for block_subject.

/*
check_identical_append(DA,Subj,Subcat,D) if
  when((DA = e_list),
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.
           append(Subj,Subcat,D)
),
  when((DA = ne_list),
       (Subj = e_list)),
       ( (
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.

         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           Subcat = D
       )),
  when((DA = ne_list),
       (Subj = ne_list)),
       ( (
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.
           (DA = [A1],
            Subj = [Subj1],
            A1 =@ Subj1) ->  append(Subj,Subcat,D)
         ;
         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           append(DA,Subj,X),
           append(X,Subcat,D)
       ))
). */

check_identical_append(DA,Subj,Subcat,D) if
  when(Subj1^(DA = e_list,
              Subj=[Subj1]),
  
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.
           D = [Subj1|Subcat]
),
  when((Subj = e_list),
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.

         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           Subcat = D
       ),
  when(A1^Subj1^(DA = [A1],
                 Subj = [Subj1]),
       ( (
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.
           (A1 =@ Subj1) ->  D = [Subj1|Subcat]
         ;
         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           D =[A1,Subj1|Subcat]
       ))
).

% if we were allowed to use inequations in the antecedents to when/2 statements, we could do this:
/*
check_identical_append(DA,Subj,Subcat,D) if
  when(Subj1^(DA = e_list,
              Subj=[Subj1]),
  
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.
           D = [Subj1|Subcat]
),
  when((Subj = e_list)),
       ( (
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.

         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           Subcat = D
       )),
  when(A1^(DA = [A1],
           Subj = [A1]),
       ( (
 % for participles DA and SUBJ are identical so testing for DA =@ Subj would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.
           D = [A1|Subcat]
       )),
  when(A1^Subj1^(DA = [A1],
                 Subj = [(Subj1,=\=A1)]),
       ( (
         % Finite verbs have empty SUBJ lists.
         % The DA will be a member of the SUBCAT list.
           D =[A1,Subj1|Subcat]
       ))       
).
*/

% collects scope constraints for all realized arguments.
fun outscope_realized(+,+,+,-).

outscope_realized(Label,Handle,Subcat,ScopeConstraints) if 
   when( (Subcat=(e_list;ne_list);
          ScopeConstraints=(e_list;ne_list)) 
       , undelayed_outscope_realized(Label,Handle,Subcat,ScopeConstraints)
       ).

% The other scope constraints cause the MRSes to be graphs that are not normal.
% This is a problem for utool.
undelayed_outscope_realized(_Label,_Handle,_,[]) if true,!. % no scope constraints for debugging

undelayed_outscope_realized(_Label,_Handle,[],[]) if true.

% Arguments that are realized are outscoped by a scopal adjunct to their left.
% The argument Handle is above the quantifier handle.
undelayed_outscope_realized(Label,Handle,[(realized:plus,
                                     arg:loc:cont:quant:lbl:QH
                                    )|Subcat],[(qeq,
                                                harg:Handle,
                                                larg:QH)|ScopeConstraints]) if
    outscope_realized(Label,Handle,Subcat,ScopeConstraints).


% Arguments that are not realized yet outscope the scopal adjunct to their reight.
% The handle for the quantifier body is above the lable of the adjunct.
undelayed_outscope_realized(Label,Handle,[(realized:minus,
                                           arg:loc:cont:quant:lbl:QH % body:QH
                                           % This is a hack that was suggested to me by Stefan Thater 26.02.2009
                                           % If we refer to the body, the resulting dominance graph is not a net.
                                           % St. Mü. 01.03.2009
                                          )|Subcat],[(qeq,
                                                      harg:QH,
                                                      larg:Label)|ScopeConstraints]) if
    outscope_realized(Label,Handle,Subcat,ScopeConstraints).

% All those arguments that do not have a q_handle, that is events and (currently) pronouns.
% 17.06.2008
undelayed_outscope_realized(Label,Handle,[arg:loc:cont:(event_cont;pron)|Subcat],ScopeConstraints) if
    outscope_realized(Label,Handle,Subcat,ScopeConstraints).

