% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%       $RCSfile: core-macros.pl,v $
%%      $Revision: 326 $
%%          $Date: 2008-10-01 15:13:22 +0200 (Mi, 01 Okt 2008) $
%%         Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%% $LastChangedBy: stefan $
%%        Purpose: Parts of grammar that are identical for Chinese, German, and Maltese
%%       Language: Trale
%          System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile (if)/2.
:- multifile (fun)/1.



relational_le :=
 (synsem:loc:cont:key:Rel,
  rels:hd:Rel).

% needed for determiners with two relations (demonstratives) since the quantifier is in the second position of RELS
% in order to be able to generalize over two and one relation determiners.
relational2_le :=
 (synsem:loc:cont:key:Rel,
  rels:tl:hd:Rel).

% things that do not contribute relations.
non_relational_le :=
 (@non_hcons_le,
  @non_idiomatic_le,   % They also should not subtract relations, should they?
  rels:[]).

% one would think that things that do not contribute anything,
% do not have anything under KEY, but is not as simple as this,
% since traces do not contribute locally, but have a KEY that is shared
% with the KEY of the filler.
non_relational_no_key_le :=
 (@non_relational_le,
  synsem:loc:cont:key:none).


arg0_le :=
 (synsem:loc:cont:ind:Ind,
  rels:hd:arg0:Ind).

% needed for determiners with two relations (demonstratives) since the quantifier is in the second position of RELS
% in order to be able to generalize over two and one relation determiners.
arg0_2_le :=
 (synsem:loc:cont:ind:Ind,
  rels:tl:hd:arg0:Ind).


% In principle all arg0_le should have an appropriately specified key,
% but there are lexical rules that share the HEAD with their daughter and introduce
% an new relation. In this case we get a clash between the new KEY and the original
% main semantic contribution of the daughter (example inflection for finite verbs in German
% and Maltese and Persian). So LRs may be arg0_le and all elements from the listicon
% (that is underived stored lexical items) are relational_arg0_le.
relational_arg0_le :=
 (@relational_le,
  @arg0_le).

% needed for determiners with two relations (demonstratives) since the quantifier is in the second position of RELS
% in order to be able to generalize over two and one relation determiners.
relational2_arg0_le :=
 (@relational2_le,
  @arg0_2_le).


ltop_lbl_le :=
 (synsem:loc:cont:ltop:Handle,
  rels:hd:lbl:Handle).

% This is used in lexical rules that introduce the tense/modus information.
% offen=LTOP, CAUSE=lextop,
% pres-ind ( CAUSE ) = lextop
lextop_lbl_le :=
 (synsem:loc:cont:lextop:Handle,
  rels:hd:lbl:Handle).


% The LEXTOP is the last relation. This could be generalized with a relational
% constraint. Currently it is just the second member of RELS.
decomposed_le :=
 (synsem:loc:cont:(ind:Ind,
                   ltop:BottomHandle,
                   lextop:TopHandle),
  rels:[%offen,
        lbl:BottomHandle,
        (
         %cause,
         lbl:TopHandle,
         arg0:Ind)]).

% lexemes that are not decomposed.
% Their LEXTOP is identical to LTOP.
% LEXTOP is accessed by inflectional lexical rules.
singleton_rel_le :=
  synsem:loc:cont:(ltop:Handle,
                   lextop:Handle).

non_hcons_le :=
 h_cons:[].

% subtract_rels contains a list of literal readings that are
% subtracted from the RELS list during composition.
non_idiomatic_le :=
  subtract_rels:[].


non_relativizer_le :=
 synsem:nonloc:to_bind:slash:[].

non_clld_bind_le :=
 synsem:nonloc:to_bind:clld:[].

non_rel_bind_le :=
 synsem:nonloc:to_bind:rel:[].

non_rel_le     :=
  synsem:nonloc:inher:rel:[].

non_que_le     :=
  synsem:nonloc:inher:que:[].

non_slashed_le :=
  synsem:nonloc:inher:slash:[].

non_clld_le :=
  synsem:nonloc:inher:clld:[].


% This should be a type. St. Mü. 24.11.2011 Then we could remove the constraints on pronouns in
% particular languages and instead specifiy the SLASH:[] constraint on this type in particular languages.
overt_le := 
 %stem_or_word
 (%@non_slashed_le,                   % Hm, except resumptive pronouns (Persian).
  @non_clld_bind_le,
  synsem:trace:minus_or_resumptive).


% do we need this? Yes, since there are subtypes of simple_overt_word
overt_word *>
 (%word,
  @overt_le).


stem *> @overt_le.

%root_or_stem_or_word *> @non_rel_bind_le.

non_overt_le :=
 (@non_rel_le,
  @non_que_le,
  @non_clld_le,
  @non_clld_bind_le,
  @non_idiomatic_le,
  (
    phon:[]
%  ; phon:[a_ _]
  )
 ).

non_overt_word *>
 (%simple_word,
  @non_overt_le,
  @non_relativizer_le).

 
trace *>
 (%non_overt_word,
  @non_relational_le,
  synsem:trace:extraction_or_head_movement).

e_trace *>
  (%trace,
   synsem:(loc:Loc,
           nonloc:inher:slash:[Loc],
           trace:extraction)).


sc_saturated :=
  synsem:loc:cat:subcat:[]. %In the German grammar: list_of_spirits.  But since we are in the lexicon we may be more specific.

spr_saturated :=
  synsem:loc:cat:spr:[]. %In the German grammar: list_of_spirits.  But since we are in the lexicon we may be more specific.

saturated :=
 (@spr_saturated,
  @sc_saturated).

/*
% uninflected determiners
det(Pred) :=
 (word,
  synsem:loc:cat:(head:det,
                  spr:[],
                  subcat:[]),
  rels:hd:pred:Pred).

*/

% determiners and pronouns introduce quantifier
% This includes the clitization lexical rules.
% This is the reason why H_CONS is open. Because multiple clitzation is possible,
% the length of this list is not constrained in this type.
quant_intro_le :=
 (%arg0_relational_word,,
  @non_idiomatic_le,
  synsem:loc:cont:(gtop:GTop,
                   ltop:CL_LTop, % This differs from standard MRS, where the LTOP of a quantifier is
                                 % not instantiated. It is needed for accessing the HANDLE of the nominal
                                 % material for instance for the BA and BEI constructions in Chinese.
                                 % The subject marker says that the noun is agentive.
                   quant:Quant),

  rels:last_el((Quant,
                quant_rel,
                lbl:QHandle,
                rstr:Restr)),   % This allows us to use inheritance for fused preopsitions.
                                % The propositions introduce their main content at the beginning of the list and
                                % the quantifier adds at the end. St. Mü. 21.05.2013
  h_cons:(hd:(qeq,
              harg:GTop,
              larg:QHandle),
          tl:hd:(qeq,
                 harg:Restr,
                 larg:CL_LTop))).





determiner_or_possp_le :=
 (@quant_intro_le,
  %@relational_arg0_le,                 because of possessives this is not relational_arg0_le
  @non_relativizer_le,
  @non_slashed_le,
  @non_clld_le,
  @saturated,
  @non_slashed_le,
  synsem:loc:(cat:head:(det,
                        spec:loc:cont:(npro,
                                       gtop:GTop)),
              cont:gtop:GTop)). % This differs from standard MRS, where the LTOP of a quantifier is
                                       % not instantiated. See the Chinese grammar.




% The determiner scopes over the noun.
% determiners and posessive pronouns
%determiner_or_possp_le *>
determiner_le *>
 (@determiner_or_possp_le,
  @non_que_le,
  @quant_intro_le,

  (rels:tl:ne_list,
      @relational2_arg0_le
  ;rels:tl:e_list,
      @relational_arg0_le),

  synsem:loc:(cat:head:spec:loc:cont:(ind:Ind,
                                      gtop:GTop,
                                      ltop:Noun_LTop),
              cont:(gtop:GTop,
                    ltop:Noun_LTop)), % This differs from standard MRS, where the LTOP of a quantifier is
                                      % not instantiated. See the Chinese grammar.
   rels:last_el(arg0:Ind),
   h_cons:tl:tl:e_list).


% The second relation is adjectival. Compare the treatment of possessives in the German grammar.
two_place_determiner_le :=
 (determiner_le,
  synsem:loc:(cat:head:spec:loc:cont:ltop:NLtop),
  rels:[(arg0:event,
         lbl:NLtop,
         arg1:Ind),arg0:Ind]).

determiner_word *>
 (%simple_word,
  %determiner_le,
  @non_rel_le). % close the list off so that the inherited `last' constraint can apply.

overt_determiner_word :=
 (determiner_word,
  @overt_le). 

det(Quant-quant_rel) :=
 (@overt_determiner_word,
  rels:[Quant]).

overt_two_place_determiner_word :=
  (@overt_determiner_word,
   @two_place_determiner_le).

% This macro is used for demonstratives that introduce an additional relation
% this vs. that in English, dak vs. dan in Maltese (distal/proximal).
% The ERG does not make this distinction but uses different quantifiers (that_q_dem_rel/this_q_dem_rel),
% but I think it is nice to have the distinction explicitely in the semantic representation.
det(Quant-quant_rel,Pred) :=
 (@overt_two_place_determiner_word,
  rels:[pred:Pred,Quant]).


possessive :=
 (@ref_pronoun_le,
  @determiner_or_possp_le,
  @non_que_le, % this is too restrictive, `wessen' contains something in QUE. fix later
  synsem:loc:(cat:head:spec:loc:cont:(ind:NInd,
                                      ltop:NLtop),
              cont:(ind:Ind,
                    ltop:NamedLBL,
                    gtop:GTop)),
  rels:[ (pron_rel,
          lbl:NamedLBL,
          arg0:Ind),
         (def_q,          % This is the quantifier that scopes over the noun
          lbl:QHandle,
          arg0:NInd,
          rstr:Restr),
         (pred_arg0_2_3_relation,
          pred: (a_ besitzen_rel),
          lbl:NLtop,                                % The poss-rel is intersective with the noun relation
                                                    % The def_q scopes over both.
          arg0:event,       % hm, some event ...
          arg2:Ind,
          arg3:NInd),
         (pronoun_q,      % This is the quantifier for the possessive pronoun
          arg0:Ind)],
  h_cons:tl:tl:[(qeq,
                 harg:GTop,
                 larg:QHandle),
                (qeq,
                 harg:Restr,
                 larg:NLtop)
                ]).


% clitics and personal pronouns and relative and q-pronouns
pronoun_le *>
 (@saturated,
  @overt_le,
  %@non_relational_no_key_le, This holds for personal pronouns and clitics only.
  synsem:loc:cont:pron).

% now the type pronoun
%pronoun_word :=
% (simple_word,
%  pronoun_le).

open_pronoun_word :=
 (simple_word,
  @open_pronoun_le).

ref_pronoun_le :=
 (pronoun_le,
  synsem:loc:cont:ind:ref).

ref_pronoun_word :=
 (@ref_pronoun_le,
  pronoun).

% referential pronouns and expletives
nominal_pronoun_le :=
  (pronoun_le,
   @compl_nominal_le).

% referential pronouns and expletives
nominal_pronoun_word :=
  (pronoun,
   @nominal_pronoun_le).

nominal_ref_pronoun_le :=
  (@nominal_pronoun_le,
   @ref_pronoun_le).


nominal_non_rel_pronoun_le :=
 (@nominal_pronoun_le,
  @non_rel_le).

nominal_ref_non_rel_pronoun_le :=
 (@nominal_ref_pronoun_le,
  @nominal_non_rel_pronoun_le).

% Maltese clitics and personal pronouns
nominal_ref_non_rel_non_relational_pronoun_le :=
 (@nominal_ref_non_rel_pronoun_le,
  @non_relational_no_key_le,
  @non_que_le).

% possesives have three elements
nominal_ref_pronoun_word :=
  (@nominal_ref_pronoun_le,
   @nominal_pronoun_word).

% personal pronouns and q-pronouns
nominal_ref_non_rel_pronoun_word :=
  (@nominal_non_rel_pronoun_le,
   @nominal_ref_pronoun_word).

dem_or_pers_pronoun :=
  (@nominal_ref_non_rel_pronoun_word,
   @non_relational_no_key_le,
   @non_clld_le,
   @non_que_le,
   @definite_le).

pers_pronoun :=
  (@dem_or_pers_pronoun,
   synsem:loc:cont:ppro).                        % if syntactically relevant.

dem_pronoun :=
  @dem_or_pers_pronoun.
  
pers_pronoun(Per,Num,Sort) :=
 (@pers_pronoun,
  synsem:loc:cont:ind:(per:Per,
                       num:Num,
                       sort:Sort)).

pers_pronoun(Per,Num,Gen,Sort) :=
 (@pers_pronoun(Per,Num,Sort),
  synsem:loc:cont:ind:gen:Gen).

dem_pronoun(Case,Numerus,Genus) :=
 (@dem_pronoun,
  @pronoun_c(Case,third,Numerus,Genus)).


% This is used in left dislocation structures in German:
% Klug, das ist er.
% Stolz, das ist er auf seinen Sohn.
% These structures are treated as instances of incomplete category fronting, in some cases involving argument attraction.
% The part of speech, head values, and valence are determined by the core clause:
%
%   Lesen, das will er den Aufsatz.
% * Gelesen, das will er den Aufsatz.
%
event_pronoun :=
  (@open_pronoun_word,
   @non_relational_no_key_le,
   @non_relativizer_le,
   @non_idiomatic_le,
   synsem:loc:(cat:head:(non_modifier_head,
                         major),             
               cont:ind:event)).

event_dem_pronoun :=
  (@event_pronoun,
   @non_rel_le,
   @non_que_le).

% event_rel_pronoun :=
%   (@event_pronoun,
%    @rel_pronoun).


% question pronoun
int_pron :=
  (@nominal_ref_non_rel_pronoun_word,
   @quant_intro_le,
   @non_slashed_le,
   @non_clld_le,
%   @definite_le,                     % if syntactically relevant.
   synsem:(loc:cont:ind:(Ind,
                         per:third,
                         num:sg),
           nonloc:inher:que:[Ind]),
   rels:[
         
         % thing_rel or person_rel
         (lbl:OutScoped,
          arg0:Ind),
         
         % the question quantifier
         (which_q,
          arg0:Ind)
        ],
   h_cons:tl:[larg:OutScoped]).

int_pron(Pred,Sort) :=
 (@int_pron,
  synsem:loc:cont:ind:sort:Sort,
  rels:tl:hd:pred:Pred).

int_pron(Case,Pred,Sort) :=
 (@int_pron(Pred,Sort),
  synsem:loc:cat:head:case:morph_case:Case).


% Currently there are only nouns that are arguments and verbal nouns in Persian.
nominal_le :=
 (@non_relativizer_le,
  @non_idiomatic_le,
  synsem:loc:cat:head:noun).

compl_nominal_le :=
 (@nominal_le,
  synsem:loc:cat:head:compl_noun).

% Chinese localizer
overt_nominal_word :=
 (overt_word,
  @compl_nominal_le,
  @non_slashed_le, % normally this would be inherited from overt_le, but persian has resumptive pronouns.
  simple_word).
  
noun_le *>
 (@relational_arg0_le,
  @nominal_le,
  @simple_le).  % identifies the GTOP with the GTOP of the SPR and the SUBCATs
                % important for relational nouns like `son'. St. Mü. 27.05.2007

compl_noun_word *>
 (%noun_word,
  @compl_nominal_le). % currently words are always comp nouns. 

% nouns like `woman' or `plan', that is, nouns with or without argument
% and proper names
non_pronoun_noun_le :=
 (noun_le,
  @non_rel_le,
  @non_que_le,
  @non_slashed_le,
  @non_clld_le,
  @unmarked,
  synsem:loc:cont:npro).

% nouns with a specifier or verbal nouns that are used as preverbs in Persian complex predicates.
noun_or_verbal_noun_le :=
 (@non_pronoun_noun_le,
  @ltop_lbl_le).    % moved to non_pronoun_noun_le from simple_noun_le, since it also holds for (derived)
                   % nouns that have something in SUBCAT.
                   % moved it back, since proper names are also non_pronominal.
%  @non_hcons_le). % removed here since we have the LR for Iran -> Iranian, see protocol.txt 15.02.2012

% Do we need this? This causes the IND to be of type index, but it should also be possible to have an 'event' here. St. Mü. 09.06.2010
% Persian event nouns are entered as full words, so they do not undergo inflection and hence can have an IND value of type event.
% St. Mü. 12.06.2010
%  synsem:loc:cont:ind:per:third).


% Determiners, classifiers and subjects may not be extracted.
% Not true for Danish subjects, since Danish is a V2 language.
% But we need this constraint for Maltese and Chinese
% St. Mü. 10.07.2009
% spr:ne_list *> spr:[@arg(%loc:cat:spr:list_of_spirits,             % this is not necessary, but avoids residues
%                          % Hm, removes only one of ten residues
%                          nonloc:inher:slash:[])].


% nouns that take a determiner/classifier.
% nouns with or without an argument.
% This is also true for process nouns (Persian). They take a determiner, but nevertheless have a Designated Argument feature.

% This should be a type and there should be number agreement for languages that have this (e.g. German)
% To Do

% Persian verbal nouns do not have a specifier.
spr_noun_le *>
 (@noun_or_verbal_noun_le,
  synsem:loc:(cat:(head:noun,
                   spr:[(@argument,
                         @arg((loc:(cat:(spr:list_of_spirits,
                                         subcat:[]),
                                % cont:ind:Ind\), Do we need this for Chinese? It is wrong for German
                                % breaks possessives.
                                    cont:quant:QH),
                               nonloc:inher:slash:[])))]),
              cont:(ind:(ref,
                         per:third), % here it is safe to say that nouns are third person. St. Mü. 26.07.2010
                    quant:QH))).
%              cont:ind:(%Ind

simple_noun_le :=
  (spr_noun_le,
   @sc_saturated,
   @compl_nominal_le). % currently there are no modifying nouns


% The following three macros are not optimal, since a noun can have both an NP in a genitive and a
% PP argument. If lexical items for both are in the lexicon we get spurious ambiguities when we
% parse sentence with the optional arguments omitted. St. Mü. 05.07.2012

% mother, father, ...
% used in German, French
% Sohn eines Beamten/Sohn von diesem Beamten 
relational_noun_le(PForm,PCase) :=
 (spr_noun_le,
  @compl_nominal_le,
  synsem:loc:cat:subcat:[@optional_np_or_pp(gen,PForm,PCase,Ind)],
  rels:hd:arg1:Ind).

% "half of the girls" are still "girls", so the sortal restriction is the same.
% even "none of the girls" are "girls". =;-)
part_noun_le(PForm,PCase) :=
  (@relational_noun_le(PForm,PCase),
   rels:hd:(arg0:sort:Sort,
            arg1:sort:Sort)).


% report that John stole a book
cp_noun_le :=
 (spr_noun_le,
  @compl_nominal_le,
  synsem:loc:cat:subcat:[@optional_cp(LTop)],
  rels:hd:arg1:LTop).

pp_noun_le :=
 (spr_noun_le,
  @compl_nominal_le,
  synsem:loc:cat:subcat:[@optional_pp(Ind)],
  rels:hd:arg1:Ind).

% empty element in "in den Müll mit diesen Klammotten" and empty nouns in German
empty_el :=
 (non_overt_word,
  @non_slashed_le,
  synsem:trace:minus).

non_overt_noun_word :=
  (@empty_el,
   @simple_noun_word, % language specific. Chinese selects a classifier, German a determiner
   rels:[pron_rel]).

overt_noun_word *>
 (%overt_word,
  @non_slashed_le, % normally this would be inherited from overt_le, but persian has resumptive pronouns.
  noun_word).

  
proper_noun_word *>
( %overt_noun_word,
  @non_pronoun_noun_le,
  @quant_intro_le,
  @saturated,
  synsem:loc:cont:(ind:per:third,
                   ltop:NamedLBL), % This is non-standard, see type for quantifiers above.
  rels:[(named_rel,
         lbl:NamedLBL,
         arg0:Index),
        (proper_q,
         arg0:Index)],
  h_cons:tl:tl:e_list).

proper_noun(Pred,Sort) :=
 (proper_noun_word,
  synsem:loc:cont:ind:sort:Sort,
  rels:hd:name:Pred).

% For those languages that have gender distinctions
proper_noun(Pred,Gender,Sort) :=
 (@proper_noun(Pred,Sort),
  synsem:loc:cont:ind:gen:Gender).


xp_sign :=
 synsem:loc: @xp_local.

xp_synsem :=
  loc: @xp_local.

xp :=
  (@arg(loc: @xp_local),
   @cluster_minus_argument).

xp(Ind) :=
  (@xp,
   @arg(loc:cont:ind:Ind)).

np :=
  (@xp,
   @arg(loc:cat:head:noun)).

% Eine NP mit strukturellem Kasus
n_str :=
  @arg(loc:cat:head:(% compl_noun, do we need this here?  it breaks the case assignment for the
                     % Danish copula, where the predicative NP is the subject St. Mü. 16.07.2009
                     % It should not, since the np with lexical case does not count and the second NP
                     % (the underlying subject) gets structural case = nominative. St. Mü. 05.03.2013
                     str_compl_noun,
                     case:case_type:str)).

np_str :=
  (%@np,
   @n_str,
   @arg(loc: @xp_local)).

n_lex :=
   @arg(loc:cat:head:(lex_compl_noun,
                      case:case_type:lex)).

np_lex :=
  (@np,
   @n_lex).

argument_xp :=
 (@argument,
  @xp).

argument_np :=
  (@argument_xp,
   @np,
   @arg(loc:cat:(head:compl_noun,
                 unioned:minus))).

argument_n_bar :=
  (@argument,
   @arg((@n_bar,
         loc:cat:(head:compl_noun,
                  unioned:minus)))).


np_ref :=
  (@argument_np,
   @arg(loc:cont:ind:ref)).

% das Subjekt von Infinitiven und vom Passiv
pro_np_ref :=
 (@np_ref,
  @non_raised,
  @arg((loc:(cat:(spr:[],
                  subcat:[]),    % ansonsten hängt ein Constraint rum
             cont:pron),
        lex:minus))).


np(Ind) :=
  (@np_ref,
   @arg(loc:cont:ind:Ind)).


np_str(Ind) :=
  (@np_str,
   @np(Ind)).

% used in valence frames
np_str(Ind,Sort) :=
  (@np_str(Ind),
   @arg(loc:cont:ind:sort:Sort)).


pro_np(Ind) :=
  (@pro_np_ref,
   @np_str(Ind)).


lex(Case) :=
 (case_type:lex,
  morph_case:Case).

np_is(Ind,Sort) :=
 (@np(Ind),
  @arg(loc:cont:ind:sort:Sort)).

np(Case,Ind) :=
  (@np(Ind),
   @np_lex,
   @arg(loc:cat:head:case: @lex(Case))).

% for optional arguments of nouns. The REALIZED value is not '-',
% so such relational nouns can be treated as saturated.
optional_np(Case,Ind) :=
  (@np,
   @arg(loc:(cat:head:case: @lex(Case),
             cont:ind:Ind))).

optional_np_or_pp(NCase,PForm,PCase,Ind) :=
  (@optional_np(NCase,Ind)
  ;@pp(PForm,PCase)). 

np(Case,Ind,Sort) :=
 (@np_is(Ind,Sort),
  @np_lex,
  @arg(loc:cat:head:case: @lex(Case))).

np_cpg(Case, Person, Gender) :=
 @np(Case,(per:Person,
           gen:Gender)).

np_gn(Gender,Number) :=
 @np((gen:Gender,
      num:Number)).

% this covers both CPs and V2 clauses in German, 
% The part of speech has to be specified, since we have to ensure
% that we have a finite clause. If we would refer to events only,
% we would allow for infinitval verbal projections.
s :=
  (@argument_xp,
   @arg(loc:(cat:(head:(comp
                       ;(verb,
                         vform:fin,
                         inv:plus,  % V2 
                         @dsl_none)),    % Persian does not have the DSL feature.
                                         % in the case of Persian the macro does not do anything.
                  subcat:list_of_non_raised_arguments), % necessary for Persian, since arguments of finite verbs may be raised (progressive)
             cont:ind:event))).

% Danish
cp_s_uninv :=
  (@argument_xp,
   @arg(loc:(cat:(head:(comp
                       ;(verb,
                         vform:fin,
                         inv:minus,  % SVO for Danish
                         dsl:none)),
                  subcat:list_of_non_raised_arguments), % necessary for Persian, since arguments of finite verbs may be raised (progressive)
             cont:ind:event))).

interrog_s :=
  (@argument_xp,
   @arg(loc:(cat:(head:(verb,
                        vform:fin,
                        inv:minus, % SVO for Danish/English, SOV for German
                        dsl:none),
                  subcat:list_of_non_raised_arguments), % necessary for Persian, since arguments of finite verbs may be raised (progressive)
             cont:(ind:event,
                   key:interrogative)))).



% for optional arguments of nouns. The REALIZED value is not '-',
% so such relational nouns can be treated as saturated.
optional_cp(LTop) :=
  (@xp,
   @arg(loc:(cat:head:comp,
             cont:ltop:LTop))).

optional_pp(Ind) :=
  (@xp,
   @arg(loc:(cat:head:prep,
             cont:ind:Ind))).


n_bar :=
 (loc:cat:(head:noun,
           spr:hd:realized:minus,
           subcat:list_of_spirits)).

n_bar(Ind) :=
 (@n_bar,
 loc:cont:ind:Ind).

np_local :=
 (@xp_local,
  cat:head:noun).

np_local(Ind) :=
 (@np_local,
  cont:ind:Ind).

np_synsem :=
 (loc: @np_local).

np_synsem(Ind) :=
 (@np_synsem,
  loc:cont:ind:Ind).


no_compl_noun :=
  @arg(loc:cat:head: @not_(compl_noun)).


pp :=
  (@argument_xp,
   @arg(loc:cat:head:prep)).

pp(Ind) :=
  (@pp,
   @arg(loc:cont:ind:Ind)).

pp_pform(PForm) :=
  (@pp,
   @arg(loc:cat:head:pform:PForm)).

pp(PForm,Case) :=
  (@pp_pform(PForm),
   @arg(loc:cat:head:case:morph_case:Case)).


% adjs like verbs have an ARG-ST. The languages differ in the mapping from ARG-ST
% to SPR and SUBCAT
adj_le *>
 (@simple_le,
  @singleton_rel_le,  % LTOP and LEXTOP are shared
  @non_rel_le,
  @non_que_le,
  @non_relativizer_le,
  @non_slashed_le,
  @non_clld_le,
  @ltop_lbl_le,
  @non_idiomatic_le,
  %@relational_arg0_le, not for scopal adjectives
  % scopal adjectives have the modification semantics, i.e. their index is
  % identified with the modified noun in the lexicon already.
  % This means that the index has to be of type ref, not of type event.
  % See the event specification for intersective adjectives below.  20.03.2007
  synsem:loc:cat:head:adj,
  rels:[arg0:event]).





% Nicht alle Adjektive haben ein Subjekt (mir ist warm)
% Adjectives are unaccusative, hence arg2.
intersective_adj_le :=
 (adj_le,
  @relational_arg0_le,
  @non_hcons_le,
  synsem:loc:cat:(head:scopal:minus,
                  arg_st: append(_,[ @np_str(Ind) ])),                     % I do not understand why this does not work: last(@np_str(Ind))), Trale Bug?
  rels:[arg2:Ind]).



% klug
simple_adj_le :=
 (@intersective_adj_le,
  synsem:loc:cat:arg_st:tl:e_list).

% German and Maltese
simple_adj_stem :=
 (@simple_adj_le,
  underived_stem).

adj_stem(Relation) :=
 (@simple_adj_stem,
  rels:[pred:Relation]).


% Chinese, Persian
% currently there are no scopal adjectives in these grammars.
% adjectives inherit from subj_subcat_mapping_le -> SUBCAT = [], SUBJ = [NP-str]
simple_adj_word :=
 (%simple_word,
  @simple_adj_le,
  overt_word,
  synsem:loc:cat:head:prd_adj).

% Chinese, Persian
adj(Pred) :=
 (@simple_adj_word,
  rels:[pred:Pred]).


% is this used? Remainder of Maltese?
adj(Pred,Gen,Num) :=
 (@adj(Pred),
  synsem:loc:cat:arg_st:hd: @np_gn(Gen,Num)).

adj(Pred,Num) :=
 @adj(Pred,genus,Num).


% German `treu' (faithful) and Persian negarān (worried)
np_adj_le :=
 (@intersective_adj_le,
  synsem:loc:cat:arg_st:[@np(Ind2),_],
  rels:[arg3:Ind2]).

np_adj_stem :=
 (@np_adj_le,
  underived_stem).

% Persian
np_adj_word :=
 (%simple_word,
  @np_adj_le,
  overt_word,
  synsem:loc:cat:head:prd_adj).

% Persian
np_adj(Pred) :=
 (@np_adj_word,
  rels:[pred:Pred]).

% German and Maltese
% These do not appear predicatively.
% The quant points to the top-most quantifier of an NP.
% It is needed to establish scope restrictions (German wieder).
% A noun knows its q_handle value since it can access the specifier.
% q_handle is projected along the head path with the semantic content,
% but this projection is broken in case of scopal adjectives like "mutmaßlich" (alledged).
% St. Mü. 05.02.2009
scopal_adj_stem :=
 (adj_stem,
  @sc_saturated,
  synsem:loc:cat:arg_st:[@np_str],
  @scopal_modifier).

% mutmaßlich
scopal_adj_stem(Relation) :=
 (@scopal_adj_stem,
  rels:[pred:Relation]).


general_prep_word *>
(%simple_word,
 %overt_word,
 @simple_le,
 @spr_saturated,
 @non_que_le,
 @non_relativizer_le,
 @non_slashed_le,
 @non_clld_le,
 @non_idiomatic_le,
 synsem:loc:cat:head:prep).

                                % initial: @prep_initial),        % Language specific


non_rel_prep_word *>
  %general_prep_word,
  @non_rel_le.

% This macro used to restrict the SLASH value of the complement.
% However the SLASH may be non-empty in the case of resumptive pronouns (Persian).
% Nevertheless gaps are excluded. This is accounted for by restricting the complement
% to be TRACE -.
%
% St. Mü. 26.07.2010
prep_word *>
 (% non_rel_prep_word,
  @non_hcons_le,
  synsem:loc:cat:subcat:[ @argument_np 

                           % @arg(trace:minus_or_resumptive)) most languages do not allow extraction, but Danish does.
                        ]).

% German: von + dem = vom
% French: de  + le  = du
fused_prep_word *>
  %non_rel_prep_word,
  synsem:loc:cat:subcat:[ @argument_n_bar
                           
                         ].

general_compl_prep_word *>
 (%prep_word,
  synsem:loc:(cat:subcat:[@arg(loc:cont:Cont)],
              cont:Cont)).


compl_prep_word *>
  @non_relational_le.

% similar to the semantic constraints in determiner_le, but rather than doing the coindexing via SPEC the coindexing
% is established via SUBCAT. This seems to be missing a generalization ... =:-( St. Mü. 08.08.2012
%
% French and German
%

% This is the most general type. We have to distinguish between the COMPL and MOD/PRD case since, the complement prepositions
% do not introduce any semantics into RELS.

fused_prep_word *>
  (@quant_intro_le,
   synsem:loc:(cat:subcat:hd: @arg(loc:cont:(gtop:GTop,
                                             ltop:Noun_LTop)),
               cont:(gtop:GTop,
                     ltop:Noun_LTop)), % This differs from standard MRS, where the LTOP of a quantifier is
                                      % not instantiated. See the Chinese grammar.
   h_cons:tl:tl:e_list).


fused_compl_prep_word *>
  (%fused_prep_word,
   @arg0_le,
   synsem:loc:cat:subcat:hd: @arg(loc:cont:ind:Ind),
   rels:[(def_q,
          arg0:Ind)]).



compl_prep(PForm) :=
 (compl_prep_word,
  synsem:loc:cat:head:pform:PForm).


fused_compl_prep(PForm,Case) :=
 (fused_compl_prep_word,
  synsem:loc:cat:head:(pform:PForm,
                       case: @lex(Case))).

% fused or non-fused
general_mod_prep_word *>
 (@intersective_modifier_arg1,
   synsem:loc:cat:head:mod_prep).

% non-fused
mod_prep_word *>
 %prep_word & general_mod_prep_word.
 (@general_mod_prep_cannonical_word,
  @intersective_modifier_arg1_le).          % This closes the H-CONS list.


fused_mod_prep_word *>
  (%fused_prep_word,
   @general_mod_prep_cannonical_word,
   synsem:loc:cat:subcat:hd: @arg(loc:cont:ind:Ind),
   rels:[_,(def_q,
            arg0:Ind)]).


% maybe gtop sharing should be something more general
% for everything that selects other elements.
general_mod_prep_cannonical_word :=
 (general_mod_prep_word,
  synsem:loc:(cat:subcat:[@arg(loc:cont:(ind:Ind2,
                                         gtop:GTop))],
              cont:gtop:GTop),
  rels:hd:arg2:Ind2).


% vp_mod_prep_word (English, Chinese) is a special case of v_mod_prep_word
v_mod_prep_word :=
 (mod_prep_word,
  @intersective_v_modifier_word).


% Persian
v_mod_prep(Relation) :=
 (@v_mod_prep_word,
  rels:[pred:Relation]).

% German, prepositions modify either V on any projection level or n'
mod_prep(Case,Relation) :=
 (mod_prep_word,
  synsem:loc:cat:subcat:hd: @arg(loc:cat:head:case: @lex(Case) ),
  rels:[pred:Relation]).


fused_mod_prep(Case,Relation) :=
 (fused_mod_prep_word,
  synsem:loc:cat:subcat:hd: @arg(loc:cat:head:case: @lex(Case) ),
  rels:hd:pred:Relation).



prd_prep_word *>
 (%prep_word,
  @relational_arg0_le,
  @ltop_lbl_le,
  %subj_subcat_mapping_le, % different for Maltese, Chinese ???
  synsem:loc:cat:(head:prd_prep,
                  arg_st:[@np(Ind2), @np_str(Ind1)]),
  rels:[(arg1:Ind1,
         arg2:Ind2)]).
     
modifier :=
 (@non_idiomatic_le,
  synsem:loc:(cat:head:(modifier_head,  % This should be inferred from information in the signature
                                        % regarding the MOD value, but due to a huge performance bug in the old
                                        % Trale all information was removed from the head types. St. Mü. 16.06.2008
                        mod:loc:cont:(gtop:GTop,
                                      lextop:LexTop)),
              cont:(gtop:GTop,
                    lextop:LexTop))).

modifier_le :=
 (@ltop_lbl_le,
  %@relational_arg0_le,  This wrong for adjectives. Their ARG0 is an event, while the IND is the nominal INDEX.
  @modifier).

% relativizer_word inherits from this.
% relative clauses are intersective modifiers as far as nouns
% and the relative clause are concered (LTOPs are identified),
% but they introduce a relation and scopal constraints,
% since they close of a scoping domain.

% The index of the modified element is not identified with the index of the modifier,
% since this index may differ. For instance, adjectives have an event-index.
intersective_modifier_ltop :=
 (@modifier,
  synsem:loc:cat:head:scopal:minus).

intersective_modifier_ltop_no_hcons :=
 (@intersective_modifier_ltop,
  @non_hcons_le).

intersective_modifier_ltop_le :=
 (@modifier_le,
  @intersective_modifier_ltop).

intersective_modifier_le :=
 (@intersective_modifier_ltop_le,
  @intersective_modifier_ltop_no_hcons).
     
% the local top of the whole construction is identical
% to the local tops of the parts. It is projected from cont:ltop.
% for intersective modifiers the labels are identified.
% This happens since the local tops are identified with the respective
% labels.
% Adjectives introduce an event (ARG0), so arg1 is the Index argument
% that is shared with the noun.
intersective_modifier_arg1 :=
 (@intersective_modifier_ltop,
  synsem:loc:cat:head:mod:loc:cont:ind:Index,  
  rels:hd:arg1:Index).

intersective_modifier_arg1_le :=
 (@intersective_modifier_arg1,
  @intersective_modifier_le,
  @intersective_modifier_ltop_le).


% Scopal modifiers add a scope constraint that says:
% the argument (Handle2) has scope over the local top (LTop) of
% the modified head. The new local top is identical to the label
% of the scopal relation.

% At least in the German `wieder' (again) cases the modifier also outscopes alle
% realized arguments.
%
% weil Max wieder alle Fenster öffnete
%
% ALL < again 

scopal_modifier :=
 (@modifier,
  @arg0_le,
  synsem:loc:(cat:head:(mod:loc:(cat:subcat:Subcat,
                                 cont:ltop:LTop),
                        scopal:plus),
              cont:ltop:Label),
  rels:hd:(lbl:Label,
           arg3:Handle2),
  h_cons:[(qeq,
           harg:Handle2,
           larg:LTop)|outscope_realized(Label,Handle2,Subcat)]).

% unfortunateley there are scopal modifiers that introduce their own HCONS elements.
% An example are Danish complementizers. Because of the preposed negation construction
% the relation between the complementizer and the embeded sentential complement cannot be direct,
% but has to be mediated via qeq. This means that there is an additional qeq constraint, which is absent
% in adverbials for instance.
% St. Mü. 26.06.2009
scopal_complex_modifier :=
 (@modifier,
  synsem:loc:(cat:(head:(mod:loc:(cat:subcat:Subcat,
                                  cont:ltop:LTop),
                         scopal:plus),
                   subcat:hd:arg:loc:cont:gtop:SGTop), % all quantifiers in the complement clause are below the GTOP of this clause
                                                         % So, the adjunct clause is a scope island. 
              cont:ltop:Label),
  rels:hd:(lbl:Label,
           arg1:Handle1,
           arg3:Handle2),
  h_cons:[qeq, % The qeq constraint for head complement scopings, for instance complementizers.
          (qeq,
           harg:Handle1,
           larg:SGTop),
          (qeq,
           harg:Handle2,
           larg:LTop)|outscope_realized(Label,Handle2,Subcat)]).


scopal_modifier_le :=
 (@scopal_modifier,
  @modifier_le).

scopal_modifier_word :=
  (simple_overt_word,
   @scopal_modifier_le).

scopal_complex_modifier_le :=
 (@scopal_complex_modifier,
  @modifier_le).

scopal_complex_modifier_word :=
  (simple_overt_word,
   @scopal_complex_modifier_le).

% German differs here in the type hirarchy below head
% v_modifier  :=
%  (@modifier,
%   synsem:loc:cat:head:(pre_modifier:plus,
%                        mod:loc:cat:head:(adj_or_verbal,
%                                          initial:minus))).

v_modifier_le  :=
 (@v_modifier,
  @overt_le,
  @modifier_le,
  @non_rel_le,
  @non_que_le,
  @non_relativizer_le,
  synsem:loc:cont:(event_cont,
                   ind:event)).  % This event is shared for intersective modifiers, but not for scopal ones.
                                 % This is to make sure that the CONT value is specific. Currently this is needed
                                 % to get the linearization constraints in the Danish grammar to work, but ultimately
                                 % it is also necessary to further specify the properties of this event variable.
                                 % St. Mü. 07.06.2012



v_modifier_word :=
 (overt_word,
  @v_modifier_le).


intersective_v_modifier  :=
 (@intersective_modifier_arg1,
  @v_modifier).

intersective_v_modifier_le  :=
 (@intersective_v_modifier,
  @intersective_modifier_arg1_le,
  @v_modifier_le).

intersective_v_modifier_word  :=
 (@intersective_v_modifier_le,
  @v_modifier_word).

scopal_v_modifier_word        :=
 (@scopal_modifier_word,
  @v_modifier_word).

scopal_complex_v_modifier_word        :=
 (@scopal_complex_modifier_word,
  @v_modifier_word).


% This used to contain an identification of the
% n_bar Index and the Index of the n_modifier,
% however the index of an adjective and especially
% the index of an adjectival participle should be an event.
% Therefore we cannot do a structure sharing here. Instead
% the Ind of the n_bar is shared with an argument of the respective
% relation.
n_modifier :=
 (@modifier,
  synsem:loc:cat:head:mod: @n_bar).

n_modifier_le :=
 (@modifier_le,
  @n_modifier).

% relative clauses, attributive adjectives
intersective_n_modifier  :=
 (@intersective_modifier_ltop,
  @n_modifier).

%n_mod_prep_word
intersective_n_modifier_le  :=
 (@intersective_modifier_arg1_le,
  @n_modifier_le).


v_n_modifier_le  :=
 (@v_n_modifier,
  @overt_le,
  @modifier_le,
  @non_rel_le,
  @non_que_le,
  @non_relativizer_le).
% reintroduce later?
%  synsem:loc:cont:(event_cont,
%                   ind:event)).  % This event is shared for intersective modifiers, but not for scopal ones.
                                 % This is to make sure that the CONT value is specific. Currently this is needed
                                 % to get the linearization constraints in the Danish grammar to work, but ultimately
                                 % it is also necessary to further specify the properties of this event variable.
                                 % St. Mü. 07.06.2012



v_n_modifier_word :=
 (overt_word,
  @v_n_modifier_le).


intersective_v_n_modifier  :=
 (@intersective_modifier_arg1,
  @v_n_modifier).

intersective_v_n_modifier_le  :=
 (@intersective_v_n_modifier,
  @intersective_modifier_arg1_le,
  @v_n_modifier_le).

intersective_v_n_modifier_word  :=
 (@intersective_v_n_modifier_le,
  @v_n_modifier_word).




% both simple adverbs and adverbs that are derived from adjectives
adverb_word :=
 (%@v_modifier_word,
  overt_word,
%  simple_word,
  @saturated,
  @non_slashed_le,
  @non_clld_le,
  @relational_le,
  synsem:loc:cat:head:adv).

non_rel_adverb_word :=
 (@adverb_word,
  @non_rel_le,
  @non_que_le).


location_adverb_word :=
 (@non_rel_adverb_word,
  @intersective_v_n_modifier_word).

location_adverb(Pred) :=
  (@location_adverb_word,
   rels:[pred:Pred]).


ad_adj_word :=
 (overt_word,
  simple_word,
  @non_relativizer_le,
  @non_rel_le,
  @non_que_le,
  @non_slashed_le,
  @non_clld_le,
  @relational_arg0_le,
  @intersective_modifier_arg1_le,
  synsem:loc:cat:(head:(adv,
                        mod:loc:(cat:head:adj,
                                 cont:ind:Ind1)
                                %pre_modifier:plus both orders are possible
                       ),
                  spr:[],
                  subcat:[]),
  rels:hd:arg1:Ind1).

% 很 (very)
mod_ad_adj(Pred) :=
 (@ad_adj_word,
  rels:[pred:Pred]).


% This walks through a list and unifies all GTOPs.
fun gtop_list(-,+).
gtop_list(List,GTop) if
  when( List=(e_list;ne_list)
      , undelayed_gtop_list(List,GTop)
      ).
      
undelayed_gtop_list([],_) if true.
undelayed_gtop_list([@arg(loc:cont:gtop:GTop)|Rest],GTop) if
  gtop_list(Rest,GTop).



simple_le := 
  synsem:loc:(cat:(spr:gtop_list(GTop),
                   subcat:gtop_list(GTop)),
              cont:gtop:GTop).

% listed verbs have an empty specifier list.
% For configurational languages the Subject is mapped to SPR
% by a lexical rule.
verb_le *>
 (@overt_le,
  @simple_le,
  @non_rel_le,
  @non_que_le,
  @non_relativizer_le,
  @non_slashed_le,
  @non_clld_le,
%  @spr_saturated,
%  @non_hcons_le,
  @unmarked,
  synsem:loc:(cat:head:verb,
              cont:event_cont)).  % This is a content without quantifier handles. The index is of type event.

% This should be in the signature, but it is stated here, since the signature slows down TRALE considerably
event_cont *> ind:event.

% used in danish-german-persian. verb(Pred) is used in the macros here, should be unified one day.
event_verb_le :=
 (verb_le,
  @lexical_event_verb_type,              % depends on the language, whether this is event_verb_stem or event_verb_word
  @relational_arg0_le,
  @ltop_lbl_le).


% base verbs
verb(Pred) :=
 (@lexical_event_verb_type,              % depends on the language, whether this is event_verb_stem or event_verb_word
  @non_hcons_le,                         % This is not true for all verbs, but currently used for Maltese and Chinese.
  @non_idiomatic_le,
  @singleton_rel_le,
  synsem:loc:cat:head:aux:minus,
  rels:[pred:Pred]).


% Used in German and Persian
%
% Das designierte Argument Nicht-Unakkusativischer Verben ist das letzte
% Element in der SUBCAT-Liste. Das kann eintweder eine NP mit strukturellem
% Kasus oder ein Satzargument sein.
%
% German verbs + Persian verbal nouns
nerg_pred :=
  (synsem:loc:cat:(head:da:[last(ArgSt)],
                   arg_st:ArgSt)).

% Unnacusative verbs in German, inchoative light verbs in Persian
unacc_verb :=
  synsem:loc:cat:head:da:[].



mono_val_verb(Pred,Sort1) :=
 (@verb(Pred),
  synsem:loc:cat:arg_st:[@np_str(Arg1,Sort1)],
  rels:[arg1:Arg1]).

bi_val_verb(Pred,Sort1,Sort2) :=
 (@verb(Pred),
%  @bi_val_verb, % constraints on this type are only imposed in Maltese
  synsem:loc:cat:arg_st:[@np_str(Arg2,Sort2),
                         @np_str(Arg1,Sort1)],
  rels:[(arg1:Arg1,
         arg2:Arg2)] ).


% 
np_np_verb(Case,Pred,Sort1,Sort2) :=
(@verb(Pred),
  synsem:loc:cat:arg_st:[@np(Case,Arg2,Sort2),
                         @np_str(Arg1,Sort1)],
  rels:[(arg1:Arg1,
         arg2:Arg2)] ).


/*
removed this, since there is a macro with the same name
for Persian

Is now to be found in chinese-nacros.pl

np_np_pp_verb(Pred,PForm-pform,Sort1,Sort2,Sort3) :=
 (@verb(Pred),
  synsem:loc:cat:arg_st: [(@argument_xp,
                           @arg(loc:(cat:head:(prep,
                                               pform:PForm),
                                    cont:ind:(Arg3,
                                              sort:Sort3)))),
                          @np_str(Arg2,Sort2),
                          @np_str(Arg1,Sort1)  ],
  rels:[(arg1:Arg1,
         arg2:Arg2,
         arg3:Arg3)] ).

*/

tri_val_verb(Case,Pred,Sort1,Sort2,Sort3) :=
 (@verb(Pred),
%  @tri_val_verb, % constraints on this type are only imposed in Maltese
  synsem:loc:cat:arg_st: [@np(Case,Arg3,Sort3),
                          @np_str(Arg2,Sort2),
                          @np_str(Arg1,Sort1)],
  rels:[(arg1:Arg1,
         arg2:Arg2,
         arg3:Arg3)]).



tri_val_verb(Pred,Sort1,Sort2,Sort3) :=
 @tri_val_verb(dat,Pred,Sort1,Sort2,Sort3).






% Das sind die Beschränkungen, die nötig sind, damit
% keine eingebetteten Köpfe von komplexbildenden Prädikate angezogen werden.
%
% * weil er das Buch lesen [können wird]
%
% Komplexbildende Prädikate müssen immer direkt mit ihrem
% eingebetteten Kopf verbunden werden:
%
% weil er das Buch [[lesen können] wird]



% optional kohärente Verben ziehen alle Elemente auf SUBCAT an.
% This does not hold for Persian, Dutch, and German dialects like Thuringian/Franconian.
% The constraints for Standard German can be found in the respective german files.
% 
% optionally_coherent_le :=
%   synsem:loc:cat:arg_st:[(@argument,
%                           @non_dsl_argument)|list_of_non_complex_forming_arguments].

% The constraint is formulated as a constraint on SUBCAT rather than ARG-ST
% since the multiple fronting lexical rule (German) inherits from coherent_le, which
% is a subtype of optionally_coherent_le and the MVF-LR does not mention ARG-ST.
% St. Mü. 11.03.2009
% I removed even this weaker constraint since the argument of the verb that is output
% of the MVF-LR is something with a DSL value.
% optionally_coherent_le *>
%   synsem:loc:cat:arg_st:hd:(@argument,
%                             @non_dsl_argument).



% alle Anhebungsverben, also auch die, die optional kohärent konstruieren,
% Phasenverben (beginnen), sehen, lassn und die, die obligatorisch kohärent konstruieren,
% Modalverben, Futur-Hilfsverb, Perfekt-Hilfsverb

raising_verb_le :=
 (%verb_le,                                        %% not event_verb_le since Persian LV that combine with verbal nouns
                                                   %% do not contribute a relation.
  @lexical_verb_type,
  optionally_cluster_forming_verb_le,
% Since Persian light verbs can be passivized, this restriction is introduced
% at the subtypes that are relevant for German only.
%  synsem:loc:cat:head:da:[],                      %% DA-Wert schließt Passivierung von Hilfsverben aus.
  @singleton_rel_le,
  @non_idiomatic_le).

% This allows quantifiers to scope between the raising verb and the embedded predicate.
% A unicorn seems to be approaching.
% For verbs (German, Persian) and preverbs (Persian)
scopal_event_embedding_le :=
 (synsem:loc:cat:arg_st:hd:arg:loc:cont:ltop:SLTop,
  rels:[arg3:Handle],
  h_cons:[(qeq,
           harg:Handle,
           larg:SLTop)]).

scopal_event_embedding_verb :=
 (@scopal_event_embedding_le,
  @event_verb_le).

% This does not allow quantifiers to scope between.
nonscopal_event_embedding_verb :=
 (@event_verb_le,
  @non_hcons_le,
  synsem:loc:cat:arg_st:hd:arg:loc:cont:ltop:SLTop,
  rels:[arg3:SLTop]).



% These are the raising verbs that introduce a relation and that allow quantifiers to scope
% between this relation and the relation introduced by the embeeded predicate.
% All German raising verbs, but not Persian LV that combine with preverbal nouns.
scopal_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:head:da:[],                      %% DA value excludes passivization of auxiliary verbs.
  @scopal_event_embedding_verb).


raising_verb :=
 (@scopal_raising_verb_le,
  @event_verb_le).





% TO DO: can the following two macros be fused????
scopal_subj_raising_verb_le :=
 (@scopal_raising_verb_le,
  @subj_raising_verb_le).

scopal_subj_raising_verb :=
 (@scopal_subj_raising_verb_le,
  @event_verb_le).


% Persian auxiliaries
nonscopal_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:head:da:[],                      %% DA value excludes passivization of auxiliary verbs.
  @nonscopal_event_embedding_verb).

nonscopal_subj_raising_verb_le :=
 (@nonscopal_raising_verb_le,
  @subj_raising_verb_le).




% I thought of getting rid of the prd/non_prd distinction, but it would be
% unclear how verbs/VPs/Ss/CPs/determiners could be blocked from functioning as
% arguments of the copula.

% Since the index of the copula is of type event, 
% the predicative complement has to be of type event as well.
% adjectives and predicative PPs are. NPs are mapped onto events.
%
% We do not share the whole CONT value since the type my differ.
%
% For instance in left dislocation structures we require that the fronted element
% is a pronominal element. This requirement would clash with the requirement coming from
% the copula.
%
% St. Mü. 30.07.2009
%
% Klug, das ist Max.
%

predicational_copula_verb_le :=
  (@spr_and_subj_raising_verb_le,   % currently language dependent, to be decided/unified later
   @non_relational_le,
   synsem:loc:(cat:(head:da:[], 
                    arg_st:hd: @arg(loc:(cat:head:prd_head,
                                         cont:(ind:Ind,
                                               ltop:LTop,
                                               gtop:GTop)))), 
               cont:(ind:Ind,
                     ltop:LTop,
                     gtop:GTop))).


