% -*- coding:utf-8 mode:trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: core-syntax.pl,v $
%%  $Revision: 325 $
%%      $Date: 2008-09-26 14:50:11 +0200 (Fr, 26 Sep 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: All the syntactic constrints that belong to
%%             Universal Grammar.
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile (if)/2.
:- discontiguous (if)/2.
:- multifile (fun)/1.
:- discontiguous (fun)/1.


% some type constraints which were removed from the signature


non_spec_head *> spec:none.
%comp     *> spec:none.

%adj   *> dsl:none.
%comp  *> dsl:none.
%coord *> dsl:none.
%intro_case_head   *> dsl:none.  % det, noun, mod_adj
%modifier_head *> dsl:none.
%part *> dsl:none.
%prep *> dsl:none.

non_modifier_head *> mod:none.


% already in the signature

% headed_phrase *>
%   head_dtr:syntactic_sign.

headed_binary_phrase *>
   non_head_dtrs:hd:syntactic_sign.

headed_struc *>
   (synsem:loc:cat:head:Head,
    head_dtr:synsem:loc:cat:head:Head).

headed_struc *>
   (synsem:loc:cat:xarg:XArg,
    head_dtr:synsem:loc:cat:xarg:XArg).


/*
% This is the version that assumes that grammars are binary branching
% SLASH and REL percolation are done by this constraint. REL is bound
% off in relative clause phrases which are unheaded.
% Using this constraint instead of the ones that crawwl through the daughters
% saves 10 sec (from 80) while loading the lexicon of the maltese grammar.
%
% For testing I now use a grammar without the lexicon rule for clitic attachment.
% This safes a lot of time and is more practical. The proper forms of the
% constraints below apply to unary branching structures as well, so I rather
% use them. 30.05.2007 St. Mü.

headed_binary_struc *>
   (synsem:nonloc:inher:(rel:(list_with_zero_or_one_element,
                              append(Rel1,Rel2)),
                         slash:(list_with_zero_or_one_element,
                                bind_off(BSlash,append(Slash1,Slash2)))),
                         
       head_dtr:synsem:nonloc:(inher:(rel:Rel1,
                                      slash:Slash1),
                               to_bind:slash:BSlash),
       non_head_dtrs:hd:synsem:nonloc:inher:(rel:Rel2,
                                             slash:Slash2)).

*/



% This should be parallel to the constraints for RELS, but
% DTRS is instantiated only after EFD closure computation,
% and hence reference to DTRS would result in non-termination.
headed_struc *>
   (synsem:nonloc:inher:slash:(%list_with_zero_or_one_element, % true for German, Chinese, Maltese, but not for Persian (Karimi2005a:18)
                               bind_off(BSlash,append(ISlash,collect_slash(NHDtrs)))),
       head_dtr:synsem:nonloc:(inher:slash:ISlash,
                               to_bind:slash:BSlash),
       non_head_dtrs:NHDtrs).



% This was restricted to compositional_sw_or_phrase, but this would exclude the ezafe construction
% in Persian. Do we have to be that restrictive? I hope not. St. Mü. 08.09.2007
(head_non_filler_struc,
    head_dtr:structured_word_or_phrase) *>
    head_dtr:synsem:nonloc:to_bind:slash:[].

% head_non_filler_struc *>
%    head_dtr:synsem:nonloc:to_bind:slash:[].




fun collect_rel(+,-).
collect_rel(X,Y) if 
   when( X=(e_list;ne_list) 
       , undelayed_collect_rel(X,Y)
       ).

undelayed_collect_rel([],[]) if true.
undelayed_collect_rel([synsem:nonloc:inher:rel:Rel|T],CRel) if
  collect_rel(T,RelT),
  append(Rel,RelT,CRel).

fun collect_slash(+,-).
collect_slash(X,Y) if 
   when( X=(e_list;ne_list) 
       , undelayed_collect_slash(X,Y)
       ).

undelayed_collect_slash([],[]) if true.
undelayed_collect_slash([synsem:nonloc:inher:slash:Slash|T],CSlash) if
  collect_slash(T,SlashT),
  append(Slash,SlashT,CSlash).

fun collect_que(+,-).
collect_que(X,Y) if 
   when( X=(e_list;ne_list) 
       , undelayed_collect_que(X,Y)
       ).

undelayed_collect_que([],[]) if true.
undelayed_collect_que([synsem:nonloc:inher:que:Que|T],CQue) if
  collect_que(T,QueT),
  append(Que,QueT,CQue).


/*
headed_struc *>
  (synsem:nonloc:inher:rel:(list_with_zero_or_one_element,
                                   collect_rel(Dtrs)),
   dtrs:Dtrs).

*/


% For reasons I do not understand, the above constraint results in non-termination
% of EFD computation. Maybe the two delayed relations deblock each other in a strange way.
% St. Mü. 12.05.2007
headed_struc *>
   (synsem:nonloc:inher:rel:(list_with_zero_or_one_element,
                             append(IRel,collect_rel(NHDtrs))),
       head_dtr:synsem:nonloc:inher:rel:IRel,
       non_head_dtrs:NHDtrs).


headed_struc *>
  (synsem:nonloc:inher:que:collect_que(Dtrs),
   dtrs:Dtrs).

% This used to be in the description of cluster-forming languages,
% but I now put it here, since Danish referes to LEX as well, without beeing
% a cluster forming language.  St. Mü. 28.06.2009

head_argument_phrase  *> synsem:lex:minus.
head_filler_phrase    *> synsem:lex:minus.
head_specifier_phrase *> synsem:lex:minus.


% restricts adjunct extraction to structures with verbal head.
% Without this constraint an adjunct trace could originate in
% the classifier phrase:
% man read every _ classifier book DE shop = the shop in which the man read every book.

% Reduces the number of edges from 148 to 46.

(head_adjunct_phrase,
 non_head_dtrs:[synsem:trace:extraction]) *> synsem:loc:cat:head:verb.


% Part of the Trace Principle: The Head-Dtr may not be extracted.
%% Ein Problem stellt hierbei das Verb in PVP-Konstellationen
%% dar (siehe Müller, 1999)
%% "Helfen wird er ihm morgen."

%% For Persian we have head-adjunct structure for object + RA. The object may be a resumptive.
%% St. Mü. 17.09.2010

headed_phrase *>
  head_dtr:synsem:trace:minus_or_head_movement_or_resumptive.

% The following collects all the RELS of the daughters and appends the constructional RELS
% to the resulting list. From this list it is tried to subtract the collection of SUBTRACT_RELS
% from all daughters. All elements from SUBTRACT_RELS that cannot be removed are represented
% in Subtract_Rest. If possible they are removed at the next higher node in the tree.

% includes relative clauses

% the strings, that Pat pulled


structured_word_or_phrase *>
  (rels:subtract(collect_subtract_rels(Dtrs),append(Rels1,collect_rels(Dtrs)),Subtract_Rest),
   subtract_rels:Subtract_Rest,
   c_cont:(rels:Rels1,
           h_cons:HCons1),
   h_cons:append(HCons1,collect_hcons(Dtrs)),
   dtrs:Dtrs).                    

fun subtract(+,+,-,+).
subtract(SIn,LIn,LOut,SOut) if 
   when( ((SIn=(e_list;ne_list),
           LIn=(e_list;ne_list))
%          ;
%           (SOut=(e_list;ne_list),
%            LOut=(e_list;ne_list))
         )   
         
       , undelayed_subtract(SIn,LIn,LOut,SOut)
       ).


undelayed_subtract([],L,L,[]) if true.
undelayed_subtract([E|T],LIn,LOut,Rest) if
  del(E,LIn,LTemp),
  subtract(T,LTemp,LOut,Rest).

% A cut after the first delete does not work because of the delays.
% This seems highly inefficient to me, but I do not know a better way.
% The stuff below does not work because of spurious ambiguities.
undelayed_subtract([E|T],LIn,LOut,[E|Rest]) if
  %\+ del(E,LIn,_LTemp),
  not_member(E,LIn),
  subtract(T,LIn,LOut,Rest).


/*
% This is Gerald's version:

undelayed_subtract([],L,L,[]) if true.
undelayed_subtract([S|Ss],LIn,LOut,SOut) if
  us_act(LIn,S,Ss,Accum,Accum,LOut,SOut).

us_act([],S,Ss,LIn,[],LOut,[S|SOut]) if
  subtract(Ss,LIn,LOut,SOut).
us_act([S|Is],S,Ss,LIn,Is,LOut,SOut) if
  !,subtract(Ss,LIn,LOut,SOut).
us_act([T|Is],S,Ss,LIn,[T|LInRest],LOut,SOut) if
  us_act(Is,S,Ss,LIn,LInRest,LOut,SOut). 

*/

/*
undelayed_subtract([],L,L,[]) if !,true.
undelayed_subtract(L,[],[],L) if !,true.

% corresponds to
% undelayed_del(El,[El|L],L) if true.
undelayed_subtract([El|RestSIn],[El|RestLIn],LOut,    SOut) if !,subtract(RestSIn,RestLIn,LOut,SOut).

% corresponds to
% undelayed_del(El,[H|T1],[H|T2]) if del(El,T1,T2).
undelayed_subtract(         SIn,[H|RestLIn], [H|LOut],SOut) if subtract(SIn,RestLIn,LOut,SOut).

% if deleting fails, we give up deleting the first element and try the next one.
undelayed_subtract([El|RestSIn],LIn, LOut,[El|SOut]) if subtract(RestSIn,LIn,LOut,SOut).

*/


% The LTOP and INDEX is represented directly under CONT.
% The values are either changed in the phrase, that is the values in c_cont:hook
% differ from the LTOP/INDEX of the daughters or threaded through c_cont, that is
% LTOP/INDEX in c_cont:hook are identical to the CONT value of one of the daughters.
% This depends on the various subtypes of phrase.
structured_word_or_phrase *>
 (synsem:loc:cont:Cont,
  c_cont:hook:Cont).

compositional_sw_or_phrase *>
  (c_cont:(rels:[],
           h_cons:[])).

headed_compositional_sw_or_phrase *>
 (head_dtr:synsem:loc:cont:(gtop:GTop,
                            ind:Ind),
  c_cont:hook:(gtop:GTop,
               ind:Ind)).

headed_compositional_non_adjunct_struc *>
 (head_dtr:synsem:loc:cont:Cont,
  c_cont:hook:Cont).


% ? GTOP, LEXTOP
non_compositional_phrase *>
  (c_cont:(rels:hd:(Reln,
                    lbl:LTop,
                    arg0:Ind),
           hook:(ind:Ind,
                 ltop:LTop,
                 key:Reln))).


  
% This would project the quant information from adjectives like alledged.
% These adjectives take it over from the noun they modify.
% St. Mü. 05.02.2009
%
% head_adjunct_phrase *>
% (non_head_dtrs:hd:synsem:loc:cont:Cont,
%  c_cont:hook:Cont).
% However, it does not work since the index of an adjective is verbal
% while the index of the noun is nominal, that is there are different indices.
%
% der geschlagene Mann
% the beaten man
%

head_adjunct_phrase *>
  (non_head_dtrs:hd:synsem:loc:cont:ltop:LTop,
   c_cont:hook:ltop:LTop).

% Needed for Danish since the preposed negation phrase acesses the KEY of a clause embedded under negation.
head_adjunct_phrase *>
  (head_dtr:synsem:loc:cont:key:Key,
   c_cont:hook:key:Key).

% The LTOPs are identified in syntax. This solves Kasper's puzzle:
% an apperently simple example
% has to be analyzed as as (apparently simple) + example
% If simple is conjoined with example in the lexicon, we get a problem.
%
% On the other hand there are particle verbs like `anlachen' `smile at somebody'.
% Here the particle and the verb are syntactically not in an head adjunct configuration, the
% particle is a syntactic argument of the verb, but acts as a modifier semantically.
% These coindexations have to beintroduced lexically as in PS94 modification.
% So `an' shares its `LTOP' with the verb.
%
% Er lacht sie an.

(head_adjunct_phrase,
 non_head_dtrs:hd:synsem:loc:cat:head:scopal:minus) *>
  (head_dtr:synsem:loc:cont:ltop:LTop,
   non_head_dtrs:hd:synsem:loc:cont:ltop:LTop).


% Adjuncts are extraction islands (more general explanation in terms of information structure,
% see Goldberg 2006)
% This would also block the complete extraction of the adjunct. St. Mü. 10.07.2009
%head_adjunct_phrase *>
% non_head_dtrs:hd:synsem:nonloc:inher:slash:[].

h_arg(HeadDtr,NonHeadDtr) :=
 (head_argument_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).

head_non_argument_non_cluster_phrase *>
   (synsem:loc:cat:subcat:Subcat,
    head_dtr:synsem:loc:cat:subcat:Subcat).



% The following constraint ensures that the handle of the topmost quantifier of an NP is part
% of the CONT of this NP. This handle is needed to establish scope constraints between various
% quantifiers and adjuncts in a clause (German: wieder)
% In an earlier version of the grammar this information was percolated together with the CONT
% value of the noun. However, this breaks down when scopal adjectives like alledged intervene.
% To handle this one would have to let this adjective take over the QHandle of the noun.
% But then the head-adjunct-schema has to project the quant from there, if it is present ...
% St. Mü. 05.02.2009.
(head_specifier_phrase,
  non_head_dtrs:hd:synsem:loc:(cat:head:det,
                               cont:quantifier_cont)) *>
(synsem:loc:cont:quant:Q,
  non_head_dtrs:hd:synsem:loc:cont:quant:Q).



%% Spezifikatorprinzip

(headed_binary_phrase,
 non_head_dtrs:hd:synsem:loc:cat:head:spec:synsem) *>
   (head_dtr:synsem:Head,
    non_head_dtrs:hd:synsem:loc:cat:head:spec:Head).


head_non_specifier_struc *> 
   (synsem:loc:cat:spr:Spr,
    head_dtr:synsem:loc:cat:spr:Spr).



spr_h(HeadDtr,NonHeadDtr) :=
  (head_specifier_phrase,
   head_dtr:HeadDtr,
   non_head_dtrs:[NonHeadDtr]).


%% Kopf-Adjunkt-Strukturen


head_adjunct_phrase *>
   (head_dtr:synsem:HeadSynsem,
    non_head_dtrs:[(@xp_sign,
                    synsem:(loc:cat:head:mod:HeadSynsem,
                            lex:minus))]).





h_adj(HeadDtr,NonHeadDtr) :=
 (head_adjunct_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).


/*
head_filler_phrase *>
 (synsem:loc:cat:(spr:Spr,
                  subcat:Subcat),
  head_dtr:synsem:loc:cat:(spr:Spr,
                           subcat:Subcat)).
*/


filler_h(HeadDtr,NonHeadDtr) :=
 (compositional_head_filler_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).




% Subjekt-Verb-Kongruenz
%

/*

% Diese Formulierung entspricht der Formulierung im Buch, ist allerdings
% uneffektiv, da eine Liste, die keine Nominative enthält, zweimal vollständig
% durchlaufen werden muß.

% Das Laden der Grammatik dauert ewig ....

fun subj_verb_agreement(-,+,+).
subj_verb_agreement(List,Per,Num) if
  append(_Rest,[@np_str(Per,Num)|list_of_non_nominatives],List).

subj_verb_agreement(list_of_non_nominatives,third,sg) if true.

*/

% This relational constraint is also used in the lexical rule for
% participle fromation.
%
% das dem Jungen zulesen erlaubte Buch

fun list_of_non_nominatives(-).
list_of_non_nominatives(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_nominatives(L) ).

undelayed_list_of_non_nominatives([]) if true.
undelayed_list_of_non_nominatives([@n_lex|T])  if
   list_of_non_nominatives(T).
undelayed_list_of_non_nominatives([@no_compl_noun|T]) if
   list_of_non_nominatives(T).





/*
fun block_subject(+,-,+).
block_subject([H|T],RestSubcat,Subj) if
   when( T=(e_list;ne_list)
       , undelayed_block_subject([H|T],RestSubcat,Subj)).


% this case does not arise, since all verbs have at least
% one element in their SUBCAT list. For raising verbs this is
% the embedded verb.
%undelayed_block_subject([],[],[]) if true.
% the list may contain only the embedded verb/verbal complex:
% daß gelacht werden (dürfen) kann


undelayed_block_subject([(SubjNP,
                          @np_str)],[],[SubjNP]) if true.
undelayed_block_subject([(Other,
                         @np_lex)],[Other],[]) if true.
undelayed_block_subject([(Other,
                          loc:cat:head:(@not_(noun)))],[Other],[]) if true.

undelayed_block_subject([X|T1],[X|T2],Subj) if block_subject(T1,T2,Subj).
*/

fun block_subject(+,-,+).

%block_subject(Subcat,RestSubcat,Subj) if !. % debugging only
block_subject(Subcat,RestSubcat,Subj) if
   when( Subcat=(e_list;ne_list)
       , undelayed_block_subject(Subcat,RestSubcat,Subj)).


% this case does not arise, since all verbs have at least
% one element in their SUBCAT list. For raising verbs this is
% the embedded verb.
%undelayed_block_subject([],[],[]) if true.
% the list may contain only the embedded verb/verbal complex:
% daß gelacht werden (dürfen) kann


undelayed_block_subject([(SubjNP,
                          @n_str)],[],[SubjNP]) if true.
undelayed_block_subject([(Other,
                         @n_lex)],[Other],[]) if true.
% undelayed_block_subject([(Other,
%                          @no_compl_noun)],[Other],[]) if true.

/*
undelayed_block_subject([X|T1],[X|T2],Subj) if
  when( T1 = (e_list;ne_list)
      , ( (T1=e_list,
           T2=e_list,
           X= @no_noun,
           Subj=e_list)
        ;
          block_subject(T1,T2,Subj))).
*/

% Rewritten by Gerald 24.05.2012: We have two when clauses, that cannot be both true, since T1 is
% either an e_list or an ne_list. If it is an e_list the first clause applies and does whatever it
% is supposed to do and the second one succeeds without having any effect and vice versa for the
% case in which T1 is an ne_list.
undelayed_block_subject([X|T1],[X|T2],Subj) if
  when(T1=e_list,(T1=e_list,
           T2=e_list,
           X= @no_compl_noun,
           Subj=e_list)),
  when(T1=ne_list,block_subject(T1,T2,Subj)).


fun block_da(+,+,-).
%block_da(_,_,_) if true. % debugging
block_da((DA,
          list_of_non_complex_forming_synsems),         % speed
                                                          % for auxiliaries like `haben', we do not know what the DA is, but we know that
                                                          % it is not complex forming
                                                          % without this constraint the da_blocking would
                                                          % block the embedded ppp_verb (cyclic structure), only to find out
                                                          % later that the DA of the embedded ppp_verb differs from the ppp_verb
         Subcat,RedSubcat) if
  append(RedSubcat,DA,Subcat).



% The following is a version of the above constraint. It blocks the designated argument from the
% ARG-ST list and then takes the rest and removes an NP[str] from the remaining list and adds it to
% the beginning of the remaining list.
%
%           German           English         Danish
% active    str1,str2,ldat   str1,str2,lacc  str1,str2,str3
% passive   str2,ldat        str2,lacc       str2,str3           ( first clause )
%                                            str3,str2           ( second clause )
fun block_da_and_promote_obj(+,+,-).
%block_da(_,_,_) if true. % debugging
block_da_and_promote_obj((DA,
          list_of_non_complex_forming_synsems),         % speed
                                                          % for auxiliaries like `haben', we do not know what the DA is, but we know that
                                                          % it is not complex forming
                                                          % without this constraint the da_blocking would
                                                          % block the embedded ppp_verb (cyclic structure), only to find out
                                                          % later that the DA of the embedded ppp_verb differs from the ppp_verb
         Subcat,NewArgSt) if
  append(NewArgSt,DA,Subcat).

block_da_and_promote_obj((DA,
          list_of_non_complex_forming_synsems),         % speed
                                                          % for auxiliaries like `haben', we do not know what the DA is, but we know that
                                                          % it is not complex forming
                                                          % without this constraint the da_blocking would
                                                          % block the embedded ppp_verb (cyclic structure), only to find out
                                                          % later that the DA of the embedded ppp_verb differs from the ppp_verb
         Subcat,[NP2,NP3]) if
  append([(@np_str,
           NP3),(@np_str,
                 NP2)],DA,Subcat).


% Kasusprinzip

% Das Kasusprinzip könnte an Lexikoneinträgen festgemacht werden.
% Wegen der mehrfachen Vorfeldbesetzung muß dieses Prinzip aber sowohl für
% Lexikoneinträge von Verben als auch für Spuren gelten.
% [[Der Frau] [das Buch] _] gibt er nicht.

% Some languages (configurational ones) have the subject in the SPR list,
% others have them in SUBCAT (finite verbs in German). Blocked subjects
% are represented under HEAD:SUBJ (non-finite verbs in German).

% The actual case principle is defined in nom-acc-case.pl and erg-abs-case.pl respectively.
% (word,
%  synsem:loc:cat:head:adj_or_verbal) *> synsem:loc:cat:(head:subj:Subj,
%                                                        spr:Spr,
%                                                        subcat:Subcat) goal assign_case_verb(append(Subcat,append(Spr,Subj))).

% Since Danish has complex mappings to SPR for object shift, case assignment has to happen on ARG-ST.
% St. Mü. 05.03.2012

(word,
 synsem:loc:cat:head:adj_or_verbal) *> synsem:loc:cat:arg_st:ArgSt goal assign_case_verb(ArgSt).


% The semantics principle ignores the semantics of all daughters that
% are idiomatic plus. Currently the feature is used for arguments in the
% predicate cluster only.
(head_non_cluster_phrase,
 non_head_dtrs:ne_list)        % this is needed since pro_drop_phrase does not have any non_head_dtrs.
                          *> non_head_dtrs:hd:synsem:loc:idiomatic:minus.


fun attract(+,-).
attract(List1,List2) if
       when( (List1=(e_list;ne_list);
              List2=(e_list;ne_list))
           , undelayed_attract(List1,List2)
           ).

undelayed_attract([],[]) if true.
undelayed_attract([(arg:Synsem,
                    realized:Realized)|Rest1],[(arg:Synsem,
                                                realized:Realized)|Rest2]) if attract(Rest1,Rest2).


% Kopiert die ARGUMENT-Werte einer Liste1 in eine Liste2 und markiert die Elemente
% von Liste1 als angezogen.
fun raise(+,-).
raise(List1,List2) if
       when( (List1=(e_list;ne_list);
              List2=(e_list;ne_list))
           , undelayed_raise(List1,List2)
           ).

undelayed_raise([],[]) if true.
undelayed_raise([(arg:Synsem,
                  realized:Realized,
                  raised:plus)|Rest1],[(arg:Synsem,
                                        realized:Realized)|Rest2]) if raise(Rest1,Rest2).



fun list_of_raised_arguments(-).

%list_of_raised_arguments(L) if !.      % for debugging

list_of_raised_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_raised_arguments(L) ).

undelayed_list_of_raised_arguments([]) if true.
undelayed_list_of_raised_arguments([raised:plus|T]) if
   list_of_raised_arguments(T).


% In inkohärenten Konstruktionen werden nur die nicht realisierten
% Argumente angezogen.
fun attract_unrealized(+,-).
attract_unrealized(List1,List2) if
       when( List1=(e_list;ne_list)
           , undelayed_attract_unrealized(List1,List2)
           ).

undelayed_attract_unrealized([],[]) if true.
undelayed_attract_unrealized([(realized:(minus,
                                         Realized),
                               arg:Synsem,
                               raised:plus)|Rest1],[(realized:Realized,
                                                     arg:Synsem)|Rest2]) if attract_unrealized(Rest1,Rest2).

% Bereits realisierte Argumente werden nicht angehoben.
% Das ist für die inkohärente Konstruktion wichtig.
undelayed_attract_unrealized([(realized:plus,
                               raised:minus)|Rest1],Rest2) if attract_unrealized(Rest1,Rest2).



% only the arguments can be IDIOMATIC+
headed_struc *> head_dtr:synsem:loc:idiomatic:minus.

head_initial := (head_dtr:HD,
                    non_head_dtrs:NHDs,
                    dtrs:[HD|NHDs]).

head_final := (head_dtr:HD,
                  non_head_dtrs:NHDs,
                  dtrs:append(NHDs,[HD])).


head_final_binary := (head_dtr:HD,
                         non_head_dtrs:[NHD],
                         dtrs:[NHD,HD]).


