% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%          $File: german-maltese-lexrules.pl $
%%      $Revision: 280 $
%%          $Date: 2008-01-11 15:00:27 +0100 (Fr, 11 Jan 2008) $
%%         Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%% $LastChangedBy: stefan $
%%        Purpose: Lexical rules that are identical for German and Maltese
%%       Language: Trale
%          System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.
:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile lex_rule/2.
:- discontiguous lex_rule/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.

infl_lr *>
  dtrs:[root_or_stem].      % Will be changed back to stem, once the proper morphology for Maltese verbs is in place.

% stem entries are usually underspecified with respect to their later use as predicative
% or attributive use. The HEAD value of the inflected form is just taken over from the stem.
% In the case of scopal adjectives like `alledged' there is only an attributive form. The
% HEAD value of such adjectives is specified in the lexical items.
% This underspecification approach does not work for languages that do not have adjective
% inflection. Therefore we state the sharing here as language class particular constraint.
% Languages that map fully inflected predicative forms to attributive ones have to constrain
% the HEAD values of the input and output independently.

attr_adj_lr *>
(synsem:loc:cat:head:Head,
 dtrs:hd:synsem:loc:cat:head:Head).


% non-native adjectives in Maltese are subtype of this type, but not of infl_lr.
attr_adj_infl_lr *>
  dtrs:[stem].

  
% This is not nice, but I treat copulaless sentences as direct head specifier combinations.
% Therefore Maltese adjectives have something in SPR and German adjectives don't.
% German
%attr_adj_infl_lr *>
% (synsem:loc:cat:spr:Spr,
%  dtrs:hd:synsem:loc:cat:spr:Spr).

% Maltese
%attr_adj_infl_lr *>
% (synsem:loc:cat:(head:subj:Subj,
%                  spr:[]),
%  dtrs:hd:synsem:loc:cat:spr:Subj).


prd_adj_infl_lr *>
(%complex_word,
 @sem_identical_lr,
 synsem:(loc:cat:(head:(Head,
                         prd_adj),
                  spr:Spr,
                  subcat:Subcat),
         nonloc:Nonloc,
         lex:Lex,
         trace:Trace),
 dtrs:[(stem,
        synsem:(loc:cat:(head:(Head,
                               adj),
                         spr:Spr,
                         subcat:Subcat),
                nonloc:Nonloc,
                lex:Lex,
                trace:Trace))]
 ).

