% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: core-syntax-spirits.pl,v $
%%  $Revision: 302 $
%%      $Date: 2008-04-21 17:24:18 +0200 (Mo, 21 Apr 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Case assignment for all nominative-accusative
%%             languages.
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile (if)/2.
:- discontiguous (if)/2.
:- multifile (fun)/1.
:- discontiguous (fun)/1.



% What about finite verbs in Maltese and Chinese? 26.03.2007


% Das ist die erste Version gewesen, leider ist sie aber mit der scheinbar mehrfachen Vorfeldbesetzung
% nicht kompatibel. Wenn die MVF als Instanz der kohärenten Konstruktion analysiert werden soll, dann
% ist es für die Analyse von Sätzen wie (1) nötig, die Anhebung von Argumenten eines finiten Verbs zuzulassen.
%
% (1) Der Frau das Buch gibt er nicht.
%
%(word,
% synsem:loc:cat:head:vform:fin) *> synsem:loc:cat:subcat:list_of_non_raised_arguments.

% Bei der folgenden Formulierung wird der raised-Wert erst festgelegt, wenn das Verb in einer
% syntaktischen Struktur verwendet wird.

% head_dtr:(%(complex_word;
%           %  simple_word),
%           complex_word,
%            % word, % should be sufficient, seems to be a TRALE bug.
%           phon:ne_list, % sonst würde die finite Spur im Vorfeld die Anhebung eines Arguments nicht gestatten.
%                         % Leider wird die Implikation somit auch nicht auf die Verbspur in der rechten Satzklammer
%                         % im Hauptsatz angewendet. Deshalb muß die Beschränkung noch mal extra in der
%                         % Lexikonregel für die Bewegung des finiten Verbs formuliert werden.

%           synsem:loc:cat:head:vform:fin) *> synsem:loc:cat:subcat:list_of_non_raised_arguments.


% Even this is to general, since in Persian we have the progressive, in which a finite verb is embedded.
% So we add the cluster:minus constraint. [which is inappropriate for Danish ...] in Danish the constraint is
% included in the lexical rule that forms finite verbs.

/*

head_dtr:(%(complex_word;
          %  simple_word),
          complex_word,
           % word, % should be sufficient, seems to be a TRALE bug.
          phon:ne_list, % sonst würde die finite Spur im Vorfeld die Anhebung eines Arguments nicht gestatten.
                        % Leider wird die Implikation somit auch nicht auf die Verbspur in der rechten Satzklammer
                        % im Hauptsatz angewendet. Deshalb muß die Beschränkung noch mal extra in der
                        % Lexikonregel für die Bewegung des finiten Verbs formuliert werden.

          synsem:loc:cat:head:vform:fin)) *> synsem:loc:cat:subcat:list_of_non_raised_arguments.

*/

fun assign_case_verb(-).

%assign_case_verb(_) if !,prolog((write(yes-yes),nl)),true. % for debugging we can disable case assignment here.

% Da Spuren auch Kasus zuweisen, muß man warten, bis die ARG-ST-Liste überhaupt instantiiert
% ist. Ansonsten, wäre klar, daß es immer ein Argument gibt und man könnte gleich mit
% assign_case_verb2 beginnen.

% Unfortunately the delaying is insufficient. If we have a cut after < NP[str], NP[lex] > the Danish
% examples of partial fronting Læst har Bjarne den ikke. do not work. The case assignment happens in
% "har Bjarne den ikke".  The presense of the pronoun "den" and the argument "Bjarne" instantiates
% the respective valency lists, but only when we know the verb, we know whether it assigns lexical
% or structural case. In order to do this properly, one would have to delay on the case type ...

assign_case_verb(List) if

% this can happen in languages that have weather verbs but no expletives.
% and with the participle of intransitive verbs.
       when( List=e_list, true),
       
       when( List=ne_list
           , assign_case_verb2(List)).

assign_case_verb2([]) if true.

assign_case_verb2([(H,
                    arg:loc:cat:head:Head,
                    raised:R)|T]) if
            when( (Head=(str_case_head;no_str_case_head),
                      R=(plus;minus),
                      T=e_list) % [H]
                , undelayed_assign_case_verb([H])
                ),
            when( (Head=(str_case_head;no_str_case_head),
                      R=(plus;minus),
                      T=ne_list)                  
                , (T=[arg:loc:cat:head:Head2|T2],
                      when((Head2=(str_case_head;no_str_case_head),
                            T2=e_list) % [H,H2]
                          ,undelayed_assign_case_verb([H|T])),
                      when((Head2=(str_case_head;no_str_case_head),
                            T2=ne_list) % [H,H2,H3|_]
                          ,(T2=[arg:loc:cat:head:Head3|T3],
                            when((Head3=(str_case_head;no_str_case_head),
                                  T3=(e_list;ne_list)) % we know that we are [H,H2,H3] or [H,H2,H3,...]
                                ,undelayed_assign_case_verb([H|T])))))).
           

% If arguments are raised, no case is assigned.
undelayed_assign_case_verb([raised:plus])      if !.
undelayed_assign_case_verb([raised:plus|Rest]) if assign_case_verb(Rest).

% If arguments are not raised, NPs with structural case get nominative or accusative depending on their position in the ARG-ST list.

% The last NP with structural case gets nominative.
undelayed_assign_case_verb([(raised:minus,
                             @n_str,
                             arg:loc:cat:head:case:morph_case:nom)])  if !.

% Persian verbal nouns have a determiner in SPR. Since Maltese (still) has the subject under SPR,
% the SPR is appended to the list of NPs that get assigned case. Therefore the subject is on second position.
% This clearly is not nice ... St. Mü. 12.01.2008
% This also applys to specificational structures in Danish and English.
% < NP[str], XP >
% Ein Aufsatz wurde ihm zu lesen erlaubt.
% < NP[str], NP[lex] >
undelayed_assign_case_verb([(raised:minus,
                             @n_str,
                             arg:loc:cat:head:case:morph_case:nom),arg:loc:cat:head:no_str_case_head])  if !. %,prolog((write('nom,no_str_case_head'),nl)).



/*
Die werden ja unten erledigt.

% Nouns that are parts of verbal clusters get lexical case.
% They are unsaturated. The following clause accounts both for regular NPs
% with lexical case and for nouns that are part of predicate complexes.
% < NP[lex] >
undelayed_assign_case_verb([(raised:minus,
                             @n_lex)])                                        if !.
% < XP >
undelayed_assign_case_verb([(raised:minus,
                             @no_compl_noun)])                                if !.

*/

% Alle anderen NPen mit strukturellem Kasus bekommen Akkusativ.
% Es muß noch mindestens ein Element in der Valenzliste geben, daß
% nicht durch Passivierung blockiert ist (realized:bool = nicht realized:blocked).
% Für dieses werden die obigen Klauseln angewendet.
% < NP[str], NP[str] | Rest >
undelayed_assign_case_verb([(raised:minus,
                             @n_str,
                             arg:loc:cat:head:case:morph_case:acc),(Nom,
                                                                    @n_str)|Rest])  if assign_case_verb([Nom|Rest]).
% Er verspricht ihm das lied zu singen.
% < NP[str], NP[lex], NP[str] | Rest >
undelayed_assign_case_verb([(raised:minus,
                             @n_str,
                             arg:loc:cat:head:case:morph_case:acc),@n_lex,
                                                                   (Nom_or_Acc,
                                                                    @n_str)|Rest])  if assign_case_verb([Nom_or_Acc|Rest]).


% < NP[lex]/XP | Rest >
undelayed_assign_case_verb([(raised:minus,
                             arg:loc:cat:head:no_str_case_head)|Rest])              if assign_case_verb(Rest).




