% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: particle-verb-lexrules.pl,v $
%%  $Revision: 280 $
%%      $Date: 2008-01-11 15:00:27 +0100 (Fr, 11 Jan 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: German grammar
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile (if)/2.
:- discontiguous (if)/2.
:- multifile (fun)/1.
:- discontiguous (fun)/1.
:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile (lex_rule)/2.
:- discontiguous (lex_rule)/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.



transparent_particle_verb_lr *>
(%stem,
 @rels_hcons_identical_lr,
 synsem:(loc:(cat:(head:Head,
                   spr:Spr,
                   arg_st:[(@argument,
                           arg:
                           (loc:(cat:(head:(part,
                                            subj:ParticleSubj,
                                            mod:InputSynsem),
                                      subcat:ParticleSubcat),
                                 cont:ParticleCont),
                            lex:plus))
                          |append(append(ParticleSubcat,ParticleSubj),InputSubcat)]),
              cont:ParticleCont),
                   % nucleus:non_psoa_rel)),        % Diese Beschränkung ist nur aus technischen Gründen hier.
                                       % Sie sorgt dafür, daß die Adjektivflexionsregel für skopale
                                       % Adjektive nicht angewendet wird. Die Information über den
                                       % semantischen Beitrag ist in der Grammatik erst nach der Kombination
                                       % mit der Verbpartikel bekannt, aber das Adjektiv wird vorher gebildet,
                                       % ohne mit irgendwelchen Partikeln kompatibel zu sein, ist also unnütz.
                                       %
                                       % Das Laden hat sich von 3 min 11 sec auf  2 min 38 sec verkürzt.
                                       % Statt 3410 Lexikoneinheiten wurden nur 3298 erzeugt.
        
         nonloc:Nonloc,
         lex:Lex,
         trace:Trace),
 zu:Zu,
 infl:Infl,
 dtrs:[(stem,
        synsem:(InputSynsem,
                loc:cat:(head:(Head,
                               verb),
                         spr:Spr,
                         arg_st:(InputSubcat,
                                 [arg:lex:minus])  % Das schränkt die Eingabe auf intransitive Verben ein.
                                                   % Diese Beschränkung ist linguistisch nicht nötig, da
                                                   % sie außerdem von den Partikeln (MOD) kommt. Ohne diese
                                                   % Beschränkung wird allerdings unnötig ein riesiges Lexikon erzeugt.
                        ),
                nonloc:Nonloc,
                lex:Lex,
                trace:Trace),
        zu:Zu,
        infl:Infl)]
 ).



transparent_particle_verb_lr ##
  Dtr
 **>
( transparent_particle_verb_lr,
  dtrs:[Dtr])
morphs
  X becomes X.



% Die Analyse der Partikelverben so, wie sie im Buch beschrieben ist,
% sieht vor, daß der Verbstamm flektiert und erst danach mit der Partikel
% kombiniert wird. Da es Lexikoneinträge für Partikeln gibt und da
% Trale keine eigene Morphologiekomponente hat, die eine Kombination
% von Wörtern zu neuen Wörtern erlaubt, muß man die Kombination mit
% Lexikonregeln nachbauen, die die Information der Lexikoneinträge
% für die Partikel einschließen.
% Dazu wird der lexikalische Typ der ersten Tochter spezifiziert (particle).
% Für diesen Typ gibt es eine disjunktive Spezifikation aller Verbpartikel
% (siehe lexicon.pl).

% Die Kombination kann nicht vom Typ head_cluster_phrase sein, da die
% Töchter von Phrasen in Bezug auf `zu' vollständig sein müssen.
% Das ist aber für Fälle wie `anzulachen' nicht gegeben, denn das `zu'
% wird durch die Lexikonregel eingeführt.

% Eigentlich sollte cluster_word ein Untertyp von cluster_structure sein,
% aber aus irgendwelchen Gründen, die ich nicht durchschaue, interagiert
% das mit der bar-Derivations-LR und Trale hängt sich auf.


% Da die Lexikonregel die Arbeit eines Schemas übernimmt, muß sie
% auch die Ergebnisse von Beschränkungen einbauen, die für Schemata gelten
% würden. Dazu zählt die Spezifikation des DSL-Werts bei phonologisch gefüllten
% Töchtern.

head_cluster_word *>
(%complex_word,
 synsem:(loc:(cat:(head:Head,
                   spr:Spr,
                   subcat:[(raised:Raised,
                            realized:plus,
                            arg:Arg)|Subcat]),
              cont:Cont),
         nonloc:Nonloc,
         lex:Lex,
         trace:Trace),
 rels:append(PRels,VRels),
 subtract_rels:SR,
 h_cons:append(PHCons,VHCons),
 dtrs:[(particle,
        synsem:Arg,
        rels:PRels,
        h_cons:PHCons),
       (word,
        synsem:(loc:(cat:(head:(Head,
                                major,        % otherwise it would apply to coordinations too.
                                              % The complement of the conjunction is unspecified.
                                              % St. Mü. 11.06.2010
                                dsl:none),
                          spr:Spr,
                          subcat:[(raised:Raised,
                                   realized:minus,
                                   arg:Arg)|Subcat]), % Das erste Element ist die Partikel. Das wird abgebunden.
                     cont:Cont),
                nonloc:Nonloc,
                lex:Lex,
                trace:Trace),
        rels:VRels,
        subtract_rels:SR,
        h_cons:VHCons)]
).


% für fin-, bse- und ppp-Formen = anlachst, anlachen, gelacht
% für Adjektive und Nomina
head_cluster_word_fin_bse_ppp_lr ##
 (zu:(Zu,
      minus),
  Dtr)
**>
(head_cluster_word,
 dtrs:[phon:[a_ ParticlePhon],
       Dtr],
 zu:Zu)
morphs
  X becomes (ParticlePhon,X).


% für inf-Formen = anzulachen
head_cluster_word_inf_lr_hack ##
 (zu:plus,
  Dtr)
**>
(head_cluster_word,
 dtrs:[phon:[a_ ParticlePhon],
       Dtr],
 zu:minus)
morphs
  X becomes (ParticlePhon,zu,X).
