% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%          $File: german-maltese-lexrules.pl $
%%      $Revision: 94 $
%%          $Date: 2007-03-26 17:16:20 +0200 (Mon, 26 Mar 2007) $
%%         Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%% $LastChangedBy: stefan $
%%        Purpose: Macros that are identical for German and Maltese
%%       Language: Trale
%          System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile (if)/2.
:- multifile (fun)/1.


% languages that embedd a VP under the auxiliary (Danish, English)


incoherent_verb_embedding_le :=
  (incoherent_verb_le,
   synsem:loc:cat:arg_st:hd:(@argument,
                             arg: loc:cat:(head:(verb,
                                                 subj:[]),
                                %              spr:ne_list,
                                           subcat:list_of_non_raised_arguments))).


% like German, but always incoherent, that is, we select a VP

% for Danish and English all auxiliaries are alike. This is not true for German, since the passive
% auciliary behaves differently there: It is not a subject raising verb.

aux_verb :=
 (@event_verb_le,
  @incoherent_verb_embedding_le,
  @scopal_raising_verb_le,
  @spr_raising_verb_le,
  synsem:loc:cat:(head:aux:plus,
                  arg_st:hd:arg:(loc:cat:unioned:plus,
                                 left_adj_:minus))). % This excludes adjuncts inbetween an auxiliary
                                                    % and the VP that it embedds.

/*

For German, there is a generalization to be captured regarding participles:
They construct always coherently. For English and Danish we just have the
form of the governed verb and the relation contributed by the auxiliary.

*/


perf_inf_verb :=
  (@raising_verb,
   @verbal_complement_le,
   synsem:loc:cat:arg_st:hd:arg:loc:cat:head:vform:perf).

perfect_aux_verb :=
 (@aux_verb,
  rels:[pred: (a_ perfect)]).

perf_perfect_aux_verb :=
 (@perfect_aux_verb,
  @perf_inf_verb).


subj_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:arg_st:[(@argument,
                          arg:loc:cat:head:subj:Subj)
                        |(raise(Subj),
                          tl:e_list)]).

spr_raising_verb_le :=
 (@raising_verb_le,
  synsem:loc:cat:(subcat:tl:e_list,                         % This constraint is here for efficiency reasons only.
                                                            % It ensures that the SUBCAT list is closed. Otherwise the SUBCAT list
                                                            % would be a variable until the VP is combined with the auxiliary. But before this
                                                            % a huge amount of combinations is build up since everything can be combined with the aux verb.
                                                            % St. Mü. 25.02.2012
                  arg_st:[(@argument,
                           arg:loc:cat:spr:Spr)
                         |raise(Spr)
%                           list_with_at_least_one_element          
                          ])).



% Used by the copula, which attracts both shifted pronouns and subjects. St. Mü. 25.04.2012
spr_and_subj_raising_verb_le :=
(@raising_verb_le,
  synsem:loc:cat:(subcat:tl:e_list,                         % This constraint is here for efficiency reasons only.
                                                            % It ensures that the SUBCAT list is closed. Otherwise the SUBCAT list
                                                            % would be a variable until the VP is combined with the auxiliary. But before this
                                                            % a huge amount of combinations is build up since everything can be combined with the aux verb.
                                                            % St. Mü. 25.02.2012
                  arg_st:[(@argument,
                           arg:loc:cat:(head:subj:Subj,
                                        spr:Spr))
                         |append(raise(Spr),raise(Subj))
%                           list_with_at_least_one_element          
                          ])).


ppp_passive_aux_verb :=
 (@ppp_inf_verb,
  @passive_aux_verb).


agentive_passive_aux_verb :=
 (@ppp_passive_aux_verb,
  rels:[pred: (a_ agentive_passive)]).

/*
This is wrong, since SPR may contain pronouns.
da_blocking_verb_infl_lr *>
  synsem:loc:cat:(xarg:Xarg,
                  spr:Xarg).
*/      



aux_verb(VForm,Pred) :=
 (@aux_verb,
  synsem:loc:cat:arg_st:hd:arg:loc:cat:head:vform:VForm,
  rels:[pred:Pred]).


modal_verb :=
 (@event_verb_le,
  @incoherent_verb_embedding_le,
  @subj_control_verb,
  synsem:loc:cat:(head:aux:minus,
                  arg_st:[_,_])).



% let and perception verbs
% lassen, sehen, hören
aci_verb :=
 (@bse_inf_verb,
  @scopal_raising_verb_le,
  @incoherent_verb_embedding_le,
  synsem:loc:cat:arg_st:[arg:loc:cat:xarg:[(Subj,
                                            @np_str)]     % The specification as np_str is not
                                                          % necessary for linguistic reasons since
                                                          % this follows from the fact that all
                                                          % embedded verbs have a subject with
                                                          % structural case. But we have to specify
                                                          % it for efficiency reasons since without
                                                          % this specification we would either have
                                                          % an undetermined list which causes an
                                                          % enourmous amount of combinations, or we
                                                          % would have the case prinicple fire and
                                                          % cause lexical items with subjects with
                                                          % lexical case or non-NPs. By the way: Can
                                                          % we have verbs with non-nominal subjects
                                                          % in AcI constructions?     St. Mü. 09.03.2012

                                                          % 2 min 20.650 sec CPU time. 313 passive edges ->
                                                          % 1 min 13.690 sec CPU time. 148 passive edges
                                                          % for jeg hørte manden  sove.
                        
                        |append(raise([Subj]),[@np_str(Ind)])],
  rels:[arg1:Ind]).




/*
% If modal verbs can raise negation and pronouns
modal_verb :=
 (@event_verb_le,
  @incoherent_verb_embedding_le,
  @subj_control_verb,
  @spr_raising_verb_le,
  synsem:loc:cat:head:aux:minus).
*/


/*

selected verb form is language specific: wants to read, viller læse

modal_verb(Relation) :=
 (@modal_verb,
  rels:[pred:Relation]).

*/