% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: clitic-lexrules.pl,v $
%%  $Revision: 145 $
%%      $Date: 2007-05-23 13:46:16 +0200 (Wed, 23 May 2007) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%%     System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile if/2.
:- multifile ':='/2.
:- discontiguous ':='/2.

:- multifile lex_rule/2.
:- discontiguous lex_rule/2.

:- multifile '*>'/2.
:- discontiguous '*>'/2.








% enclise
do_or_io_clitic_lr *>   @head_initial.

       

% Direct object clitisation
do_clitic_lr ##
( 
  Dtr
) 
 **>
( do_clitic_lr,
  dtrs:[Dtr,phon:[a_ CliticPhon]])
morphs
  (X,V) becomes (X,V,h) when (vowel(V),    CliticPhon=hu), %  n-ara-h
  (X,C) becomes (X,C,u) when (consonant(C),CliticPhon=hu), %  n-hobb-u
  (X)   becomes (X,CliticPhon).                            % covers all other clitics


       

% indirect object clitisation
io_clitic_lr ##
( 
  Dtr
) 
 **>
( @io_clitic_lr,
  dtrs:[Dtr,phon:[a_ CliticPhon]])
morphs
  X becomes (X,lu) when CliticPhon=hu, % u is used after a consonant. `l' is one.
  X becomes (X,l,CliticPhon).          % covers all other clitics

do_io_clitic_lr *> @head_initial.


do_io_clitic_lr ##
( 
  Dtr
) 
 **>
( do_io_clitic_lr,
  dtrs:[Dtr,phon:[a_ CliticPhon1],phon:[a_ CliticPhon2]])
morphs
  % mappings for the first clitic = hu and the second = hu
  (X,V) becomes (X,V,h,lu)             when (vowel(V),    CliticPhon1=hu, CliticPhon2=hu),
  (X,C) becomes (X,C,u,lu)             when (consonant(C),CliticPhon1=hu, CliticPhon2=hu),

  
  % mappings for the first clitic =/= hu and the second = hu
  X becomes (X,CliticPhon1,lu)         when CliticPhon2=hu, % u is used after a consonant. `l' is one.

  % mappings for the first clitic = hu and the second =/= hu
  (X,V) becomes (X,V,h,l,CliticPhon2)             when (vowel(V),    CliticPhon1=hu),
  (X,C) becomes (X,C,u,l,CliticPhon2)             when (consonant(C),CliticPhon1=hu),

  
  % mappings for both clitics different from hu
  X becomes (X,CliticPhon1,l,CliticPhon2).                      % covers all other clitics


/*
% Direct object clitisation
% hu is used iff an io marker follows.
% According to Fabri93a only 3sgmas DO clitics are possible if an IO clitic follows.
% Fabri attributes this to the possability to stress certain clitics. Only hu and
% have this property.
% The ultimate analysis has to refer to this property. For now I introduce both clitics
% simultaneously. This ensures the right order and makes bookkeeping features unnecessary.

do_clitic_lr(Per,Num,Gen) :=
 (synsem:loc:cat:subcat:append(Rest,[(arg:Argument,
                                      raised:Raised,
                                      realized:plus)]),
  rels:tl:hd:(lbl:PronLBL,
              arg0:Ind),
  dtrs:[synsem:loc:cat:subcat:append(Rest,[(arg:(Argument,
                                                 loc:cont:ltop:PronLBL),
                                            % This allows for objects of prepositions, which have lexical case,
                                            % and objects of verbs, which have structural case.
                                            arg:loc:cat:head:case:morph_case:acc,
                                            @np((Ind,
                                                 per:Per,
                                                 num:Num,
                                                 gen:Gen)),
                                            @pro_np_ref,
                                            raised:Raised,
                                            realized:minus)]) ]).

do_io_clitic_lr ##
( 
  Dtr
) 
 **>
( do_clitic_lr,
  dtrs:[Dtr])
morphs
  X becomes (X,hu).





io_clitic_lr(Per,Num,Dtr) :=
 (clitic_lr,
  synsem:loc:cat:subcat:append(FirstPart,append([(arg:Argument,
                                                  raised:Raised,
                                                  realized:plus)],LastPart)),
  rels:tl:hd:(lbl:PronLBL,
              arg0:Ind),
  dtrs:[(Dtr,
         synsem:loc:cat:subcat:append(FirstPart,append([(arg:(Argument,
                                                              loc:cont:ltop:PronLBL),
                                                         @np(dat,(Ind,
                                                                  per:Per,
                                                                  num:Num),anything),
                                                         @pro_np_ref,
                                                         raised:Raised,
                                                         realized:minus)],LastPart))) ]).

% `l' is the dative marker `i' is first person singular
% Peterson: ta-w=hu=l=i   'Sie gaben ihn (= das Buch) mir.'
io_clitic_lr ##
( 
  Dtr
) 
 **>
@io_clitic_lr(first,sg,Dtr)
morphs
  X becomes (X,li).

% Fabri93a:41: ta-ni l-ktieb = gave-me df-book
io_clitic_lr ##
( 
  Dtr
) 
 **>
@io_clitic_lr(first,sg,Dtr)
morphs
  X becomes (X,ni).


% ta-k il-ktieb = gave-you df-book
io_clitic_lr ##
( 
  Dtr
) 
 **>
@io_clitic_lr(second,sg,Dtr)
morphs
  X becomes (X,k).

*/

