% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexicon.pl,v $
%%  $Revision: 190 $
%%      $Date: 2007-06-16 12:51:22 +0200 (Sat, 16 Jun 2007) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%%     System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '--->'/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.


% Fabri93a: 62
dak  ~~> @demonstrative(sg,mas,demonstrative_q, a_ distal).
dik  ~~> @demonstrative(sg,fem,demonstrative_q, a_ distal).
dawk ~~> @demonstrative(pl,    demonstrative_q, a_ distal).

dan  ~~> @demonstrative(sg,mas,demonstrative_q, a_ proximal).
din  ~~> @demonstrative(sg,fem,demonstrative_q, a_ proximal).
dawn ~~> @demonstrative(pl,    demonstrative_q, a_ proximal).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% pronouns (Fabri93a:122)

% jien(a)
jien ~~> @unmarked_pers_pronoun(first, sg, human).

% int(i)
int  ~~> @unmarked_pers_pronoun(second, sg, human).

% hu(wa)
hu   ~~> @unmarked_pers_pronoun(third, sg, mas, anything).

% hi(ja)
hi   ~~> @unmarked_pers_pronoun(third, sg, fem, anything).
hija ~~> @unmarked_pers_pronoun(third, sg, fem, anything).

%
aħna ~~> @unmarked_pers_pronoun(first, pl, human).

% int(k)om
intom ~~> @unmarked_pers_pronoun(second, pl, human).

%
huma ~~> @unmarked_pers_pronoun(third, pl, anything).


% case marked forms of pronouns
% These forms correspond to lil + object clitic,
% but they always refer to humans, so this is not compositional,
% since clitics may refer to non-humans as well.
% Therefore the full forms are listed here. Fabri93a:122
lili  ~~> @marked_pers_pronoun(first, sg).


lilek ~~> @marked_pers_pronoun(second, sg).

lilu  ~~> @marked_pers_pronoun(third, sg, mas).

lilha ~~> @marked_pers_pronoun(third, sg, fem).

%
lilna  ~~> @marked_pers_pronoun(first,  pl).

lilkom ~~> @marked_pers_pronoun(second, pl).

lilhom ~~> @marked_pers_pronoun(third,  pl).


% proper nouns

albert ~~> @proper_noun(a_ albert,human).
pawlu  ~~> @proper_noun(a_ pawlu, human).

ingrid ~~> @proper_noun(a_ ingrid, human).
norma  ~~> @proper_noun(a_ norma,  human).


% these are nouns that keep their form in singular
ajruplan ~~> @noun(mas,   a_ airplain).

bieb   ~~> @noun(mas,   a_ door).

dinj  ~~> @noun(fem,   a_ world).

disk ~~> @noun(fem,   a_ record, human). % todo check translation

% check gender and translation
iskrivan ~~> @noun(genus, a_ employee, human).

ittr     ~~> @noun(fem,   a_ letter, info_bearer).

karozz ~~>  @noun(fem,   a_ car, vehicle).

komunist ~~> @noun(mas,   a_ communist,   human).

ktieb ~~> @noun(mas,   a_ book, thing). % plural kotb-a

mamm ~~> @noun(fem,   a_ mother, human).

mar   ~~> @noun(fem,   a_ woman, human).

mazzit ~~> @noun(fem,   a_ blutwurst, food).

nies  ~~> @noun(genus, a_ people, human),
          @pl_stem(a_ nies),
          synsem:loc:cont:ind:num:pl.

papa ~~> @noun(mas,   a_ pope, human). 

papà ~~> @noun(mas,   a_ father, human).

president ~~> @noun(mas,   a_ president,   human).

raġel ~~> @noun(mas,   a_ man).
%ras   ~~> @noun(mas,   a_ head).

skol  ~~> @noun(fem,   a_ school).

tazz  ~~> @noun(fem,   a_ glas).

terrorist ~~> @noun(mas,   a_ terrorist,   human).

tifel ~~> @noun(mas, a_ boy).

tifl  ~~> @noun(fem, a_ girl).

vedut ~~> @noun(fem,   a_ view).

xkor  ~~> @noun(fem,   a_ sack).

zij   ~~> @noun(fem,   a_ aunt).

% Thomas Stolz
qtiel ~~> @noun(mas, a_ murderer).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% verbs


% send Fabri93a:104
bgħt ~~>  @tri_val_verb(a_ send_rel,human,    object, agentive),
          @perf_stem(a_ bagħat), 
          @imperf_stem(a_ bgħat). % ji statt i als Präfix

bs ~~> @bi_val_verb(a_ kiss_rel,agentive, object),
       @perf_stem(a_ bis),
       @imperf_stem(a_ imperfective_bis).

% come Fabri93a p. 18
ġie   ~~> @mono_val_verb(a_ come_rel,object),        % todo restricted to agentive? If so change test suite.
          @perf_stem(a_ ġie),
          @imperf_stem(a_ imperfective_ġie).


% jump Fabri93a:80
qbiż  ~~> @mono_val_verb(a_ jump_rel,agentive),
          @perf_stem(a_ qbiż),
          @imperf_stem(a_ imperfective_qbiż).
          

% see Fabri93a:102
r   ~~> @bi_val_verb(a_ see_rel,agentive, object),
        @perf_stem(a_ ra),    % Fabri93:114
        @imperf_stem(a_ ara).

% open Fabri93a:141
ftħ ~~> @bi_val_verb(a_ open_rel,agentive, thing),
        @perf_stem(a_ fetħ),
        @imperf_stem(a_ imperfective_fetħ).

% love Fabri93a:102
ħobb ~~> @bi_val_verb(a_ love_rel,agentive, thing),
         @perf_stem(a_ perfective_ħobb),             % todo
         @imperf_stem(a_ ħobb).

% write Peterson 
ktb ~~> @bi_val_verb(a_ write_rel,agentive, thing),
        @perf_stem(a_ kiteb),  % Fabri93a:130
        @imperf_stem(a_ iktib). % check Peterson

% eat Fabri93a:140
kl ~~> @bi_val_verb(a_ eat_rel,agentive, thing),
       @perf_stem(a_ kiel),
       @imperf_stem(a_ imperfective_kiel).

% catch
qabad ~~> @bi_val_verb(a_ catch_rel,agentive, object),
          @perf_stem(a_ perfective_qabad), % todo
          @imperf_stem(a_ imperfective_qabad).


% give Fabri93a:41
% ta-ni and ta-k take an accusative clitic, first attemt
% to get this right is to assume that ta assigns two accusatives.
% Thomas said something that this is the case only for clitics.
% check. St. Mü. 01.05.2007
ta    ~~> @tri_val_verb(acc,a_ give_rel,human, object, agentive),
          @perf_stem(a_ ta), % todo
          @imperf_stem(a_ imperfective_ta).


% buy Fabri93a:146
xtr ~~> @bi_val_verb(a_ buy_rel,agentive, object),
        @perf_stem(a_ xtra), % todo
        @imperf_stem(a_ imperfective_xtra).

xtr ~~> @tri_val_verb(a_ buy_rel,human, object, agentive),
        @perf_stem(a_ xtra), % todo
        @imperf_stem(a_ imperfective_xtra).


% wink Fabri93a:130
xr  ~~> @np_np_verb(dat,a_ wink_rel,agentive, agentive),
        @perf_stem(a_ xejjer),
        @imperf_stem(a_ imperfective_xejjer).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% adjectives

% native adjectives that inflect for gender

% Thomas Stolz: kiesaħ, kiesħa, ksieħ
kiesaħ ~~> @native_adj_stem(a_ brutal).
ġdid   ~~> @native_adj_stem(a_ new).               % pl ġodd-a
oħxon  ~~> @native_adj_stem(a_ thick).
sabiħ  ~~> @native_adj_stem(a_ nice). %, thing).
twil   ~~> @native_adj_stem(a_ big).
żgħir  ~~> @native_adj_stem(a_ klein). % Fabri93a:64

% Thomas Stolz
preżumtiv ~~> @native_scopal_adj_stem(a_ alledged).

% non-native adjectives that do not inflect for gender

intelliġenti ~~> @non_native_adj_stem(a_ intelligent).
arroganti    ~~> @non_native_adj_stem(a_ arrogant).
interessanti ~~> @non_native_adj_stem(a_ interesting).

%kannella     ~~> @non_native_adj_stem(a_ brown).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% prepositions


fuq ~~> @location_v_mod_prep(a_ on).

lil ~~> @lil_marker.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% adverbs

illum   ~~> @temp_adv(a_ today).
'''llum'    ~~> @temp_adv(a_ today).

% These are the object clitics.
% For prepositions one has to use the possessive clitics.
% They differ in first person singular:
% Instead of 'ni' one uses `i' and if the the preposition
% ends in a vowel, one takes `ja'. Example: bi-ja
clitic *>
 (
   (phon:[a_ ni],
    @clitic(acc,first,sg,genus),
    stressible:minus)
 ;
   (phon:[a_ i],
    @clitic(dat,first,sg,genus),
    stressible:minus)

%  todo: The vowel has to match the verb
 ; (( phon:[a_ ek]
    ; phon:[a_ k]
    ),
    @clitic(second,sg,genus),
    stressible:minus)

 ; (phon:[a_ hu],
    @clitic(third,sg,mas))

 ; (phon:[a_ ha],
    @clitic(third,sg,fem),
    stressible:minus)

 ; (phon:[a_ hie],
    @clitic(third,sg,mas),
    stressible:plus)


 ; (phon:[a_ na],
    @clitic(first,pl,genus),
    stressible:minus)

 ; (phon:[a_ kom],
    @clitic(second,pl,genus),
    stressible:minus)

 ; (phon:[a_ hom],
    @clitic(third,pl,genus),
    stressible:minus)
).



%test ~~> @e_copula.

%empty
%  @e_copula.


empty
  (@empty_determiner_word,
      ((synsem:loc:cat:head:spec:loc:cat:head:def:plus,
        rels:[udef_q])
      ;(synsem:loc:cat:head:spec:loc:cat:head:def:minus,
        rels:[some_q])
      )
  ).



empty 
   e_trace.



