% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexrules.pl,v $
%%  $Revision: 190 $
%%      $Date: 2007-06-16 12:51:22 +0200 (Sat, 16 Jun 2007) $
%%     Author: Stefan Mueller (Stefan.Mueller@fu-berlin.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%%     System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile if/2.
:- multifile ':='/2.
:- discontiguous ':='/2.

:- multifile lex_rule/2.
:- discontiguous lex_rule/2.

:- multifile '*>'/2.
:- discontiguous '*>'/2.

:- lex_rule_depth(5).

% This was intended to be used for the outer epentheis rules.
% prefix_lr :=
% (last:Last,
%  dtrs:[last:Last]).



/*
fin_verb_infl_lr := 
( %complex_word,
  @scoping_lextop_lr,
  @cat_identical_lr,
  @usually_shared_in_lr,  
  synsem:loc:cat:head:vform:fin,
  dtrs:hd:synsem:loc:cat:arg_st:list_of_non_raised_arguments).

  synsem:(loc:cat:(head:(Head,
                         subj:[],
                         vform:fin),
                   spr:Subj,
                   subcat:block_subject(Subcat,Subj),
                   marking:Marking,
                   def:Def),
          nonloc:Nonloc,
          trace:Trace),
  dtrs:[( root, % This will be 'stem' once we introduced a complete account of root to stem mapping.
                % currently the stems are just stored in the lexical representation.
          %stem,
          synsem:(loc:cat:(head:(Head,
                                 verb),
                           subcat:(list_of_non_raised_arguments,
                                   Subcat),
                           marking:Marking,
                           def:Def),
                  nonloc:Nonloc,
                  trace:Trace))]).

*/

/*
fin_verb_infl_lr *>
 (synsem:loc:cat:(marking:Marking,
                  def:Def),
     dtrs:[( root, % This will be 'stem' once we introduced a complete account of root to stem mapping.
                                % currently the stems are just stored in the lexical representation.
                                %stem,
             synsem:loc:cat:(marking:Marking,
                             def:Def))]).

*/

% real morphology is lacking right now.
% the rule just maps stems to words and puts the least oblique element
% with structural case under SPR.
reg_fin_verb_infl_lr *>
( %@fin_verb_infl_lr,
  rels:hd:Tense,
  affix:(Affix,
         fin_verb_i_affix,
         per:Per,
         num:Num,
         gen:Gen,
         tense:Tense),
  dtrs:[(synsem:loc:cat:arg_st:subj_verb_agreement((per:Per,num:Num,gen:Gen)),
         infl:affix_:Affix)]).    % This is needed due to a bug in Trale. Trale cannot access information in the output
                                  % of the LR therefore everything has to be present in the input as well.

/*
irreg_fin_verb_infl_lr *>
( @fin_verb_infl_lr ).
*/


fin_verb_infl_lr ##
( 
  Dtr,
  infl:(affix_:(fin_verb_i_affix,              % Das muß hier auch maximal spezifisch sein, da die Typinferenz, die
                                               % aus dem Vorhandensein von NUM und PER auf die Finitheit schließt,
                                               % erst angewendet wird, wenn die linke Regelseite angeguckt wird.
                prefix:plus,
                tense:Tense,
                phon:[(a_ AffixPhon)]),
        v_stems:Stems)
) 
 **>
( reg_fin_verb_infl_lr,
  dtrs:[Dtr])
if get_v_stem(Tense,Stems,a_ Stem)
morphs
  _X becomes (AffixPhon,Stem).

get_v_stem(  perfective,  perfective:Stem,Stem) if true.
get_v_stem(imperfective,imperfective:Stem,Stem) if true.

fin_verb_infl_lr ##
( 
  Dtr,
  infl:(affix_:(fin_verb_i_affix,              % Das muß hier auch maximal spezifisch sein, da die Typinferenz, die
                                               % aus dem Vorhandensein von NUM und PER auf die Finitheit schließt,
                                               % erst angewendet wird, wenn die linke Regelseite angeguckt wird.
                prefix:minus,
                tense:Tense,
                phon:[(a_ AffixPhon)]),
        v_stems:Stems)
) 
 **>
( reg_fin_verb_infl_lr,
  dtrs:[Dtr])
if get_v_stem(Tense,Stems,a_ Stem)
morphs
  _X becomes rajt   when (Stem=ra,   AffixPhon=t), % This is a hack. Todo: Find out the real conditions.
  _X becomes tajt   when (Stem=ta,   AffixPhon=t), % This is a hack. Todo: Find out the real conditions.
  _X becomes xtrajt when (Stem=xtra, AffixPhon=t), % This is a hack. Todo: Find out the real conditions.
  _X becomes kielet when (Stem=kiel, AffixPhon=t),
  _X becomes fetħit when (Stem=fetħ, AffixPhon=t),
  _X becomes bisit  when (Stem=bis,  AffixPhon=t),
  _X becomes (Stem,AffixPhon).





noun_infl_lr :=
(infl_lr,
 @sem_identical_lr,
 synsem:Synsem,
 dtrs:[synsem:(Synsem,
               loc:cat:head:noun)]).

reg_noun_infl_lr :=
 (@noun_infl_lr,
  synsem:loc:cont:ind:(gen:Genus, 
                       num:Num),
  affix:(noun_i_suffix,
         num:Num,
         gen:Genus)).

irreg_noun_infl_lr :=
 (@noun_infl_lr,
  synsem:loc:cont:ind:num:pl).

reg_noun_infl_lr ##
 (%infl:pl_stem:(a_ none), % BUG in neww TRALE?
   Dtr)
**>
(@reg_noun_infl_lr,
 affix:phon:[a_ Suffix],
 dtrs:[Dtr])
morphs
  X becomes (X,Suffix).

irreg_noun_infl_lr ##
 (infl:pl_stem:(a_ PlStem),
   Dtr)
**>
(@irreg_noun_infl_lr,
 dtrs:[Dtr])
%if prolog((write('Stem: '),write(PlStem),nl))
morphs
  _X becomes PlStem when PlStem \= none.


% We map a indefinite noun or adjective onto one
% that is marked definite. The input/output specifications
% also exclude recursion.
definiteness_lr *>
 (@sem_identical_lr,
%  @prefix_lr,
  %complex_word,
  synsem:(loc:cat:(head:Head,
                   def:plus,
                   spr:Spr,
                   subcat:Subcat,
                   marking:Marking),
          nonloc:Nonloc,
          trace:Trace),
  dtrs:[(word,
         synsem:(loc:cat:(head:(adj_or_noun,
                                Head),
                          def:minus,
                          spr:Spr,
                          subcat:Subcat,
                          marking:(Marking,
                                   unmarked)),
                 nonloc:Nonloc,
                 trace:Trace))]).



% Fabri93a:41
% Je nach phonologischer Umgebung ist /l/ den phonologischen Prozessen
% der /i/-Epenthese und Assimilation unterworfen. Es gibt zwei Formen der /i/-Epenthese:
% eine äußere und eine innere. Die äußere Epenthese findet statt, wenn das Wort,
% an das affigiert wird, mit einem Konsonanten anfängt und kein auf ein Vokal endendes Wort
% vorausgeht.

% Innere Epenthese findet statt, wenn das Wort, an das affigiert wird, mit einem /s/ oder
% /ʃ/ beginnt.
%
% l-iskola l-ixkora

% Schließlich findet eine progressive Assimilation statt, wenn das nachfolgende Wort mit den koronalen Lauten
% /d/, /t/, /s/, /z/, /ʃ/, /ts/, /tʃ/, /n/ oder /r/ beginnt. Interessant ist hier, dass /dʒ/ als einzieger koronaler
% Laut keine Assimilation auslöst.
%
% dinja id-dinja
% zija  iz-zija
% raġel ir-raġel

definiteness_lr ##
 Dtr
**>
(definiteness_lr,
 dtrs:[Dtr])
morphs
  (S,X) becomes (li,S,X)  when s_sh(S),     % l-iskola         inner epenthesis
  (C,X) becomes (C,C,X) when coronal(C),    % r-raġel          assimilation          `i' for ir-ragel is added later. I hope that r-raġel exists
  X becomes (l,X).                          % l-ktieb          

s_sh([s]).
s_sh([x]).
     
coronal([d]).
coronal([t]).
coronal([s]).
coronal([z]).
coronal([n]).
coronal([r]).

% This is the LR for outer epenthesis. It takes somethink definite
% as input and adds the `i'. This rule is optional. It should also
% reflect the restriction on the preceding word.

% lktieb -> ilktieb

% The rule cannot be itterated, since the output does not start with `l'.
% The rule does not apply to products of assimilation, since they start with
% `i' already.
% We have to test for two consonants, since the first one can be `l' or
% one of the consonants that are the result of assimilation. The rule is not allowed
% to apply to `lajruplan'.


definiteness_epenthesis_lr :=
 (complex_word,
  @sem_identical_lr,
  %@prefix_lr,
  synsem:(Synsem,
          loc:cat:(head:adj_or_noun,  % def:plus should be sufficient, but currently the DEF value of verbs etc is unscpecified
                   def:plus)),
%  previous:cons,
  dtrs:[synsem:Synsem]).

definiteness_epenthesis_lr ##
 Dtr
**>
(@definiteness_epenthesis_lr,
 dtrs:[Dtr])
morphs
  (C1,C2,X) becomes (i,C1,C2,X) when (consonant(C1),consonant(C2)).        % l-ktieb -> il-ktieb r-raġel -> ir-raġel        äußere Epenthese
vowel([a]).
vowel([e]).
vowel([i]).
vowel([j]).
vowel([o]).
vowel([u]).


consonant([b]).
consonant([c]).
consonant([ċ]).
consonant([d]).
consonant([f]).
consonant([g]).
consonant([ġ]).
consonant([h]).
consonant([ħ]).
consonant([j]).
consonant([k]).
consonant([l]).
consonant([m]).
consonant([n]).
consonant([p]).
consonant([q]).
consonant([r]).
consonant([s]).
consonant([t]).
consonant([v]).
consonant([w]).
consonant([x]).
consonant([y]).
consonant([y]).
consonant([ż]).



% object marking LR
obj_marking_lr :=
 (complex_word,
  @sem_identical_lr,
  synsem:(loc:(cat:(head:Head,
                    spr:Spr,
                    subcat:Subcat,
                    marking:marked,
                    def:Def),
               cont:Cont),
          nonloc:Nonloc,
          trace:Trace),
  dtrs:[(word,
         synsem:(loc:(cat:(head:(Head,
                                 case:morph_case:dat_or_acc),
                           spr:Spr,
                           subcat:Subcat,
                           marking:unmarked,
                           def:Def),
                      cont:(npro,                     % The rule should not be applied to pronouns.
                            Cont)),
                 nonloc:Nonloc,
                 trace:Trace),
         rels:hd: @not_(proper_q)  % lil Albert instead of lilalbert
        ) ]).




obj_marking_lr ##
 (Dtr,
  synsem:loc:cat:def:Def)
**>
(@obj_marking_lr,
 dtrs:[Dtr])
morphs
  (i,C,X) becomes (li,C,X) when (coronal(C),ale(Def=plus)),  % l-it-tifel           Fabri93a:114
  (i,X)   becomes (lil,X)  when ale(Def = plus),             % lil-l-mara           Fabri93a:114 -> l + il-mara
  X       becomes (lil,X)  when ale(Def = minus).            % check. I hope this is correct.




% The type attr_adj_lr is defined in Core-Grammar/attr-adj-lexrules.pl

% additional constraint for Maltese only.  
attr_adj_lr *>
 (synsem:loc:cat:(head:subj:Subj,
                  spr:[]),
  dtrs:hd:synsem:loc:cat:spr:Subj).

attr_adj_lr *>
 (synsem:loc:cat:def:Def,
  dtrs:hd:synsem:loc:cat:def:Def).

% Maltese only
native_attr_adj_infl_lr *>
(%infl_lr,
 synsem:loc:cat:head:mod:loc:cat:spr:[@arg(loc:cont:ind:(gen:Genus,     % this is wrong in German, but is there evidence
                                                                        % for GEN and NUM as head features of Dets?
                                                         num:Num))],
 affix:(adj_i_suffix,
        num:Num,
        gen:Genus),
 dtrs:[native_stem]).

native_attr_adj_lr ##
 Dtr
**>
(native_attr_adj_infl_lr,
 affix:phon:[(a_ Suffix)],
 dtrs:[Dtr])
morphs
  X becomes (X,Suffix).

non_native_attr_adj_lr ##
 Dtr
**>
(non_native_attr_adj_infl_lr,
 dtrs:[(non_native_stem,
        Dtr)])
morphs
  X becomes X.


% see also Core-Grammar/danish-german-maltese-lexrules.pl

prd_adj_infl_lr *>
 synsem:loc:cat:head:subj:[].

native_prd_adj_infl_lr *>
(%infl_lr,
 synsem:loc:cat:spr:[@arg(loc:cont:ind:(gen:Genus,
                                        num:Num))],
 affix:(adj_i_suffix,
        num:Num,
        gen:Genus),
 dtrs:[native_stem]).

native_prd_adj_lr ##
 Dtr
**>
(native_prd_adj_infl_lr,
 affix:phon:[(a_ Suffix)],
 dtrs:[Dtr])
morphs
  X becomes (X,Suffix).

non_native_prd_adj_lr ##
 Dtr
**>
(non_native_prd_adj_infl_lr,
 dtrs:[(non_native_stem,
        Dtr)])
morphs
  X becomes X.