% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $HeadUrl: maltese-macros.pl,v $
%%  $Revision: 362 $
%%      $Date: 2013-07-10 15:28:03 +0200 (Wed, 10 Jul 2013) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile 'if'/2.
:- multifile 'fun'/1.

demonstrative(Number,Genus,Quant-quant_rel,Pred) :=
 (@det(Quant,Pred),
  synsem:loc:cat:head:(spec:loc:cat:def:plus,
                       num:Number,
                       gen:Genus)).

demonstrative(Number,Quant-quant_rel,Pred) :=
   @demonstrative(Number,genus,Quant,Pred).


indefinite_art(Genus) :=
 (@det(some_q),
  synsem:loc:cat:head:(spec:loc:(cat:def:minus,
                                 cont:ind:sort:human),  % Fabri2001a:155
                       num:Number,
                       gen:Genus)).


% german-maltes-macros.pl
%
% % all nouns that take a specifier
% det_noun_stem *>
%  (stem,
%   @noun_le,
%   @non_rel_le,
%   synsem:loc:(cat:spr:[(@argument,
%                          arg:loc:cat:(head:det,
%                                       subcat:[] ))],
%               cont:ind:per:third)).

% The lexical entries in Maltese are not marked as definite,
% this is reflected by the determiner they select.
% This rules out "dik mara" where it should be "dik il-mara"
det_noun_stem *>
  synsem:loc:cat:def:minus.

% proper nouns cannot be combined with the definiteness marker.
proper_noun_word *>
  synsem:loc:cat:def:plus.


% Fabri93a:122

marked_pers_pronoun(Per,Num) :=
 (@pers_pronoun(Per,Num,human),
  synsem:loc:cat:(head:case:morph_case:dat_or_acc,
                  marking:marked)).

marked_pers_pronoun(Per,Num,Gen) :=
 (@pers_pronoun(Per,Num,Gen,human),
  synsem:loc:cat:marking:marked).

unmarked_pers_pronoun(Per,Num,Sort) :=
 (@pers_pronoun(Per,Num,Sort),
  synsem:loc:cat:(%head:case:morph_case:nom,        it depends on humanness whether the case is nominative or accusative, check
                  marking:unmarked)).

unmarked_pers_pronoun(Per,Num,Gen,Sort) :=
 (@pers_pronoun(Per,Num,Gen,Sort),
  synsem:loc:cat:marking:unmarked).


(root,
 synsem:loc:cat:head:verb) *>
 (synsem:loc:cat:(head:subj:[],
                  xarg:Subj,
                  spr:(Subj,
                       list_with_exactly_one_element),
                  subcat:Subcat,
                  arg_st:append(Subcat,Subj))).


% This should be more general for all non-nominal elements.
% Only adj and noun can be DEF+
verb_le *>
 synsem:loc:cat:def:minus.


lexical_verb_type :=
  verb_root.

% Do we need this?
lexical_event_verb_type :=
  event_verb_root.

event_verb_root *>
  @event_verb_le.


simple_adj_root :=
 (@simple_adj_le, 
  root).

adj_root(Relation) :=
 (@simple_adj_root,
  rels:[pred:Relation]).

adj_stem(Relation,PreModifier) :=
 (@adj_stem(Relation),
  synsem:loc:cat:head:pre_modifier:PreModifier).

native_adj_stem(Relation) :=
 (native_stem,
  @adj_stem(Relation,minus)).


non_native_adj_stem(Relation) :=
 (non_native_stem,
  @adj_stem(Relation,minus)).

native_scopal_adj_stem(Relation,PreModifier) :=
 (native_stem,
  synsem:loc:cat:head:pre_modifier:PreModifier,
  @scopal_adj_stem(Relation)).


non_dsl_argument := argument.

% German uses this for depictives.
v_modifier :=
  (@modifier,
   synsem:loc:cat:head:mod:loc:cat:head:verb).


prep_initial := plus.

location_v_mod_prep_word :=
 (@v_mod_prep_word,
  synsem:loc:cat:subcat:[ @np(acc,_Ind2) ]).

location_v_mod_prep(Relation) :=
 (@location_v_mod_prep_word,
  rels:[pred:Relation]).

/*

Not used.

% The effect of the lexical rule has to be replayed here,
% since Trale does not apply lexical rules to empty elements.
e_copula :=
 (irreg_fin_verb_infl_lr,
  phon:[],
  synsem:loc:cat:subcat:(list_of_non_raised_arguments,
                         [(@xp,              % This has to be stated for all copulas in Maltese, since there are no coherent constructions.
                           arg:trace:minus)]), % otherwise EFD computation does not terminate.
  rels:hd:pred: (a_ present),
  dtrs:[(@copula_verb_le,
         phon:[])]).


*/



definite_le :=
 synsem:loc:cat:def:plus.

unmarked := synsem:loc:cat:marking:unmarked.

% not used
cluster_minus_argument := argument.

% This is a hack. It ensures that `lil' is combined with proper nouns only.
% All other combinations of `lil' are done without a space by a lexical rule.
% St. Mü. 30.04.2007
(head_argument_phrase,
% phon:[a_ lil]                 does not work, Trale bug
  synsem:loc:cat:marking:marked
)
*> non_head_dtrs:hd:rels:tl:hd:proper_q.



% These constraints have to be formulated with respect to
% objects in syntactic structures, since otherwise we would say
% about the nouns that undergo lil marking that they are non_human
% (before marking) and human (after marking).
% The reference to verbal environments is necessary, since `lil'
% is selecting its argument like a verb. Without the verb specification
% in the antecedent the constraints would apply to `lil Pawlu' as well.

% Felix says this is similar in Spanish, but the generalizaton is wrong.
% Inanimates can be lil marked as well if otherwise ambiguity would be the
% result. check St. Mü. 14.05.2007

% Dative objects are always `lil' marked.
(head_argument_phrase,
 synsem:loc:cat:head:verb,
 non_head_dtrs:hd:synsem:loc:cat:head:case:morph_case:dat) *>
 non_head_dtrs:hd:synsem:loc:cat:marking:marked.

% Accusative objects are `lil' marked iff the referent is human.
(head_argument_phrase,
 synsem:loc:cat:head:verb,
 non_head_dtrs:hd:synsem:loc:(cat:head:case:morph_case:acc,
                              cont:ind:sort:human)) *>
 non_head_dtrs:hd:synsem:loc:cat:marking:marked.

(head_argument_phrase,
 synsem:loc:cat:head:verb,
 non_head_dtrs:hd:synsem:loc:(cat:head:case:morph_case:acc,
                              cont:ind:sort:non_human)) *>
 non_head_dtrs:hd:synsem:loc:cat:marking:unmarked.

(head_argument_phrase,
 synsem:loc:cat:head:verb,
 non_head_dtrs:hd:synsem:loc:cat:(head:case:morph_case:acc,
                                  marking:marked)) *>
 non_head_dtrs:hd:synsem:loc:cont:ind:sort:human.


(head_argument_phrase,
 synsem:loc:cat:head:verb,
 non_head_dtrs:hd:synsem:loc:cat:(head:case:morph_case:acc,
                                  marking:unmarked)) *>
 non_head_dtrs:hd:synsem:loc:cont:ind:sort:non_human.


% This is the alternative solution: the marking is specified in the lexicon.
% This doubles loading times of the lexicon and slightly increses parse times.
% To use these macros uncomment the respective lines in core-macros.pl
% 11.02.2008
bi_val_verb :=
  synsem:loc:cat:arg_st:hd:arg:loc:((cat:marking:unmarked,
                                     cont:ind:sort:non_human)
                                   ;(cat:marking:marked,
                                     cont:ind:sort:human)).

tri_val_verb :=
    synsem:loc:cat:arg_st:[arg:loc:cat:marking:marked,
                           arg:loc:((cat:marking:unmarked,
                                     cont:ind:sort:non_human)
                                   ;(cat:marking:marked,
                                     cont:ind:sort:human))|_].



lil_marker :=
 (simple_overt_word,
  @spr_saturated,
  @non_relational_le,
  @non_slashed_le,
  @non_clld_le,
  @non_que_le,
  @non_rel_le,
  @non_relativizer_le,
  @non_idiomatic_le,
  synsem:loc:(cat:(head:Head,
                   subcat:[(@argument_np,
                            arg:loc:(cat:(head:(Head,
                                                case:morph_case:dat_or_acc), % Nominatives are not `lil' marked.
                                          marking:unmarked),
                                     cont:(Cont,
                                           npro)))],   % the embedded NP may not be a pronoun, since these have lexicalized forms
                                                       % In addition this rules out the combination with clitics.
                                                       % St. Mü. 29.04.2007
                   marking:marked),
              cont:Cont)).
     






% adverbs can appear before or after their head.
v_mod_pre_modifier :=
  bool.

% adjuncts do not extract, they are just placed somewhere.
e_trace *>
  synsem:loc:cat:head:mod:none.


% not used
cluster_minus_synsem :=
  synsem.

% not used
dsl_none :=
  head.

