% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: syntax.pl,v $
%%  $Revision: 362 $
%%      $Date: 2013-07-10 15:28:03 +0200 (Wed, 10 Jul 2013) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: syntactic constraints that are special to Maltese.
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.

noun *> initial:plus.
verb *> initial:plus.

% This is not entirely correct. (p.c. Thomas Stolz, 2007), but without this constraint
% we get two readings for Jien xtrali ktieb sabiħ ilpapà.
% More information about the distribution of prenominal adjectives is needed.
mod_adj *> pre_modifier:minus.

headed_struc *>
 (synsem:loc:cat:marking:Marked,
  head_dtr:synsem:loc:cat:marking:Marked).


% Even in configurational languages that saturate the arguments from the end of the list,
% we have to use append here, since the SUBCAT list may start with realized elements (spirits),
% due to the lexical treatment of cliticization.


head_argument_phrase *>
 (synsem:loc:cat:subcat:append(FirstPart,
                               [(arg:NonHeadDtr,
                                 raised:Raised,
                                 realized:plus)|Rest]),
  head_dtr:synsem:loc:cat:subcat:append(FirstPart,
                                        [(arg:NonHeadDtr,
                                          raised:Raised,
                                          realized:minus)|(Rest,
                                                           list_of_spirits)]),
  non_head_dtrs:[synsem:(NonHeadDtr,
                         loc:cat:(head:major,                 % excludes determiners in EFD computation.
                                  subcat:list_of_spirits))]). % Maltese does not allow complex predicate formation (I hope). St. Mü. 13.05.2007


% Generalization 1 in Fabri93a:43:
% if the noun in an attributive construction is indefinite,
% the adjective has to be indefinite as well.

% As Fabri states there seems to be a deeper semantic explanation for this,
% but for the time beeing it is stipulated as a syntactic constraint here.
(head_adjunct_phrase,
 head_dtr:synsem:loc:cat:def:minus,
 non_head_dtrs:hd:synsem:loc:cat:head:adj) *> non_head_dtrs:hd:synsem:loc:cat:def:minus.

% Initial definite adjectives do not allow for definite nouns:
(head_adjunct_phrase,
 head_dtr:synsem:loc:cat:def:plus,
 dtrs:hd:synsem:loc:cat:head:adj) *> dtrs:tl:hd:synsem:loc:cat:def:minus.


% The element at the left periphery determines the definiteness:
%
% Df-Adj  N
% Df-N    Adj
% Df-N Df-Adj
%    N    Adj
headed_binary_phrase *> (synsem:loc:cat:def:Def,
                         dtrs:hd:synsem:loc:cat:def:Def).



% German, Chinese, Maltese, but nor Persian
headed_struc *>
   synsem:nonloc:inher:slash:list_with_zero_or_one_element.

% Determiners, classifiers and subjects may not be extracted.
% Not true for Danish subjects, since Danish is a V2 language.
% But we need this constraint for Maltese and Chinese
% St. Mü. 10.07.2009
spr:ne_list *> spr:[@arg(%loc:cat:spr:[],             % this is not necessary, but avoids residues
                          % Hm, removes only one of ten residues
                          nonloc:inher:slash:[])].



pro_drop_phrase *>
 (synsem:loc:cat:spr:[],                 % we do not keep the element around
  head_dtr:synsem:(loc:cat:(head:verb,   % this excludes `sabiħ' as pro drop, which is correct (Fabri, p.c. 11.02.2008).
                                         % only verbs have person, number agreement
                            spr:[@pro_np_ref],
                            subcat:list_of_spirits),
                   right_adj_:minus),         % Hack to ensure high atachment of adjuncts and exclude spurious ambiguities.
  non_head_dtrs:[]).

pro_drop(HeadDtr) :=
 (pro_drop_phrase,
  head_dtr:HeadDtr).


% for pronouns and clitics
(index,
 per:first)  *> sort:human.

(index,
 per:second) *> sort:agentive.    % humans, dogs, ...


fun collect_clld(+,-).
collect_clld(X,Y) if 
   when( (X=(e_list;ne_list);
          Y=(e_list;ne_list)) 
       , undelayed_collect_clld(X,Y)
       ).

undelayed_collect_clld([],[]) if true.
undelayed_collect_clld([synsem:nonloc:inher:clld:Clld|T],CClld) if
  collect_clld(T,ClldT),
  append(Clld,ClldT,CClld).

/*
headed_struc *>
   (synsem:nonloc:inher:clld:bind_off(BClld,collect_clld(Dtrs)),
       head_dtr:synsem:nonloc:to_bind:clld:BClld,
       dtrs:Dtrs).

*/


% This should be parallel to the constraints for REL, but
% DTRS is instantiated only after EFD closure computation,
% and hence reference to DTRS would result in non-termination.
headed_struc *>
   (synsem:nonloc:inher:clld:bind_off(BClld,append(IClld,collect_clld(NHDtrs))),
       head_dtr:synsem:nonloc:(inher:clld:IClld,
                               to_bind:clld:BClld),
       non_head_dtrs:NHDtrs).


/*
headed_binary_struc *>
   (synsem:nonloc:inher:clld:bind_off(BClld,append(Clld1,Clld2)),
       head_dtr:synsem:nonloc:(inher:clld:Clld1,
                               to_bind:clld:BClld),
       non_head_dtrs:hd:synsem:nonloc:inher:clld:Clld2).
*/



% There are no lexical items that bind of clitics,
% so this constraint holds for all non clld structures.
head_non_clld_struc *>
    head_dtr:synsem:nonloc:to_bind:clld:[].

% The specifier of the head daughter is underspecified.
% This allows binding off of the nonlocal dependency before
% the subject or after the subject.
head_clld_phrase *>
   (%synsem:nonloc:inher:clld:[], % wrong
    head_dtr:synsem:(loc:cat:(head:verb,
                              subcat:list_of_spirits),
                     nonloc:to_bind:clld:[Clld]),
    non_head_dtrs:[(%phon:ne_list,
                    % to do: there has to be a restriction on the filler
                    %        that it is definite.
                    synsem:(loc:Clld,
                            nonloc:inher:(rel:[], % "In der hat er geschlafen." hätte sonst zwei Strukturen.
                                          clld:[],
                                          slash:[])))]).

clld_h(HeadDtr,NonHeadDtr) :=
 (head_clld_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).



root :=
 (synsem:(loc:(cat:(head:major,
                    spr:list_of_spirits,
                    subcat:list_of_spirits),
               cont:(gtop:_GTop,     % The H_CONS GTop =q LTop is missing.
                     ltop:_LTop)),
          nonloc:inher:(%clld:[], % This requires an analysis in which clitics introduce nothing into CLLD.
                                  % The lexicon needs 26 min to load with such an analysis. If clitics always project
                                  % information the loading takes 7 min.
                        clld:list_of_complete_locals, % This is needed to get rid of residues, since otherwise the
                                                    % SUBCAT list of the elements in CLLD would be not instantiated.
                        slash:[]))).

interrog :=
 (@root).

decl :=
 (@root).
