% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: speed.pl,v $
%%  $Revision: 293 $
%%      $Date: 2008-03-06 17:48:37 +0100 (Do, 06 Mär 2008) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '*>'/2.


% There is no speed up with these constraints so far.
% Strange ...

/*

% excludes empty determiners and empty nominal heads
% this is not needed for linguistic reasons since no nonlocal
% dependencies are introduced in which these lements could
% be a filler.
% The constraint is needed anyway since Trale does the rule
% computation and takes all empty elements into account.

head_filler_phrase *>
  non_head_dtr:phon:ne_list.

% does not work because of [one CL] book
%head_adjunct_phrase *>
%  head_dtr:synsem:loc:cat:head:major.


(head_adjunct_phrase,
 non_head_dtr:synsem:loc:cat:head:pre_modifier:minus) *>
 head_dtr:synsem:loc:cat:head:major.


% % this excludes adjunct extraction, justified?
% head_adjunct_phrase *>
%   non_head_dtr:synsem:trace:minus.

% this rules out classifiers as arguments in head_argument_phrases.
% classifier phrases are selected vie SPR
head_argument_phrase *>
  non_head_dtr:synsem:loc:cat:head:major.


*/


% This excludes the empty copula as a specifier in the EFD computation.
%head_specifier_phrase *> 
%   non_head_dtrs:hd:synsem:loc:cat:head:(det;noun).



(head_adjunct_phrase,
 non_head_dtrs:hd:synsem:loc:cat:head:pre_modifier:minus) *> synsem:right_adj_:plus.


% Hack to ensure high atachment of adjuncts and exclude spurious ambiguities.
% If the head is final: S V Adj we exclude S [V (O) Adj]
(head_specifier_phrase,
 synsem:loc:cat:head:verb,
 dtrs:tl:hd:synsem:loc:cat:head:verb) *> head_dtr:synsem:right_adj_:minus.


% We mark V (O) S structures als right_adj_:plus.
% The head filler schema is sensitive to this. Otherwise we would get spurious
% ambiguities for O V S structures and even worse ambiguities for
% O V S Adv.
(head_specifier_phrase,
 synsem:loc:cat:head:verb,
 dtrs:hd:synsem:loc:cat:head:verb) *> synsem:right_adj_:plus.

% * O [V S]
%   [O V] S
head_filler_phrase *> head_dtr:synsem:right_adj_:minus.

% We mark V-Cl O structures als right_adj_:plus.
% The head filler schema is sensitive to this. Otherwise we would get spurious
% ambiguities for O V S structures and even worse ambiguities for
% O V S Adv.
(head_clld_phrase,
 synsem:loc:cat:head:verb,
 dtrs:hd:synsem:loc:cat:head:verb) *> synsem:right_adj_:plus.


% [O S V-O] Adv
% * O [S V-O Adv]
(head_clld_phrase,
 synsem:loc:cat:head:verb,
 dtrs:tl:hd:synsem:loc:cat:head:verb) *> head_dtr:synsem:right_adj_:minus.


% * O [V S]
%   [O V] S
head_filler_phrase *> head_dtr:synsem:right_adj_:minus.

% * V _O Adv
%   V Adv _O
(head_adjunct_phrase,
 non_head_dtrs:hd:synsem:loc:cat:head:pre_modifier:minus,
 head_dtr:head_argument_phrase) *> head_dtr:non_head_dtrs:hd:synsem:trace:minus.

% This excludes ambiguities with adjunct/trace attachments.
% * [V _] Adv
%   [V Adv] _
%   [Adv V] _
% * Adv [V _]
(head_argument_phrase,
 head_dtr:head_adjunct_phrase) *> non_head_dtrs:hd:synsem:trace:minus.

% Leider ist Adv V Obj aber nicht auf Spuren beschränkt.


% If there is an object, we mark the phrase plus:
%(head_argument_phrase,
% synsem:loc:cat:head:initial:plus) *> synsem:right_adj_:plus.

% Adjuncts attach to VPs if they are premodifiers.
% Adv [V O]
% Adv O [V _]
% O Adv [V _]
(head_adjunct_phrase,
 non_head_dtrs:hd:synsem:loc:cat:head:pre_modifier:plus) *>  (synsem:loc:cat:subcat:list_of_spirits,
                                                              % * Adv [ V O Subj]
                                                              %   Adv [ V O ] Subj   
                                                              head_dtr:synsem:right_adj_:minus).

%   _ [O V]
% * O [_ V]
pro_drop_phrase *> synsem:right_adj_:plus.


% The following three constraints have no effect on performance,
% but they make the chart display more usable, since rules that will never be used
% are not displayed.

% EFD computation produces an instance of head_filler_phrase in which
% the empty copula is used as the filler. One could require that the SUBCAT list of the filler
% is a list of spirits. This would correspond to the property of Maltese that it does not have
% predicate complexes. The constraint below is faster ...
head_filler_phrase *>
non_head_dtrs:hd:phon:ne_list.


% Same here, determiners cannot be dislocated clitics and empty copulas neither.
head_clld_phrase *>
non_head_dtrs:hd:phon:ne_list.


head_specifier_phrase  *>
  non_head_dtrs:hd:synsem:loc:cont:ind:index. % Determiners and nouns, not verbs. This excludes the empty copula as specifier.