% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: syntax.pl,v $
%%  $Revision: 122 $
%%      $Date: 2007-05-09 09:34:38 +0200 (Wed, 09 May 2007) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.


% already in the signature

% headed_phrase *>
%   head_dtr:syntactic_object.

headed_binary_phrase *>
   non_head_dtrs:[syntactic_object].


headed_phrase *>
  (synsem:loc:cat:head:Head,
   head_dtr:synsem:loc:cat:head:Head).



/*
head_non_filler_phrase *>
   (synsem:nonloc:inher:slash:(list_with_zero_or_one_element,
                               append(Slash1,Slash2)),
       head_dtr:synsem:nonloc:inher:slash:Slash1,
       non_head_dtrs:[synsem:nonloc:inher:slash:Slash2]).
*/

headed_binary_phrase *>
   (synsem:nonloc:inher:slash:(list_with_zero_or_one_element,
                               bind_off(BSlash,append(Slash1,Slash2))),
       head_dtr:synsem:nonloc:(inher:slash:Slash1,
                               to_bind:slash:BSlash),
       non_head_dtrs:[synsem:nonloc:inher:slash:Slash2]).

(head_non_filler_phrase,
   head_dtr:phrase) *>
   head_dtr:synsem:nonloc:to_bind:slash:[].



% restricts adjunct extraction to structures with verbal head.
% Without this constraint an adjunct trace could originate in
% the classifier phrase:
% man read every _ classifier book DE shop = the shop in which the man read every book.

% Reduces the number of edges from 148 to 46.

(head_adjunct_phrase,
 non_head_dtrs:[trace]) *> synsem:loc:cat:head:verb.


% Part of the Trace Principle: The Head-Dtr may not be extracted.
headed_phrase *>
  head_dtr:synsem:trace:minus.

headed_binary_phrase *>
  (rels:append(Rels1,append(Rels2,Rels3)),
   h_cons:append(HCons1,append(HCons2,HCons3)),
   c_cont:(rels:Rels1,
           h_cons:HCons1),

      /*
   head_dtr:(h_cons:HCons2,
             rels:Rels2),
   non_head_dtrs:[(h_cons:HCons3,
                   rels:Rels3)]).

                              */

   % This is equivalent, but gives more readable MRSes, since
   % the relations appear in surface order. 
   dtrs:[(h_cons:HCons2,
          rels:Rels2),(h_cons:HCons3,
                       rels:Rels3)]).                    

% The LTOP and INDEX is represented directly under CONT.
% The values are either changed in the phrase, that is the values in c_cont:hook
% differ from the LTOP/INDEX of the daughters or threaded through c_cont, that is
% LTOP/INDEX in c_cont:hook are identical to the CONT value of one of the daughters.
% This depends on the various subtypes of phrase.
phrase *>
 (synsem:loc:cont:Cont,
  c_cont:hook:Cont).






% This is a case by case specification from where the Hook
% is passed up. In addition, verbal constructions introduce
% a prop_quest_m_rel.
% This is not nice, but I do not see a less stipulative way
% at the moment. (10.09.2006 St. Mü.)
head_non_specifier_phrase *>
  (c_cont:(rels:[],
           h_cons:[])).

% At the top most node GTOP and LTOP of the head are identified
% and everything is embedded under a message relation.
/*

(head_specifier_phrase,
 synsem:loc:cat:head:(adj;verb)) *>
(head_dtr:synsem:loc:cont:(ltop:HeadLTop,
                           gtop:Handle,
                           ind:Event),
 c_cont:(hook:(gtop:LTop,
               ltop:LTop,
               ind:Event),            
         rels:[(prop_quest_m_rel,
                lbl:LTop,
                marg:Handle)],
         h_cons:[(qeq,
                  harg:Handle,
                  larg:HeadLTop)])).

*/


/*
(head_specifier_phrase,
 synsem:loc:cat:head:(adj;verb)) *>
(head_dtr:synsem:loc:cont:(gtop:Handle,
                           ltop:HeadLTop,
                           ind:Event),
 c_cont:(hook:(gtop:LTop,
               ltop:LTop,
               ind:Event),            
         rels:[],
         h_cons:[(qeq,
                  harg:Handle,
                  larg:HeadLTop)])).

*/

(head_specifier_phrase,
 synsem:loc:cat:head:(adj;verb)) *>
(head_dtr:synsem:loc:cont:Hook,
 c_cont:(hook:Hook,            
         rels:[],
         h_cons:[])).


(head_specifier_phrase,
 synsem:loc:cat:head:noun
) *>
(non_head_dtrs:[synsem:loc:cont:Hook],
 c_cont:(hook:Hook,
         rels:[],
         h_cons:[])).


head_argument_phrase *>
 (synsem:loc:cat:(spr:Spr,
                  subcat:Subcat),
  head_dtr:synsem:loc:cat:(spr:Spr,
                           subcat:append(Subcat,[NonHeadDtrSynsem])),
  non_head_dtrs:[synsem:NonHeadDtrSynsem]).


/*

% If this is used, passive has to be dealt with in a separate
% schema, because argument attraction has to happen in a fixed
% order.

head_argument_phrase *>
 (synsem:loc:cat:(spr:Spr,
                  subcat:del(NonHeadDtrSynsem,Subcat)),
  head_dtr:synsem:loc:cat:(spr:Spr,
                           subcat:Subcat),
  non_head_dtrs:[synsem:NonHeadDtrSynsem]).
*/


h_arg(HeadDtr,NonHeadDtr) :=
 (head_argument_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).

head_specifier_phrase *>
 (synsem:loc:cat:(spr:Spr,
                  subcat:[]),
  head_dtr:synsem:loc:cat:(spr:[NonHeadDtrSynsem|Spr],
                           subcat:[]),
  non_head_dtrs:[synsem:NonHeadDtrSynsem]).


% this constraint is an embarresment.
% It rules out the combination of an empty classifier phrase
% with an empty noun.
% This should follow from more principled things.
head_specifier_phrase *>
 phon:ne_list.

(headed_binary_phrase,
 non_head_dtrs:[synsem:loc:cat:head:spec:synsem]) *>
 (head_dtr:synsem:HeadSynsem,
  non_head_dtrs:hd:synsem:loc:cat:head:spec:HeadSynsem).


spr_h(HeadDtr,NonHeadDtr) :=
  (head_specifier_phrase,
   head_dtr:HeadDtr,
   non_head_dtrs:[NonHeadDtr]).

head_adjunct_phrase *>
 (synsem:loc:cat:(spr:Spr,
                  subcat:Subcat),
  head_dtr:synsem:(HeadDtrSynsem,
                   loc:cat:(spr:Spr,
                            subcat:Subcat)),
  non_head_dtrs:[synsem:loc:cat:(head:mod:HeadDtrSynsem,
                                 spr:[],
                                 subcat:[])]).


% The hook is percolated up from the semantic head.
head_adjunct_phrase *>
  (c_cont:hook:Hook,
   non_head_dtrs:[synsem:loc:cont:Hook]).


head_non_adjunct_non_specifier_phrase *>
  (c_cont:hook:Hook,
   head_dtr:synsem:loc:cont:Hook).


h_adj(HeadDtr,NonHeadDtr) :=
 (head_adjunct_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).


% The specifier of the head daughter is underspecified.
% This allows binding off of the nonlocal depnedncy before
% the subject or after the subject.
head_filler_phrase *>
   (synsem:nonloc:inher:slash:[],
    head_dtr:synsem:(loc:cat:(head:verb,
                              subcat:[]),
                     nonloc:(inher:slash:[Slash],
                             to_bind:slash:[Slash])),
    non_head_dtrs:[(%phon:ne_list,
                    % to do: there has to be a restriction on the filler
                    %        that it is definite.
                    synsem:(loc:Slash,
                            nonloc:inher:slash:[]))]).

% the following two constraints should be integrated in the general
% type hierarchy.
head_adjunct_phrase *>
 non_head_dtrs:hd:synsem:nonloc:inher:slash:[].  % adjuncts do not extract and are extraction islands.
                                                 % see Goldberg2006 on extraction islands, but maybe that the
                                                 % non-island phenomena are not relevant for Chinese.
                                                 % We leave the constraint in, for the time beeing. 21.04.2006

head_filler_phrase *>
 (synsem:loc:cat:(spr:Spr,
                  subcat:Subcat),
  head_dtr:synsem:loc:cat:(spr:Spr,
                           subcat:Subcat)).


filler_h(HeadDtr,NonHeadDtr) :=
 (head_filler_phrase,
  head_dtr:HeadDtr,
  non_head_dtrs:[NonHeadDtr]).

pro_drop(HeadDtr) :=
 (%headed_phrase,
  pro_drop_phrase,
  synsem:(loc:cat:(spr:Spr,
                   subcat:[]),
          nonloc:Nonloc),
  rels:[% the quantifier
        (pronoun_q,
         lbl:QHandle,
         arg0:Index,
         rstr:Restr),
        % the nominal relation
        (pron_rel,
         lbl:PronLBL,
         arg0:Index)|Rels],
  h_cons:[(qeq,
           harg:GTop,
           larg:QHandle),
          (qeq,
           harg:Restr,
           larg:PronLBL)|HCons],   
  head_dtr:(HeadDtr,
            synsem:(loc:cat:(spr:Spr,
                             subcat:[(@np_ci(nom,Index),
                                      loc:cont:gtop:GTop)]),
                    nonloc:Nonloc),
            rels:Rels,
            h_cons:HCons),
  non_head_dtrs:[]).




root :=
 (synsem:(loc:(cat:(head:major,
                    spr:[],
                    subcat:[]),
               cont:(gtop:_GTop,     % The H_CONS GTop =q LTop is missing.
                     ltop:_LTop)),
          nonloc:inher:slash:[])).

interrog :=
 (@root).

decl :=
 (@root).
