% -*-  coding:utf-8 mode:trale-prolog   -*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: theory.pl,v $
%%  $Revision: 362 $
%%      $Date: 2013-07-10 15:28:03 +0200 (Wed, 10 Jul 2013) $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: A grammar for Maltese
%%   Language: Trale
%%     System: TRALE 2.7.5 (release ) under Sicstus 3.12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% this checks for unicode settings and emacs communication settings.
% if TRALE_LANGUAGE is set to `cn', the Trale-script was called appropriately.
check_language(Language,LanguageName) :-
        (environ('TRALE_LANGUAGE', Language);
         format(user_error,"~n~n**ERROR: Please start trale with the option `-L ~w' to enable support for ~w.~n~n~n",[Language,LanguageName]),
         abort).

% This is incompatible with TSDB. The call from inside of emacs does not use the -L cn flag.
%:- check_language(cn,'Chinese').
        
:- multifile if/2.

:-['grammar-version'].

%:- parse_and_gen.

:- ['Core-Grammar/hiding-ordering'].



% use ghostview for drawing signatures
graphviz_option(ps,gv).
%graphviz_option(svg,squiggle).

% Load phonology and tree output

:- [trale_home(tree_extensions)].

:- trale_milca_version('2.7.12') -> ['Core-Grammar/old-trale']; ['Core-Grammar/new-trale.pl'].

:- chart_display.

:- nochart_debug.  % this helps if somebody interrupted during chart debugging and the
                   % flag is still set to 'on'.

%nochart_display.
%chart_display.       % default

%:- german.

:- notcl_warnings.  % on = output of warnings in a TCL window, off = output to console

:- hrp.  % use grisu for rules

%:- nofs. % do not print feature structures after parsing


% display MRSes after each parse in the interactive mode.
:- trale_milca_version('2.7.12') -> mrs; true.

% send MRSes to utool for display
:- trale_milca_version('2.7.12') -> display_mrs; true.

% send MRSes to utool for scoping
:- trale_milca_version('2.7.12') -> scope_mrs; true.

% send MRSes to utool for scoping during [incr TSDB()] test runs
% This cannot be done via a on/off flag in the tsdb-Prolog code, since
% [incr TSDB()] is loaded after the grammar.
%tsdb_scope_mrs.


% show error messages from utool in case the MRS does not scope
:- debug_mrs.

root_symbol(@root).
decl_symbol(@decl).
que_symbol(@interrog).

% load tokenization rules for parsing ordinary strings and atoms
:- [tokenization].

% specify signature file
signature(signature).


:- ['Core-Grammar/common'].

:- ['Core-Grammar/maltese'].

% load macros
:- ['maltese-macros'].
:- ['flex_macros'].

% load suffixes for inflection
:- ['maltese-suffixes'].

% load lexical rules
:- ['maltese-lexrules'].

% Loading the clitic lexrules causes very long loading times,
% since all fullformes are computed. You may load clitic-hack instead.
% This file contains the clitics as lexical items. The can than be combined
% with the verbs in syntax.
:- ['clitic-lexrules'].
%:- ['clitic-hack'].


% load lexicon
:- ['maltese-lexicon'].
%:- ['test-lexicon'].
%:- ['lexicon-junk'].

% load phrase structure rules
:- [rules].

% load phrase structure macros
:- ['maltese-syntax'].


% load a test sequence
:- [test_items].

% load additional constraints that make Trales
% rule compilation more efficient.
:- ['speed'].


grammar_hook :-
         inform_user_about_top_level,
         print_examples,
         write('Please, have a look into maltese-ts.works.txt, to get an idea of what works'),
         nl,nl.

examples(['Jien niktibu.',
          'Niktibu.'
          ]).








